#define _CFFI_

/* We try to define Py_LIMITED_API before including Python.h.

   Mess: we can only define it if Py_DEBUG, Py_TRACE_REFS and
   Py_REF_DEBUG are not defined.  This is a best-effort approximation:
   we can learn about Py_DEBUG from pyconfig.h, but it is unclear if
   the same works for the other two macros.  Py_DEBUG implies them,
   but not the other way around.

   Issue #350 is still open: on Windows, the code here causes it to link
   with PYTHON36.DLL (for example) instead of PYTHON3.DLL.  A fix was
   attempted in 164e526a5515 and 14ce6985e1c3, but reverted: virtualenv
   does not make PYTHON3.DLL available, and so the "correctly" compiled
   version would not run inside a virtualenv.  We will re-apply the fix
   after virtualenv has been fixed for some time.  For explanation, see
   issue #355.  For a workaround if you want PYTHON3.DLL and don't worry
   about virtualenv, see issue #350.  See also 'py_limited_api' in
   setuptools_ext.py.
*/
#if !defined(_CFFI_USE_EMBEDDING) && !defined(Py_LIMITED_API)
#  include <pyconfig.h>
#  if !defined(Py_DEBUG) && !defined(Py_TRACE_REFS) && !defined(Py_REF_DEBUG)
#    define Py_LIMITED_API
#  endif
#endif

#include <Python.h>
#ifdef __cplusplus
extern "C" {
#endif
#include <stddef.h>

/* This part is from file 'cffi/parse_c_type.h'.  It is copied at the
   beginning of C sources generated by CFFI's ffi.set_source(). */

typedef void *_cffi_opcode_t;

#define _CFFI_OP(opcode, arg)   (_cffi_opcode_t)(opcode | (((uintptr_t)(arg)) << 8))
#define _CFFI_GETOP(cffi_opcode)    ((unsigned char)(uintptr_t)cffi_opcode)
#define _CFFI_GETARG(cffi_opcode)   (((intptr_t)cffi_opcode) >> 8)

#define _CFFI_OP_PRIMITIVE       1
#define _CFFI_OP_POINTER         3
#define _CFFI_OP_ARRAY           5
#define _CFFI_OP_OPEN_ARRAY      7
#define _CFFI_OP_STRUCT_UNION    9
#define _CFFI_OP_ENUM           11
#define _CFFI_OP_FUNCTION       13
#define _CFFI_OP_FUNCTION_END   15
#define _CFFI_OP_NOOP           17
#define _CFFI_OP_BITFIELD       19
#define _CFFI_OP_TYPENAME       21
#define _CFFI_OP_CPYTHON_BLTN_V 23   // varargs
#define _CFFI_OP_CPYTHON_BLTN_N 25   // noargs
#define _CFFI_OP_CPYTHON_BLTN_O 27   // O  (i.e. a single arg)
#define _CFFI_OP_CONSTANT       29
#define _CFFI_OP_CONSTANT_INT   31
#define _CFFI_OP_GLOBAL_VAR     33
#define _CFFI_OP_DLOPEN_FUNC    35
#define _CFFI_OP_DLOPEN_CONST   37
#define _CFFI_OP_GLOBAL_VAR_F   39
#define _CFFI_OP_EXTERN_PYTHON  41

#define _CFFI_PRIM_VOID          0
#define _CFFI_PRIM_BOOL          1
#define _CFFI_PRIM_CHAR          2
#define _CFFI_PRIM_SCHAR         3
#define _CFFI_PRIM_UCHAR         4
#define _CFFI_PRIM_SHORT         5
#define _CFFI_PRIM_USHORT        6
#define _CFFI_PRIM_INT           7
#define _CFFI_PRIM_UINT          8
#define _CFFI_PRIM_LONG          9
#define _CFFI_PRIM_ULONG        10
#define _CFFI_PRIM_LONGLONG     11
#define _CFFI_PRIM_ULONGLONG    12
#define _CFFI_PRIM_FLOAT        13
#define _CFFI_PRIM_DOUBLE       14
#define _CFFI_PRIM_LONGDOUBLE   15

#define _CFFI_PRIM_WCHAR        16
#define _CFFI_PRIM_INT8         17
#define _CFFI_PRIM_UINT8        18
#define _CFFI_PRIM_INT16        19
#define _CFFI_PRIM_UINT16       20
#define _CFFI_PRIM_INT32        21
#define _CFFI_PRIM_UINT32       22
#define _CFFI_PRIM_INT64        23
#define _CFFI_PRIM_UINT64       24
#define _CFFI_PRIM_INTPTR       25
#define _CFFI_PRIM_UINTPTR      26
#define _CFFI_PRIM_PTRDIFF      27
#define _CFFI_PRIM_SIZE         28
#define _CFFI_PRIM_SSIZE        29
#define _CFFI_PRIM_INT_LEAST8   30
#define _CFFI_PRIM_UINT_LEAST8  31
#define _CFFI_PRIM_INT_LEAST16  32
#define _CFFI_PRIM_UINT_LEAST16 33
#define _CFFI_PRIM_INT_LEAST32  34
#define _CFFI_PRIM_UINT_LEAST32 35
#define _CFFI_PRIM_INT_LEAST64  36
#define _CFFI_PRIM_UINT_LEAST64 37
#define _CFFI_PRIM_INT_FAST8    38
#define _CFFI_PRIM_UINT_FAST8   39
#define _CFFI_PRIM_INT_FAST16   40
#define _CFFI_PRIM_UINT_FAST16  41
#define _CFFI_PRIM_INT_FAST32   42
#define _CFFI_PRIM_UINT_FAST32  43
#define _CFFI_PRIM_INT_FAST64   44
#define _CFFI_PRIM_UINT_FAST64  45
#define _CFFI_PRIM_INTMAX       46
#define _CFFI_PRIM_UINTMAX      47
#define _CFFI_PRIM_FLOATCOMPLEX 48
#define _CFFI_PRIM_DOUBLECOMPLEX 49
#define _CFFI_PRIM_CHAR16       50
#define _CFFI_PRIM_CHAR32       51

#define _CFFI__NUM_PRIM         52
#define _CFFI__UNKNOWN_PRIM           (-1)
#define _CFFI__UNKNOWN_FLOAT_PRIM     (-2)
#define _CFFI__UNKNOWN_LONG_DOUBLE    (-3)

#define _CFFI__IO_FILE_STRUCT         (-1)


struct _cffi_global_s {
    const char *name;
    void *address;
    _cffi_opcode_t type_op;
    void *size_or_direct_fn;  // OP_GLOBAL_VAR: size, or 0 if unknown
                              // OP_CPYTHON_BLTN_*: addr of direct function
};

struct _cffi_getconst_s {
    unsigned long long value;
    const struct _cffi_type_context_s *ctx;
    int gindex;
};

struct _cffi_struct_union_s {
    const char *name;
    int type_index;          // -> _cffi_types, on a OP_STRUCT_UNION
    int flags;               // _CFFI_F_* flags below
    size_t size;
    int alignment;
    int first_field_index;   // -> _cffi_fields array
    int num_fields;
};
#define _CFFI_F_UNION         0x01   // is a union, not a struct
#define _CFFI_F_CHECK_FIELDS  0x02   // complain if fields are not in the
                                     // "standard layout" or if some are missing
#define _CFFI_F_PACKED        0x04   // for CHECK_FIELDS, assume a packed struct
#define _CFFI_F_EXTERNAL      0x08   // in some other ffi.include()
#define _CFFI_F_OPAQUE        0x10   // opaque

struct _cffi_field_s {
    const char *name;
    size_t field_offset;
    size_t field_size;
    _cffi_opcode_t field_type_op;
};

struct _cffi_enum_s {
    const char *name;
    int type_index;          // -> _cffi_types, on a OP_ENUM
    int type_prim;           // _CFFI_PRIM_xxx
    const char *enumerators; // comma-delimited string
};

struct _cffi_typename_s {
    const char *name;
    int type_index;   /* if opaque, points to a possibly artificial
                         OP_STRUCT which is itself opaque */
};

struct _cffi_type_context_s {
    _cffi_opcode_t *types;
    const struct _cffi_global_s *globals;
    const struct _cffi_field_s *fields;
    const struct _cffi_struct_union_s *struct_unions;
    const struct _cffi_enum_s *enums;
    const struct _cffi_typename_s *typenames;
    int num_globals;
    int num_struct_unions;
    int num_enums;
    int num_typenames;
    const char *const *includes;
    int num_types;
    int flags;      /* future extension */
};

struct _cffi_parse_info_s {
    const struct _cffi_type_context_s *ctx;
    _cffi_opcode_t *output;
    unsigned int output_size;
    size_t error_location;
    const char *error_message;
};

struct _cffi_externpy_s {
    const char *name;
    size_t size_of_result;
    void *reserved1, *reserved2;
};

#ifdef _CFFI_INTERNAL
static int parse_c_type(struct _cffi_parse_info_s *info, const char *input);
static int search_in_globals(const struct _cffi_type_context_s *ctx,
                             const char *search, size_t search_len);
static int search_in_struct_unions(const struct _cffi_type_context_s *ctx,
                                   const char *search, size_t search_len);
#endif

/* this block of #ifs should be kept exactly identical between
   c/_cffi_backend.c, cffi/vengine_cpy.py, cffi/vengine_gen.py
   and cffi/_cffi_include.h */
#if defined(_MSC_VER)
# include <malloc.h>   /* for alloca() */
# if _MSC_VER < 1600   /* MSVC < 2010 */
   typedef __int8 int8_t;
   typedef __int16 int16_t;
   typedef __int32 int32_t;
   typedef __int64 int64_t;
   typedef unsigned __int8 uint8_t;
   typedef unsigned __int16 uint16_t;
   typedef unsigned __int32 uint32_t;
   typedef unsigned __int64 uint64_t;
   typedef __int8 int_least8_t;
   typedef __int16 int_least16_t;
   typedef __int32 int_least32_t;
   typedef __int64 int_least64_t;
   typedef unsigned __int8 uint_least8_t;
   typedef unsigned __int16 uint_least16_t;
   typedef unsigned __int32 uint_least32_t;
   typedef unsigned __int64 uint_least64_t;
   typedef __int8 int_fast8_t;
   typedef __int16 int_fast16_t;
   typedef __int32 int_fast32_t;
   typedef __int64 int_fast64_t;
   typedef unsigned __int8 uint_fast8_t;
   typedef unsigned __int16 uint_fast16_t;
   typedef unsigned __int32 uint_fast32_t;
   typedef unsigned __int64 uint_fast64_t;
   typedef __int64 intmax_t;
   typedef unsigned __int64 uintmax_t;
# else
#  include <stdint.h>
# endif
# if _MSC_VER < 1800   /* MSVC < 2013 */
#  ifndef __cplusplus
    typedef unsigned char _Bool;
#  endif
# endif
#else
# include <stdint.h>
# if (defined (__SVR4) && defined (__sun)) || defined(_AIX) || defined(__hpux)
#  include <alloca.h>
# endif
#endif

#ifdef __GNUC__
# define _CFFI_UNUSED_FN  __attribute__((unused))
#else
# define _CFFI_UNUSED_FN  /* nothing */
#endif

#ifdef __cplusplus
# ifndef _Bool
   typedef bool _Bool;   /* semi-hackish: C++ has no _Bool; bool is builtin */
# endif
#endif

/**********  CPython-specific section  **********/
#ifndef PYPY_VERSION


#if PY_MAJOR_VERSION >= 3
# define PyInt_FromLong PyLong_FromLong
#endif

#define _cffi_from_c_double PyFloat_FromDouble
#define _cffi_from_c_float PyFloat_FromDouble
#define _cffi_from_c_long PyInt_FromLong
#define _cffi_from_c_ulong PyLong_FromUnsignedLong
#define _cffi_from_c_longlong PyLong_FromLongLong
#define _cffi_from_c_ulonglong PyLong_FromUnsignedLongLong
#define _cffi_from_c__Bool PyBool_FromLong

#define _cffi_to_c_double PyFloat_AsDouble
#define _cffi_to_c_float PyFloat_AsDouble

#define _cffi_from_c_int(x, type)                                        \
    (((type)-1) > 0 ? /* unsigned */                                     \
        (sizeof(type) < sizeof(long) ?                                   \
            PyInt_FromLong((long)x) :                                    \
         sizeof(type) == sizeof(long) ?                                  \
            PyLong_FromUnsignedLong((unsigned long)x) :                  \
            PyLong_FromUnsignedLongLong((unsigned long long)x)) :        \
        (sizeof(type) <= sizeof(long) ?                                  \
            PyInt_FromLong((long)x) :                                    \
            PyLong_FromLongLong((long long)x)))

#define _cffi_to_c_int(o, type)                                          \
    ((type)(                                                             \
     sizeof(type) == 1 ? (((type)-1) > 0 ? (type)_cffi_to_c_u8(o)        \
                                         : (type)_cffi_to_c_i8(o)) :     \
     sizeof(type) == 2 ? (((type)-1) > 0 ? (type)_cffi_to_c_u16(o)       \
                                         : (type)_cffi_to_c_i16(o)) :    \
     sizeof(type) == 4 ? (((type)-1) > 0 ? (type)_cffi_to_c_u32(o)       \
                                         : (type)_cffi_to_c_i32(o)) :    \
     sizeof(type) == 8 ? (((type)-1) > 0 ? (type)_cffi_to_c_u64(o)       \
                                         : (type)_cffi_to_c_i64(o)) :    \
     (Py_FatalError("unsupported size for type " #type), (type)0)))

#define _cffi_to_c_i8                                                    \
                 ((int(*)(PyObject *))_cffi_exports[1])
#define _cffi_to_c_u8                                                    \
                 ((int(*)(PyObject *))_cffi_exports[2])
#define _cffi_to_c_i16                                                   \
                 ((int(*)(PyObject *))_cffi_exports[3])
#define _cffi_to_c_u16                                                   \
                 ((int(*)(PyObject *))_cffi_exports[4])
#define _cffi_to_c_i32                                                   \
                 ((int(*)(PyObject *))_cffi_exports[5])
#define _cffi_to_c_u32                                                   \
                 ((unsigned int(*)(PyObject *))_cffi_exports[6])
#define _cffi_to_c_i64                                                   \
                 ((long long(*)(PyObject *))_cffi_exports[7])
#define _cffi_to_c_u64                                                   \
                 ((unsigned long long(*)(PyObject *))_cffi_exports[8])
#define _cffi_to_c_char                                                  \
                 ((int(*)(PyObject *))_cffi_exports[9])
#define _cffi_from_c_pointer                                             \
    ((PyObject *(*)(char *, struct _cffi_ctypedescr *))_cffi_exports[10])
#define _cffi_to_c_pointer                                               \
    ((char *(*)(PyObject *, struct _cffi_ctypedescr *))_cffi_exports[11])
#define _cffi_get_struct_layout                                          \
    not used any more
#define _cffi_restore_errno                                              \
    ((void(*)(void))_cffi_exports[13])
#define _cffi_save_errno                                                 \
    ((void(*)(void))_cffi_exports[14])
#define _cffi_from_c_char                                                \
    ((PyObject *(*)(char))_cffi_exports[15])
#define _cffi_from_c_deref                                               \
    ((PyObject *(*)(char *, struct _cffi_ctypedescr *))_cffi_exports[16])
#define _cffi_to_c                                                       \
    ((int(*)(char *, struct _cffi_ctypedescr *, PyObject *))_cffi_exports[17])
#define _cffi_from_c_struct                                              \
    ((PyObject *(*)(char *, struct _cffi_ctypedescr *))_cffi_exports[18])
#define _cffi_to_c_wchar_t                                               \
    ((_cffi_wchar_t(*)(PyObject *))_cffi_exports[19])
#define _cffi_from_c_wchar_t                                             \
    ((PyObject *(*)(_cffi_wchar_t))_cffi_exports[20])
#define _cffi_to_c_long_double                                           \
    ((long double(*)(PyObject *))_cffi_exports[21])
#define _cffi_to_c__Bool                                                 \
    ((_Bool(*)(PyObject *))_cffi_exports[22])
#define _cffi_prepare_pointer_call_argument                              \
    ((Py_ssize_t(*)(struct _cffi_ctypedescr *,                           \
                    PyObject *, char **))_cffi_exports[23])
#define _cffi_convert_array_from_object                                  \
    ((int(*)(char *, struct _cffi_ctypedescr *, PyObject *))_cffi_exports[24])
#define _CFFI_CPIDX  25
#define _cffi_call_python                                                \
    ((void(*)(struct _cffi_externpy_s *, char *))_cffi_exports[_CFFI_CPIDX])
#define _cffi_to_c_wchar3216_t                                           \
    ((int(*)(PyObject *))_cffi_exports[26])
#define _cffi_from_c_wchar3216_t                                         \
    ((PyObject *(*)(int))_cffi_exports[27])
#define _CFFI_NUM_EXPORTS 28

struct _cffi_ctypedescr;

static void *_cffi_exports[_CFFI_NUM_EXPORTS];

#define _cffi_type(index)   (                           \
    assert((((uintptr_t)_cffi_types[index]) & 1) == 0), \
    (struct _cffi_ctypedescr *)_cffi_types[index])

static PyObject *_cffi_init(const char *module_name, Py_ssize_t version,
                            const struct _cffi_type_context_s *ctx)
{
    PyObject *module, *o_arg, *new_module;
    void *raw[] = {
        (void *)module_name,
        (void *)version,
        (void *)_cffi_exports,
        (void *)ctx,
    };

    module = PyImport_ImportModule("_cffi_backend");
    if (module == NULL)
        goto failure;

    o_arg = PyLong_FromVoidPtr((void *)raw);
    if (o_arg == NULL)
        goto failure;

    new_module = PyObject_CallMethod(
        module, (char *)"_init_cffi_1_0_external_module", (char *)"O", o_arg);

    Py_DECREF(o_arg);
    Py_DECREF(module);
    return new_module;

  failure:
    Py_XDECREF(module);
    return NULL;
}


#ifdef HAVE_WCHAR_H
typedef wchar_t _cffi_wchar_t;
#else
typedef uint16_t _cffi_wchar_t;   /* same random pick as _cffi_backend.c */
#endif

_CFFI_UNUSED_FN static uint16_t _cffi_to_c_char16_t(PyObject *o)
{
    if (sizeof(_cffi_wchar_t) == 2)
        return (uint16_t)_cffi_to_c_wchar_t(o);
    else
        return (uint16_t)_cffi_to_c_wchar3216_t(o);
}

_CFFI_UNUSED_FN static PyObject *_cffi_from_c_char16_t(uint16_t x)
{
    if (sizeof(_cffi_wchar_t) == 2)
        return _cffi_from_c_wchar_t((_cffi_wchar_t)x);
    else
        return _cffi_from_c_wchar3216_t((int)x);
}

_CFFI_UNUSED_FN static int _cffi_to_c_char32_t(PyObject *o)
{
    if (sizeof(_cffi_wchar_t) == 4)
        return (int)_cffi_to_c_wchar_t(o);
    else
        return (int)_cffi_to_c_wchar3216_t(o);
}

_CFFI_UNUSED_FN static PyObject *_cffi_from_c_char32_t(int x)
{
    if (sizeof(_cffi_wchar_t) == 4)
        return _cffi_from_c_wchar_t((_cffi_wchar_t)x);
    else
        return _cffi_from_c_wchar3216_t(x);
}


/**********  end CPython-specific section  **********/
#else
_CFFI_UNUSED_FN
static void (*_cffi_call_python_org)(struct _cffi_externpy_s *, char *);
# define _cffi_call_python  _cffi_call_python_org
#endif


#define _cffi_array_len(array)   (sizeof(array) / sizeof((array)[0]))

#define _cffi_prim_int(size, sign)                                      \
    ((size) == 1 ? ((sign) ? _CFFI_PRIM_INT8  : _CFFI_PRIM_UINT8)  :    \
     (size) == 2 ? ((sign) ? _CFFI_PRIM_INT16 : _CFFI_PRIM_UINT16) :    \
     (size) == 4 ? ((sign) ? _CFFI_PRIM_INT32 : _CFFI_PRIM_UINT32) :    \
     (size) == 8 ? ((sign) ? _CFFI_PRIM_INT64 : _CFFI_PRIM_UINT64) :    \
     _CFFI__UNKNOWN_PRIM)

#define _cffi_prim_float(size)                                          \
    ((size) == sizeof(float) ? _CFFI_PRIM_FLOAT :                       \
     (size) == sizeof(double) ? _CFFI_PRIM_DOUBLE :                     \
     (size) == sizeof(long double) ? _CFFI__UNKNOWN_LONG_DOUBLE :       \
     _CFFI__UNKNOWN_FLOAT_PRIM)

#define _cffi_check_int(got, got_nonpos, expected)      \
    ((got_nonpos) == (expected <= 0) &&                 \
     (got) == (unsigned long long)expected)

#ifdef MS_WIN32
# define _cffi_stdcall  __stdcall
#else
# define _cffi_stdcall  /* nothing */
#endif

#ifdef __cplusplus
}
#endif

/************************************************************/

#include <git2.h>

/************************************************************/

static void *_cffi_types[] = {
/*  0 */ _CFFI_OP(_CFFI_OP_FUNCTION, 10), // char const *()(git_refspec const *)
/*  1 */ _CFFI_OP(_CFFI_OP_POINTER, 742), // git_refspec const *
/*  2 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/*  3 */ _CFFI_OP(_CFFI_OP_FUNCTION, 10), // char const *()(git_remote const *)
/*  4 */ _CFFI_OP(_CFFI_OP_POINTER, 743), // git_remote const *
/*  5 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/*  6 */ _CFFI_OP(_CFFI_OP_FUNCTION, 10), // char const *()(git_submodule *)
/*  7 */ _CFFI_OP(_CFFI_OP_POINTER, 756), // git_submodule *
/*  8 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/*  9 */ _CFFI_OP(_CFFI_OP_FUNCTION, 683), // git_attr_t()(char const *)
/* 10 */ _CFFI_OP(_CFFI_OP_POINTER, 682), // char const *
/* 11 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 12 */ _CFFI_OP(_CFFI_OP_FUNCTION, 685), // git_blame_hunk const *()(git_blame *, size_t)
/* 13 */ _CFFI_OP(_CFFI_OP_POINTER, 684), // git_blame *
/* 14 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 28), // size_t
/* 15 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 16 */ _CFFI_OP(_CFFI_OP_FUNCTION, 685), // git_blame_hunk const *()(git_blame *, uint32_t)
/* 17 */ _CFFI_OP(_CFFI_OP_NOOP, 13),
/* 18 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 22), // uint32_t
/* 19 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 20 */ _CFFI_OP(_CFFI_OP_FUNCTION, 717), // git_direction()(git_refspec const *)
/* 21 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/* 22 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 23 */ _CFFI_OP(_CFFI_OP_FUNCTION, 718), // git_error const *()(void)
/* 24 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 25 */ _CFFI_OP(_CFFI_OP_FUNCTION, 307), // git_index_entry const *()(git_index *, char const *, int)
/* 26 */ _CFFI_OP(_CFFI_OP_POINTER, 724), // git_index *
/* 27 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 28 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7), // int
/* 29 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 30 */ _CFFI_OP(_CFFI_OP_FUNCTION, 307), // git_index_entry const *()(git_index *, size_t)
/* 31 */ _CFFI_OP(_CFFI_OP_NOOP, 26),
/* 32 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 28),
/* 33 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 34 */ _CFFI_OP(_CFFI_OP_FUNCTION, 68), // git_oid const *()(git_submodule *)
/* 35 */ _CFFI_OP(_CFFI_OP_NOOP, 7),
/* 36 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 37 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // git_refspec const *()(git_remote const *, size_t)
/* 38 */ _CFFI_OP(_CFFI_OP_NOOP, 4),
/* 39 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 28),
/* 40 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 41 */ _CFFI_OP(_CFFI_OP_FUNCTION, 551), // git_transfer_progress const *()(git_remote *)
/* 42 */ _CFFI_OP(_CFFI_OP_POINTER, 743), // git_remote *
/* 43 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 44 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(char const * *, char const * *, git_repository const *)
/* 45 */ _CFFI_OP(_CFFI_OP_POINTER, 10), // char const * *
/* 46 */ _CFFI_OP(_CFFI_OP_NOOP, 45),
/* 47 */ _CFFI_OP(_CFFI_OP_POINTER, 746), // git_repository const *
/* 48 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 49 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(char const * *, git_config const *, char const *)
/* 50 */ _CFFI_OP(_CFFI_OP_NOOP, 45),
/* 51 */ _CFFI_OP(_CFFI_OP_POINTER, 699), // git_config const *
/* 52 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 53 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 54 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(char const * *, git_repository *, uint32_t, char const *, char const *)
/* 55 */ _CFFI_OP(_CFFI_OP_NOOP, 45),
/* 56 */ _CFFI_OP(_CFFI_OP_POINTER, 746), // git_repository *
/* 57 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 22),
/* 58 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 59 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 60 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 61 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(char const *, char const *, void *)
/* 62 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 63 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 64 */ _CFFI_OP(_CFFI_OP_POINTER, 795), // void *
/* 65 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 66 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(char const *, git_oid const *, git_oid const *, void *)
/* 67 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 68 */ _CFFI_OP(_CFFI_OP_POINTER, 735), // git_oid const *
/* 69 */ _CFFI_OP(_CFFI_OP_NOOP, 68),
/* 70 */ _CFFI_OP(_CFFI_OP_NOOP, 64),
/* 71 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 72 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(char const *, int, void *)
/* 73 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 74 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 75 */ _CFFI_OP(_CFFI_OP_NOOP, 64),
/* 76 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 77 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_blame * *, git_repository *, char const *, git_blame_options *)
/* 78 */ _CFFI_OP(_CFFI_OP_POINTER, 13), // git_blame * *
/* 79 */ _CFFI_OP(_CFFI_OP_NOOP, 56),
/* 80 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 81 */ _CFFI_OP(_CFFI_OP_POINTER, 687), // git_blame_options *
/* 82 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 83 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_blame_options *, unsigned int)
/* 84 */ _CFFI_OP(_CFFI_OP_NOOP, 81),
/* 85 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 8), // unsigned int
/* 86 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 87 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_buf *)
/* 88 */ _CFFI_OP(_CFFI_OP_POINTER, 688), // git_buf *
/* 89 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 90 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_buf *, git_describe_result const *, git_describe_format_options const *)
/* 91 */ _CFFI_OP(_CFFI_OP_NOOP, 88),
/* 92 */ _CFFI_OP(_CFFI_OP_POINTER, 708), // git_describe_result const *
/* 93 */ _CFFI_OP(_CFFI_OP_POINTER, 706), // git_describe_format_options const *
/* 94 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 95 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_buf *, git_refspec const *, char const *)
/* 96 */ _CFFI_OP(_CFFI_OP_NOOP, 88),
/* 97 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/* 98 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 99 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 100 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_cert *, int, char const *, void *)
/* 101 */ _CFFI_OP(_CFFI_OP_POINTER, 689), // git_cert *
/* 102 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 103 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 104 */ _CFFI_OP(_CFFI_OP_NOOP, 64),
/* 105 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 106 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_checkout_notify_t, char const *, git_diff_file const *, git_diff_file const *, git_diff_file const *, void *)
/* 107 */ _CFFI_OP(_CFFI_OP_ENUM, 2), // git_checkout_notify_t
/* 108 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 109 */ _CFFI_OP(_CFFI_OP_POINTER, 713), // git_diff_file const *
/* 110 */ _CFFI_OP(_CFFI_OP_NOOP, 109),
/* 111 */ _CFFI_OP(_CFFI_OP_NOOP, 109),
/* 112 */ _CFFI_OP(_CFFI_OP_NOOP, 64),
/* 113 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 114 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_checkout_options *, unsigned int)
/* 115 */ _CFFI_OP(_CFFI_OP_POINTER, 694), // git_checkout_options *
/* 116 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 8),
/* 117 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 118 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_clone_options *, unsigned int)
/* 119 */ _CFFI_OP(_CFFI_OP_POINTER, 697), // git_clone_options *
/* 120 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 8),
/* 121 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 122 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_config * *)
/* 123 */ _CFFI_OP(_CFFI_OP_POINTER, 131), // git_config * *
/* 124 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 125 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_config * *, char const *)
/* 126 */ _CFFI_OP(_CFFI_OP_NOOP, 123),
/* 127 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 128 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 129 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_config * *, git_config *)
/* 130 */ _CFFI_OP(_CFFI_OP_NOOP, 123),
/* 131 */ _CFFI_OP(_CFFI_OP_POINTER, 699), // git_config *
/* 132 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 133 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_config * *, git_repository *)
/* 134 */ _CFFI_OP(_CFFI_OP_NOOP, 123),
/* 135 */ _CFFI_OP(_CFFI_OP_NOOP, 56),
/* 136 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 137 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_config *, char const *)
/* 138 */ _CFFI_OP(_CFFI_OP_NOOP, 131),
/* 139 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 140 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 141 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_config *, char const *, char const *)
/* 142 */ _CFFI_OP(_CFFI_OP_NOOP, 131),
/* 143 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 144 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 145 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 146 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_config *, char const *, char const *, char const *)
/* 147 */ _CFFI_OP(_CFFI_OP_NOOP, 131),
/* 148 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 149 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 150 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 151 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 152 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_config *, char const *, git_config_level_t, git_repository const *, int)
/* 153 */ _CFFI_OP(_CFFI_OP_NOOP, 131),
/* 154 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 155 */ _CFFI_OP(_CFFI_OP_ENUM, 4), // git_config_level_t
/* 156 */ _CFFI_OP(_CFFI_OP_NOOP, 47),
/* 157 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 158 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 159 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_config *, char const *, int)
/* 160 */ _CFFI_OP(_CFFI_OP_NOOP, 131),
/* 161 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 162 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 163 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 164 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_config *, char const *, int64_t)
/* 165 */ _CFFI_OP(_CFFI_OP_NOOP, 131),
/* 166 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 167 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 23), // int64_t
/* 168 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 169 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_config_entry * *, git_config const *, char const *)
/* 170 */ _CFFI_OP(_CFFI_OP_POINTER, 647), // git_config_entry * *
/* 171 */ _CFFI_OP(_CFFI_OP_NOOP, 51),
/* 172 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 173 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 174 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_config_entry * *, git_config_iterator *)
/* 175 */ _CFFI_OP(_CFFI_OP_NOOP, 170),
/* 176 */ _CFFI_OP(_CFFI_OP_POINTER, 701), // git_config_iterator *
/* 177 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 178 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_config_iterator * *, git_config const *)
/* 179 */ _CFFI_OP(_CFFI_OP_POINTER, 176), // git_config_iterator * *
/* 180 */ _CFFI_OP(_CFFI_OP_NOOP, 51),
/* 181 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 182 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_config_iterator * *, git_config const *, char const *, char const *)
/* 183 */ _CFFI_OP(_CFFI_OP_NOOP, 179),
/* 184 */ _CFFI_OP(_CFFI_OP_NOOP, 51),
/* 185 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 186 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 187 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 188 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_cred * *, char const *)
/* 189 */ _CFFI_OP(_CFFI_OP_POINTER, 702), // git_cred * *
/* 190 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 191 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 192 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_cred * *, char const *, char const *)
/* 193 */ _CFFI_OP(_CFFI_OP_NOOP, 189),
/* 194 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 195 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 196 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 197 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_cred * *, char const *, char const *, char const *, char const *)
/* 198 */ _CFFI_OP(_CFFI_OP_NOOP, 189),
/* 199 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 200 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 201 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 202 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 203 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 204 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_cred * *, char const *, char const *, unsigned int, void *)
/* 205 */ _CFFI_OP(_CFFI_OP_NOOP, 189),
/* 206 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 207 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 208 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 8),
/* 209 */ _CFFI_OP(_CFFI_OP_NOOP, 64),
/* 210 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 211 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_describe_format_options *, unsigned int)
/* 212 */ _CFFI_OP(_CFFI_OP_POINTER, 706), // git_describe_format_options *
/* 213 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 8),
/* 214 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 215 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_describe_options *, unsigned int)
/* 216 */ _CFFI_OP(_CFFI_OP_POINTER, 707), // git_describe_options *
/* 217 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 8),
/* 218 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 219 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_describe_result * *, git_object *, git_describe_options *)
/* 220 */ _CFFI_OP(_CFFI_OP_POINTER, 653), // git_describe_result * *
/* 221 */ _CFFI_OP(_CFFI_OP_POINTER, 734), // git_object *
/* 222 */ _CFFI_OP(_CFFI_OP_NOOP, 216),
/* 223 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 224 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_describe_result * *, git_repository *, git_describe_options *)
/* 225 */ _CFFI_OP(_CFFI_OP_NOOP, 220),
/* 226 */ _CFFI_OP(_CFFI_OP_NOOP, 56),
/* 227 */ _CFFI_OP(_CFFI_OP_NOOP, 216),
/* 228 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 229 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_diff * *, git_repository *, git_index *, git_diff_options const *)
/* 230 */ _CFFI_OP(_CFFI_OP_POINTER, 710), // git_diff * *
/* 231 */ _CFFI_OP(_CFFI_OP_NOOP, 56),
/* 232 */ _CFFI_OP(_CFFI_OP_NOOP, 26),
/* 233 */ _CFFI_OP(_CFFI_OP_POINTER, 714), // git_diff_options const *
/* 234 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 235 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_diff * *, git_repository *, git_tree *, git_index *, git_diff_options const *)
/* 236 */ _CFFI_OP(_CFFI_OP_NOOP, 230),
/* 237 */ _CFFI_OP(_CFFI_OP_NOOP, 56),
/* 238 */ _CFFI_OP(_CFFI_OP_POINTER, 763), // git_tree *
/* 239 */ _CFFI_OP(_CFFI_OP_NOOP, 26),
/* 240 */ _CFFI_OP(_CFFI_OP_NOOP, 233),
/* 241 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 242 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_diff const *, char const *, char const *, void *)
/* 243 */ _CFFI_OP(_CFFI_OP_POINTER, 711), // git_diff const *
/* 244 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 245 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 246 */ _CFFI_OP(_CFFI_OP_NOOP, 64),
/* 247 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 248 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_diff const *, git_diff_delta const *, char const *, void *)
/* 249 */ _CFFI_OP(_CFFI_OP_NOOP, 243),
/* 250 */ _CFFI_OP(_CFFI_OP_POINTER, 712), // git_diff_delta const *
/* 251 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 252 */ _CFFI_OP(_CFFI_OP_NOOP, 64),
/* 253 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 254 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_diff_options *, unsigned int)
/* 255 */ _CFFI_OP(_CFFI_OP_POINTER, 714), // git_diff_options *
/* 256 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 8),
/* 257 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 258 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_fetch_options *, unsigned int)
/* 259 */ _CFFI_OP(_CFFI_OP_POINTER, 722), // git_fetch_options *
/* 260 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 8),
/* 261 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 262 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_index * *, char const *)
/* 263 */ _CFFI_OP(_CFFI_OP_POINTER, 26), // git_index * *
/* 264 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 265 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 266 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_index * *, git_repository *)
/* 267 */ _CFFI_OP(_CFFI_OP_NOOP, 263),
/* 268 */ _CFFI_OP(_CFFI_OP_NOOP, 56),
/* 269 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 270 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_index * *, git_repository *, git_commit *, git_commit *, unsigned int, git_merge_options const *)
/* 271 */ _CFFI_OP(_CFFI_OP_NOOP, 263),
/* 272 */ _CFFI_OP(_CFFI_OP_NOOP, 56),
/* 273 */ _CFFI_OP(_CFFI_OP_POINTER, 698), // git_commit *
/* 274 */ _CFFI_OP(_CFFI_OP_NOOP, 273),
/* 275 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 8),
/* 276 */ _CFFI_OP(_CFFI_OP_POINTER, 733), // git_merge_options const *
/* 277 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 278 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_index * *, git_repository *, git_commit const *, git_commit const *, git_merge_options const *)
/* 279 */ _CFFI_OP(_CFFI_OP_NOOP, 263),
/* 280 */ _CFFI_OP(_CFFI_OP_NOOP, 56),
/* 281 */ _CFFI_OP(_CFFI_OP_POINTER, 698), // git_commit const *
/* 282 */ _CFFI_OP(_CFFI_OP_NOOP, 281),
/* 283 */ _CFFI_OP(_CFFI_OP_NOOP, 276),
/* 284 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 285 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_index * *, git_repository *, git_tree const *, git_tree const *, git_tree const *, git_merge_options const *)
/* 286 */ _CFFI_OP(_CFFI_OP_NOOP, 263),
/* 287 */ _CFFI_OP(_CFFI_OP_NOOP, 56),
/* 288 */ _CFFI_OP(_CFFI_OP_POINTER, 763), // git_tree const *
/* 289 */ _CFFI_OP(_CFFI_OP_NOOP, 288),
/* 290 */ _CFFI_OP(_CFFI_OP_NOOP, 288),
/* 291 */ _CFFI_OP(_CFFI_OP_NOOP, 276),
/* 292 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 293 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_index *)
/* 294 */ _CFFI_OP(_CFFI_OP_NOOP, 26),
/* 295 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 296 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_index *, char const *)
/* 297 */ _CFFI_OP(_CFFI_OP_NOOP, 26),
/* 298 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 299 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 300 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_index *, char const *, int)
/* 301 */ _CFFI_OP(_CFFI_OP_NOOP, 26),
/* 302 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 303 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 304 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 305 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_index *, git_index_entry const *)
/* 306 */ _CFFI_OP(_CFFI_OP_NOOP, 26),
/* 307 */ _CFFI_OP(_CFFI_OP_POINTER, 726), // git_index_entry const *
/* 308 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 309 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_index *, git_strarray const *, unsigned int, int(*)(char const *, char const *, void *), void *)
/* 310 */ _CFFI_OP(_CFFI_OP_NOOP, 26),
/* 311 */ _CFFI_OP(_CFFI_OP_POINTER, 755), // git_strarray const *
/* 312 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 8),
/* 313 */ _CFFI_OP(_CFFI_OP_POINTER, 61), // int(*)(char const *, char const *, void *)
/* 314 */ _CFFI_OP(_CFFI_OP_NOOP, 64),
/* 315 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 316 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_index *, git_tree const *)
/* 317 */ _CFFI_OP(_CFFI_OP_NOOP, 26),
/* 318 */ _CFFI_OP(_CFFI_OP_NOOP, 288),
/* 319 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 320 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_index *, int)
/* 321 */ _CFFI_OP(_CFFI_OP_NOOP, 26),
/* 322 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 323 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 324 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_index const *)
/* 325 */ _CFFI_OP(_CFFI_OP_POINTER, 724), // git_index const *
/* 326 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 327 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_index_conflict_iterator * *, git_index *)
/* 328 */ _CFFI_OP(_CFFI_OP_POINTER, 342), // git_index_conflict_iterator * *
/* 329 */ _CFFI_OP(_CFFI_OP_NOOP, 26),
/* 330 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 331 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_index_entry const * *, git_index_entry const * *, git_index_entry const * *, git_index *, char const *)
/* 332 */ _CFFI_OP(_CFFI_OP_POINTER, 307), // git_index_entry const * *
/* 333 */ _CFFI_OP(_CFFI_OP_NOOP, 332),
/* 334 */ _CFFI_OP(_CFFI_OP_NOOP, 332),
/* 335 */ _CFFI_OP(_CFFI_OP_NOOP, 26),
/* 336 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 337 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 338 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_index_entry const * *, git_index_entry const * *, git_index_entry const * *, git_index_conflict_iterator *)
/* 339 */ _CFFI_OP(_CFFI_OP_NOOP, 332),
/* 340 */ _CFFI_OP(_CFFI_OP_NOOP, 332),
/* 341 */ _CFFI_OP(_CFFI_OP_NOOP, 332),
/* 342 */ _CFFI_OP(_CFFI_OP_POINTER, 725), // git_index_conflict_iterator *
/* 343 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 344 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_merge_file_result *, git_repository *, git_index_entry const *, git_index_entry const *, git_index_entry const *, git_merge_file_options const *)
/* 345 */ _CFFI_OP(_CFFI_OP_POINTER, 731), // git_merge_file_result *
/* 346 */ _CFFI_OP(_CFFI_OP_NOOP, 56),
/* 347 */ _CFFI_OP(_CFFI_OP_NOOP, 307),
/* 348 */ _CFFI_OP(_CFFI_OP_NOOP, 307),
/* 349 */ _CFFI_OP(_CFFI_OP_NOOP, 307),
/* 350 */ _CFFI_OP(_CFFI_OP_POINTER, 730), // git_merge_file_options const *
/* 351 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 352 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_merge_options *, unsigned int)
/* 353 */ _CFFI_OP(_CFFI_OP_POINTER, 733), // git_merge_options *
/* 354 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 8),
/* 355 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 356 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_oid *, git_index *)
/* 357 */ _CFFI_OP(_CFFI_OP_POINTER, 735), // git_oid *
/* 358 */ _CFFI_OP(_CFFI_OP_NOOP, 26),
/* 359 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 360 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_oid *, git_index *, git_repository *)
/* 361 */ _CFFI_OP(_CFFI_OP_NOOP, 357),
/* 362 */ _CFFI_OP(_CFFI_OP_NOOP, 26),
/* 363 */ _CFFI_OP(_CFFI_OP_NOOP, 56),
/* 364 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 365 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_oid *, git_repository *, git_signature const *, char const *, uint32_t)
/* 366 */ _CFFI_OP(_CFFI_OP_NOOP, 357),
/* 367 */ _CFFI_OP(_CFFI_OP_NOOP, 56),
/* 368 */ _CFFI_OP(_CFFI_OP_POINTER, 751), // git_signature const *
/* 369 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 370 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 22),
/* 371 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 372 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_proxy_options *, unsigned int)
/* 373 */ _CFFI_OP(_CFFI_OP_POINTER, 736), // git_proxy_options *
/* 374 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 8),
/* 375 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 376 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_push_options *, unsigned int)
/* 377 */ _CFFI_OP(_CFFI_OP_POINTER, 738), // git_push_options *
/* 378 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 8),
/* 379 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 380 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_push_update const * *, size_t, void *)
/* 381 */ _CFFI_OP(_CFFI_OP_POINTER, 739), // git_push_update const * *
/* 382 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 28),
/* 383 */ _CFFI_OP(_CFFI_OP_NOOP, 64),
/* 384 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 385 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_refspec const *)
/* 386 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/* 387 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 388 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_refspec const *, char const *)
/* 389 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/* 390 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 391 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 392 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_remote * *, git_repository *, char const *)
/* 393 */ _CFFI_OP(_CFFI_OP_POINTER, 42), // git_remote * *
/* 394 */ _CFFI_OP(_CFFI_OP_NOOP, 56),
/* 395 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 396 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 397 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_remote * *, git_repository *, char const *, char const *)
/* 398 */ _CFFI_OP(_CFFI_OP_NOOP, 393),
/* 399 */ _CFFI_OP(_CFFI_OP_NOOP, 56),
/* 400 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 401 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 402 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 403 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_remote * *, git_repository *, char const *, char const *, char const *)
/* 404 */ _CFFI_OP(_CFFI_OP_NOOP, 393),
/* 405 */ _CFFI_OP(_CFFI_OP_NOOP, 56),
/* 406 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 407 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 408 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 409 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 410 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_remote * *, git_repository *, char const *, char const *, void *)
/* 411 */ _CFFI_OP(_CFFI_OP_NOOP, 393),
/* 412 */ _CFFI_OP(_CFFI_OP_NOOP, 56),
/* 413 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 414 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 415 */ _CFFI_OP(_CFFI_OP_NOOP, 64),
/* 416 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 417 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_remote *, git_remote_callbacks const *)
/* 418 */ _CFFI_OP(_CFFI_OP_NOOP, 42),
/* 419 */ _CFFI_OP(_CFFI_OP_POINTER, 745), // git_remote_callbacks const *
/* 420 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 421 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_remote *, git_strarray const *, git_fetch_options const *, char const *)
/* 422 */ _CFFI_OP(_CFFI_OP_NOOP, 42),
/* 423 */ _CFFI_OP(_CFFI_OP_NOOP, 311),
/* 424 */ _CFFI_OP(_CFFI_OP_POINTER, 722), // git_fetch_options const *
/* 425 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 426 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 427 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_remote *, git_strarray const *, git_push_options const *)
/* 428 */ _CFFI_OP(_CFFI_OP_NOOP, 42),
/* 429 */ _CFFI_OP(_CFFI_OP_NOOP, 311),
/* 430 */ _CFFI_OP(_CFFI_OP_POINTER, 738), // git_push_options const *
/* 431 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 432 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_remote_callbacks *, unsigned int)
/* 433 */ _CFFI_OP(_CFFI_OP_POINTER, 745), // git_remote_callbacks *
/* 434 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 8),
/* 435 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 436 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_remote_completion_type, void *)
/* 437 */ _CFFI_OP(_CFFI_OP_ENUM, 25), // git_remote_completion_type
/* 438 */ _CFFI_OP(_CFFI_OP_NOOP, 64),
/* 439 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 440 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_repository * *, char const *, char const *, git_clone_options const *)
/* 441 */ _CFFI_OP(_CFFI_OP_POINTER, 56), // git_repository * *
/* 442 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 443 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 444 */ _CFFI_OP(_CFFI_OP_POINTER, 697), // git_clone_options const *
/* 445 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 446 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_repository * *, char const *, git_repository_init_options *)
/* 447 */ _CFFI_OP(_CFFI_OP_NOOP, 441),
/* 448 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 449 */ _CFFI_OP(_CFFI_OP_POINTER, 749), // git_repository_init_options *
/* 450 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 451 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_repository * *, char const *, int, void *)
/* 452 */ _CFFI_OP(_CFFI_OP_NOOP, 441),
/* 453 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 454 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 455 */ _CFFI_OP(_CFFI_OP_NOOP, 64),
/* 456 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 457 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_repository * *, char const *, unsigned int)
/* 458 */ _CFFI_OP(_CFFI_OP_NOOP, 441),
/* 459 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 460 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 8),
/* 461 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 462 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_repository * *, git_submodule *)
/* 463 */ _CFFI_OP(_CFFI_OP_NOOP, 441),
/* 464 */ _CFFI_OP(_CFFI_OP_NOOP, 7),
/* 465 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 466 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_repository *)
/* 467 */ _CFFI_OP(_CFFI_OP_NOOP, 56),
/* 468 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 469 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_repository *, char const *)
/* 470 */ _CFFI_OP(_CFFI_OP_NOOP, 56),
/* 471 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 472 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 473 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_repository *, char const *, char const *)
/* 474 */ _CFFI_OP(_CFFI_OP_NOOP, 56),
/* 475 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 476 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 477 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 478 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_repository *, git_checkout_options const *)
/* 479 */ _CFFI_OP(_CFFI_OP_NOOP, 56),
/* 480 */ _CFFI_OP(_CFFI_OP_POINTER, 694), // git_checkout_options const *
/* 481 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 482 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_repository *, git_index *, git_checkout_options const *)
/* 483 */ _CFFI_OP(_CFFI_OP_NOOP, 56),
/* 484 */ _CFFI_OP(_CFFI_OP_NOOP, 26),
/* 485 */ _CFFI_OP(_CFFI_OP_NOOP, 480),
/* 486 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 487 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_repository *, git_object const *, git_checkout_options const *)
/* 488 */ _CFFI_OP(_CFFI_OP_NOOP, 56),
/* 489 */ _CFFI_OP(_CFFI_OP_POINTER, 734), // git_object const *
/* 490 */ _CFFI_OP(_CFFI_OP_NOOP, 480),
/* 491 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 492 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_repository *, git_oid const *)
/* 493 */ _CFFI_OP(_CFFI_OP_NOOP, 56),
/* 494 */ _CFFI_OP(_CFFI_OP_NOOP, 68),
/* 495 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 496 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_repository *, int(*)(size_t, char const *, git_oid const *, void *), void *)
/* 497 */ _CFFI_OP(_CFFI_OP_NOOP, 56),
/* 498 */ _CFFI_OP(_CFFI_OP_POINTER, 591), // int(*)(size_t, char const *, git_oid const *, void *)
/* 499 */ _CFFI_OP(_CFFI_OP_NOOP, 64),
/* 500 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 501 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_repository *, size_t)
/* 502 */ _CFFI_OP(_CFFI_OP_NOOP, 56),
/* 503 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 28),
/* 504 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 505 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_repository *, size_t, git_stash_apply_options const *)
/* 506 */ _CFFI_OP(_CFFI_OP_NOOP, 56),
/* 507 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 28),
/* 508 */ _CFFI_OP(_CFFI_OP_POINTER, 753), // git_stash_apply_options const *
/* 509 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 510 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_repository_init_options *, unsigned int)
/* 511 */ _CFFI_OP(_CFFI_OP_NOOP, 449),
/* 512 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 8),
/* 513 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 514 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_stash_apply_options *, unsigned int)
/* 515 */ _CFFI_OP(_CFFI_OP_POINTER, 753), // git_stash_apply_options *
/* 516 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 8),
/* 517 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 518 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_stash_apply_progress_t, void *)
/* 519 */ _CFFI_OP(_CFFI_OP_ENUM, 21), // git_stash_apply_progress_t
/* 520 */ _CFFI_OP(_CFFI_OP_NOOP, 64),
/* 521 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 522 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_strarray *, git_remote const *)
/* 523 */ _CFFI_OP(_CFFI_OP_POINTER, 755), // git_strarray *
/* 524 */ _CFFI_OP(_CFFI_OP_NOOP, 4),
/* 525 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 526 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_strarray *, git_repository *)
/* 527 */ _CFFI_OP(_CFFI_OP_NOOP, 523),
/* 528 */ _CFFI_OP(_CFFI_OP_NOOP, 56),
/* 529 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 530 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_strarray *, git_repository *, char const *, char const *)
/* 531 */ _CFFI_OP(_CFFI_OP_NOOP, 523),
/* 532 */ _CFFI_OP(_CFFI_OP_NOOP, 56),
/* 533 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 534 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 535 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 536 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_submodule * *, git_repository *, char const *)
/* 537 */ _CFFI_OP(_CFFI_OP_POINTER, 7), // git_submodule * *
/* 538 */ _CFFI_OP(_CFFI_OP_NOOP, 56),
/* 539 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 540 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 541 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_submodule *, int, git_submodule_update_options *)
/* 542 */ _CFFI_OP(_CFFI_OP_NOOP, 7),
/* 543 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 544 */ _CFFI_OP(_CFFI_OP_POINTER, 758), // git_submodule_update_options *
/* 545 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 546 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_submodule_update_options *, unsigned int)
/* 547 */ _CFFI_OP(_CFFI_OP_NOOP, 544),
/* 548 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 8),
/* 549 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 550 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_transfer_progress const *, void *)
/* 551 */ _CFFI_OP(_CFFI_OP_POINTER, 760), // git_transfer_progress const *
/* 552 */ _CFFI_OP(_CFFI_OP_NOOP, 64),
/* 553 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 554 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(git_transport * *, git_remote *, void *)
/* 555 */ _CFFI_OP(_CFFI_OP_POINTER, 761), // git_transport * *
/* 556 */ _CFFI_OP(_CFFI_OP_NOOP, 42),
/* 557 */ _CFFI_OP(_CFFI_OP_NOOP, 64),
/* 558 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 559 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(int *, char const *)
/* 560 */ _CFFI_OP(_CFFI_OP_POINTER, 28), // int *
/* 561 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 562 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 563 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(int *, void *, void *, void *)
/* 564 */ _CFFI_OP(_CFFI_OP_NOOP, 560),
/* 565 */ _CFFI_OP(_CFFI_OP_NOOP, 64),
/* 566 */ _CFFI_OP(_CFFI_OP_NOOP, 64),
/* 567 */ _CFFI_OP(_CFFI_OP_NOOP, 64),
/* 568 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 569 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(int, uint32_t, uint32_t, void *)
/* 570 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 571 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 22),
/* 572 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 22),
/* 573 */ _CFFI_OP(_CFFI_OP_NOOP, 64),
/* 574 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 575 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(int64_t *, char const *)
/* 576 */ _CFFI_OP(_CFFI_OP_POINTER, 167), // int64_t *
/* 577 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 578 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 579 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(size_t *, git_index *, char const *)
/* 580 */ _CFFI_OP(_CFFI_OP_POINTER, 14), // size_t *
/* 581 */ _CFFI_OP(_CFFI_OP_NOOP, 26),
/* 582 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 583 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 584 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(size_t *, size_t *, git_repository *, git_oid const *, git_oid const *)
/* 585 */ _CFFI_OP(_CFFI_OP_NOOP, 580),
/* 586 */ _CFFI_OP(_CFFI_OP_NOOP, 580),
/* 587 */ _CFFI_OP(_CFFI_OP_NOOP, 56),
/* 588 */ _CFFI_OP(_CFFI_OP_NOOP, 68),
/* 589 */ _CFFI_OP(_CFFI_OP_NOOP, 68),
/* 590 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 591 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(size_t, char const *, git_oid const *, void *)
/* 592 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 28),
/* 593 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 594 */ _CFFI_OP(_CFFI_OP_NOOP, 68),
/* 595 */ _CFFI_OP(_CFFI_OP_NOOP, 64),
/* 596 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 597 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(unsigned int, unsigned int, size_t, void *)
/* 598 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 8),
/* 599 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 8),
/* 600 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 28),
/* 601 */ _CFFI_OP(_CFFI_OP_NOOP, 64),
/* 602 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 603 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(void * *, git_diff_file const *, char const *, size_t, void *)
/* 604 */ _CFFI_OP(_CFFI_OP_POINTER, 64), // void * *
/* 605 */ _CFFI_OP(_CFFI_OP_NOOP, 109),
/* 606 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 607 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 28),
/* 608 */ _CFFI_OP(_CFFI_OP_NOOP, 64),
/* 609 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 610 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(void * *, git_diff_file const *, char const *, void *)
/* 611 */ _CFFI_OP(_CFFI_OP_NOOP, 604),
/* 612 */ _CFFI_OP(_CFFI_OP_NOOP, 109),
/* 613 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 614 */ _CFFI_OP(_CFFI_OP_NOOP, 64),
/* 615 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 616 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // int()(void)
/* 617 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 618 */ _CFFI_OP(_CFFI_OP_FUNCTION, 14), // size_t()(git_index const *)
/* 619 */ _CFFI_OP(_CFFI_OP_NOOP, 325),
/* 620 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 621 */ _CFFI_OP(_CFFI_OP_FUNCTION, 14), // size_t()(git_remote const *)
/* 622 */ _CFFI_OP(_CFFI_OP_NOOP, 4),
/* 623 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 624 */ _CFFI_OP(_CFFI_OP_FUNCTION, 18), // uint32_t()(git_blame *)
/* 625 */ _CFFI_OP(_CFFI_OP_NOOP, 13),
/* 626 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 627 */ _CFFI_OP(_CFFI_OP_FUNCTION, 795), // void()(char const *, size_t, size_t, void *)
/* 628 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 629 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 28),
/* 630 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 28),
/* 631 */ _CFFI_OP(_CFFI_OP_NOOP, 64),
/* 632 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 633 */ _CFFI_OP(_CFFI_OP_FUNCTION, 795), // void()(git_blame *)
/* 634 */ _CFFI_OP(_CFFI_OP_NOOP, 13),
/* 635 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 636 */ _CFFI_OP(_CFFI_OP_FUNCTION, 795), // void()(git_buf *)
/* 637 */ _CFFI_OP(_CFFI_OP_NOOP, 88),
/* 638 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 639 */ _CFFI_OP(_CFFI_OP_FUNCTION, 795), // void()(git_checkout_perfdata const *, void *)
/* 640 */ _CFFI_OP(_CFFI_OP_POINTER, 695), // git_checkout_perfdata const *
/* 641 */ _CFFI_OP(_CFFI_OP_NOOP, 64),
/* 642 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 643 */ _CFFI_OP(_CFFI_OP_FUNCTION, 795), // void()(git_config *)
/* 644 */ _CFFI_OP(_CFFI_OP_NOOP, 131),
/* 645 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 646 */ _CFFI_OP(_CFFI_OP_FUNCTION, 795), // void()(git_config_entry *)
/* 647 */ _CFFI_OP(_CFFI_OP_POINTER, 700), // git_config_entry *
/* 648 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 649 */ _CFFI_OP(_CFFI_OP_FUNCTION, 795), // void()(git_config_iterator *)
/* 650 */ _CFFI_OP(_CFFI_OP_NOOP, 176),
/* 651 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 652 */ _CFFI_OP(_CFFI_OP_FUNCTION, 795), // void()(git_describe_result *)
/* 653 */ _CFFI_OP(_CFFI_OP_POINTER, 708), // git_describe_result *
/* 654 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 655 */ _CFFI_OP(_CFFI_OP_FUNCTION, 795), // void()(git_index *)
/* 656 */ _CFFI_OP(_CFFI_OP_NOOP, 26),
/* 657 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 658 */ _CFFI_OP(_CFFI_OP_FUNCTION, 795), // void()(git_index_conflict_iterator *)
/* 659 */ _CFFI_OP(_CFFI_OP_NOOP, 342),
/* 660 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 661 */ _CFFI_OP(_CFFI_OP_FUNCTION, 795), // void()(git_merge_file_result *)
/* 662 */ _CFFI_OP(_CFFI_OP_NOOP, 345),
/* 663 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 664 */ _CFFI_OP(_CFFI_OP_FUNCTION, 795), // void()(git_remote *)
/* 665 */ _CFFI_OP(_CFFI_OP_NOOP, 42),
/* 666 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 667 */ _CFFI_OP(_CFFI_OP_FUNCTION, 795), // void()(git_repository *)
/* 668 */ _CFFI_OP(_CFFI_OP_NOOP, 56),
/* 669 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 670 */ _CFFI_OP(_CFFI_OP_FUNCTION, 795), // void()(git_strarray *)
/* 671 */ _CFFI_OP(_CFFI_OP_NOOP, 523),
/* 672 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 673 */ _CFFI_OP(_CFFI_OP_FUNCTION, 795), // void()(git_submodule *)
/* 674 */ _CFFI_OP(_CFFI_OP_NOOP, 7),
/* 675 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 676 */ _CFFI_OP(_CFFI_OP_FUNCTION, 795), // void()(void *, void *)
/* 677 */ _CFFI_OP(_CFFI_OP_NOOP, 64),
/* 678 */ _CFFI_OP(_CFFI_OP_NOOP, 64),
/* 679 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 680 */ _CFFI_OP(_CFFI_OP_POINTER, 681), // char * *
/* 681 */ _CFFI_OP(_CFFI_OP_POINTER, 682), // char *
/* 682 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 2), // char
/* 683 */ _CFFI_OP(_CFFI_OP_ENUM, 0), // git_attr_t
/* 684 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 20), // git_blame
/* 685 */ _CFFI_OP(_CFFI_OP_POINTER, 686), // git_blame_hunk const *
/* 686 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 21), // git_blame_hunk
/* 687 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 22), // git_blame_options
/* 688 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 0), // git_buf
/* 689 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 1), // git_cert
/* 690 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 2), // git_cert_hostkey
/* 691 */ _CFFI_OP(_CFFI_OP_ENUM, 1), // git_cert_ssh_t
/* 692 */ _CFFI_OP(_CFFI_OP_ENUM, 24), // git_cert_t
/* 693 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 3), // git_cert_x509
/* 694 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 23), // git_checkout_options
/* 695 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 4), // git_checkout_perfdata
/* 696 */ _CFFI_OP(_CFFI_OP_ENUM, 3), // git_clone_local_t
/* 697 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 24), // git_clone_options
/* 698 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 25), // git_commit
/* 699 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 26), // git_config
/* 700 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 27), // git_config_entry
/* 701 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 28), // git_config_iterator
/* 702 */ _CFFI_OP(_CFFI_OP_POINTER, 703), // git_cred *
/* 703 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 29), // git_cred
/* 704 */ _CFFI_OP(_CFFI_OP_ENUM, 5), // git_credtype_t
/* 705 */ _CFFI_OP(_CFFI_OP_ENUM, 6), // git_delta_t
/* 706 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 5), // git_describe_format_options
/* 707 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 30), // git_describe_options
/* 708 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 31), // git_describe_result
/* 709 */ _CFFI_OP(_CFFI_OP_ENUM, 7), // git_describe_strategy_t
/* 710 */ _CFFI_OP(_CFFI_OP_POINTER, 711), // git_diff *
/* 711 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 32), // git_diff
/* 712 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 6), // git_diff_delta
/* 713 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 7), // git_diff_file
/* 714 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 8), // git_diff_options
/* 715 */ _CFFI_OP(_CFFI_OP_POINTER, 716), // git_diff_similarity_metric *
/* 716 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 9), // git_diff_similarity_metric
/* 717 */ _CFFI_OP(_CFFI_OP_ENUM, 8), // git_direction
/* 718 */ _CFFI_OP(_CFFI_OP_POINTER, 719), // git_error const *
/* 719 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 10), // git_error
/* 720 */ _CFFI_OP(_CFFI_OP_ENUM, 9), // git_error_code
/* 721 */ _CFFI_OP(_CFFI_OP_ENUM, 10), // git_feature_t
/* 722 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 11), // git_fetch_options
/* 723 */ _CFFI_OP(_CFFI_OP_ENUM, 11), // git_fetch_prune_t
/* 724 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 33), // git_index
/* 725 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 34), // git_index_conflict_iterator
/* 726 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 35), // git_index_entry
/* 727 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 12), // git_index_time
/* 728 */ _CFFI_OP(_CFFI_OP_ENUM, 12), // git_merge_file_favor_t
/* 729 */ _CFFI_OP(_CFFI_OP_ENUM, 13), // git_merge_file_flag_t
/* 730 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 13), // git_merge_file_options
/* 731 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 14), // git_merge_file_result
/* 732 */ _CFFI_OP(_CFFI_OP_ENUM, 14), // git_merge_flag_t
/* 733 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 15), // git_merge_options
/* 734 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 36), // git_object
/* 735 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 37), // git_oid
/* 736 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 16), // git_proxy_options
/* 737 */ _CFFI_OP(_CFFI_OP_ENUM, 15), // git_proxy_t
/* 738 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 17), // git_push_options
/* 739 */ _CFFI_OP(_CFFI_OP_POINTER, 740), // git_push_update const *
/* 740 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 18), // git_push_update
/* 741 */ _CFFI_OP(_CFFI_OP_ENUM, 16), // git_reference_t
/* 742 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 38), // git_refspec
/* 743 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 39), // git_remote
/* 744 */ _CFFI_OP(_CFFI_OP_ENUM, 17), // git_remote_autotag_option_t
/* 745 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 40), // git_remote_callbacks
/* 746 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 41), // git_repository
/* 747 */ _CFFI_OP(_CFFI_OP_ENUM, 18), // git_repository_init_flag_t
/* 748 */ _CFFI_OP(_CFFI_OP_ENUM, 19), // git_repository_init_mode_t
/* 749 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 19), // git_repository_init_options
/* 750 */ _CFFI_OP(_CFFI_OP_POINTER, 751), // git_signature *
/* 751 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 42), // git_signature
/* 752 */ _CFFI_OP(_CFFI_OP_ENUM, 20), // git_stash_apply_flags
/* 753 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 43), // git_stash_apply_options
/* 754 */ _CFFI_OP(_CFFI_OP_ENUM, 22), // git_stash_flags
/* 755 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 44), // git_strarray
/* 756 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 45), // git_submodule
/* 757 */ _CFFI_OP(_CFFI_OP_ENUM, 23), // git_submodule_ignore_t
/* 758 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 46), // git_submodule_update_options
/* 759 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 47), // git_time
/* 760 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 48), // git_transfer_progress
/* 761 */ _CFFI_OP(_CFFI_OP_POINTER, 762), // git_transport *
/* 762 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 49), // git_transport
/* 763 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 50), // git_tree
/* 764 */ _CFFI_OP(_CFFI_OP_POINTER, 66), // int(*)(char const *, git_oid const *, git_oid const *, void *)
/* 765 */ _CFFI_OP(_CFFI_OP_POINTER, 72), // int(*)(char const *, int, void *)
/* 766 */ _CFFI_OP(_CFFI_OP_POINTER, 100), // int(*)(git_cert *, int, char const *, void *)
/* 767 */ _CFFI_OP(_CFFI_OP_POINTER, 106), // int(*)(git_checkout_notify_t, char const *, git_diff_file const *, git_diff_file const *, git_diff_file const *, void *)
/* 768 */ _CFFI_OP(_CFFI_OP_POINTER, 204), // int(*)(git_cred * *, char const *, char const *, unsigned int, void *)
/* 769 */ _CFFI_OP(_CFFI_OP_POINTER, 242), // int(*)(git_diff const *, char const *, char const *, void *)
/* 770 */ _CFFI_OP(_CFFI_OP_POINTER, 248), // int(*)(git_diff const *, git_diff_delta const *, char const *, void *)
/* 771 */ _CFFI_OP(_CFFI_OP_POINTER, 380), // int(*)(git_push_update const * *, size_t, void *)
/* 772 */ _CFFI_OP(_CFFI_OP_POINTER, 410), // int(*)(git_remote * *, git_repository *, char const *, char const *, void *)
/* 773 */ _CFFI_OP(_CFFI_OP_POINTER, 436), // int(*)(git_remote_completion_type, void *)
/* 774 */ _CFFI_OP(_CFFI_OP_POINTER, 451), // int(*)(git_repository * *, char const *, int, void *)
/* 775 */ _CFFI_OP(_CFFI_OP_POINTER, 518), // int(*)(git_stash_apply_progress_t, void *)
/* 776 */ _CFFI_OP(_CFFI_OP_POINTER, 550), // int(*)(git_transfer_progress const *, void *)
/* 777 */ _CFFI_OP(_CFFI_OP_POINTER, 554), // int(*)(git_transport * *, git_remote *, void *)
/* 778 */ _CFFI_OP(_CFFI_OP_POINTER, 563), // int(*)(int *, void *, void *, void *)
/* 779 */ _CFFI_OP(_CFFI_OP_POINTER, 569), // int(*)(int, uint32_t, uint32_t, void *)
/* 780 */ _CFFI_OP(_CFFI_OP_POINTER, 597), // int(*)(unsigned int, unsigned int, size_t, void *)
/* 781 */ _CFFI_OP(_CFFI_OP_POINTER, 603), // int(*)(void * *, git_diff_file const *, char const *, size_t, void *)
/* 782 */ _CFFI_OP(_CFFI_OP_POINTER, 610), // int(*)(void * *, git_diff_file const *, char const *, void *)
/* 783 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 21), // int32_t
/* 784 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 20), // uint16_t
/* 785 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4), // unsigned char
/* 786 */ _CFFI_OP(_CFFI_OP_ARRAY, 785), // unsigned char[16]
/* 787 */ (_cffi_opcode_t)(16),
/* 788 */ _CFFI_OP(_CFFI_OP_ARRAY, 785), // unsigned char[20]
/* 789 */ (_cffi_opcode_t)(20),
/* 790 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 6), // unsigned short
/* 791 */ _CFFI_OP(_CFFI_OP_POINTER, 627), // void(*)(char const *, size_t, size_t, void *)
/* 792 */ _CFFI_OP(_CFFI_OP_POINTER, 639), // void(*)(git_checkout_perfdata const *, void *)
/* 793 */ _CFFI_OP(_CFFI_OP_POINTER, 646), // void(*)(git_config_entry *)
/* 794 */ _CFFI_OP(_CFFI_OP_POINTER, 676), // void(*)(void *, void *)
/* 795 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 0), // void
};

static int _cffi_const_GIT_ATTR_UNSPECIFIED_T(unsigned long long *o)
{
  int n = (GIT_ATTR_UNSPECIFIED_T) <= 0;
  *o = (unsigned long long)((GIT_ATTR_UNSPECIFIED_T) | 0);  /* check that GIT_ATTR_UNSPECIFIED_T is an integer */
  return n;
}

static int _cffi_const_GIT_ATTR_TRUE_T(unsigned long long *o)
{
  int n = (GIT_ATTR_TRUE_T) <= 0;
  *o = (unsigned long long)((GIT_ATTR_TRUE_T) | 0);  /* check that GIT_ATTR_TRUE_T is an integer */
  return n;
}

static int _cffi_const_GIT_ATTR_FALSE_T(unsigned long long *o)
{
  int n = (GIT_ATTR_FALSE_T) <= 0;
  *o = (unsigned long long)((GIT_ATTR_FALSE_T) | 0);  /* check that GIT_ATTR_FALSE_T is an integer */
  return n;
}

static int _cffi_const_GIT_ATTR_VALUE_T(unsigned long long *o)
{
  int n = (GIT_ATTR_VALUE_T) <= 0;
  *o = (unsigned long long)((GIT_ATTR_VALUE_T) | 0);  /* check that GIT_ATTR_VALUE_T is an integer */
  return n;
}

_CFFI_UNUSED_FN
static void _cffi_checkfld_typedef_git_buf(git_buf *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { char * *tmp = &p->ptr; (void)tmp; }
  (void)((p->asize) | 0);  /* check that 'git_buf.asize' is an integer */
  (void)((p->size) | 0);  /* check that 'git_buf.size' is an integer */
}
struct _cffi_align_typedef_git_buf { char x; git_buf y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld_typedef_git_cert(git_cert *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { git_cert_t *tmp = &p->cert_type; (void)tmp; }
}
struct _cffi_align_typedef_git_cert { char x; git_cert y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld_typedef_git_cert_hostkey(git_cert_hostkey *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { git_cert *tmp = &p->parent; (void)tmp; }
  { git_cert_ssh_t *tmp = &p->type; (void)tmp; }
  { unsigned char(*tmp)[16] = &p->hash_md5; (void)tmp; }
  { unsigned char(*tmp)[20] = &p->hash_sha1; (void)tmp; }
}
struct _cffi_align_typedef_git_cert_hostkey { char x; git_cert_hostkey y; };

static int _cffi_const_GIT_CERT_SSH_MD5(unsigned long long *o)
{
  int n = (GIT_CERT_SSH_MD5) <= 0;
  *o = (unsigned long long)((GIT_CERT_SSH_MD5) | 0);  /* check that GIT_CERT_SSH_MD5 is an integer */
  return n;
}

static int _cffi_const_GIT_CERT_SSH_SHA1(unsigned long long *o)
{
  int n = (GIT_CERT_SSH_SHA1) <= 0;
  *o = (unsigned long long)((GIT_CERT_SSH_SHA1) | 0);  /* check that GIT_CERT_SSH_SHA1 is an integer */
  return n;
}

_CFFI_UNUSED_FN
static void _cffi_checkfld_typedef_git_cert_x509(git_cert_x509 *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { git_cert *tmp = &p->parent; (void)tmp; }
  { void * *tmp = &p->data; (void)tmp; }
  (void)((p->len) | 0);  /* check that 'git_cert_x509.len' is an integer */
}
struct _cffi_align_typedef_git_cert_x509 { char x; git_cert_x509 y; };

static int _cffi_const_GIT_CHECKOUT_NOTIFY_NONE(unsigned long long *o)
{
  int n = (GIT_CHECKOUT_NOTIFY_NONE) <= 0;
  *o = (unsigned long long)((GIT_CHECKOUT_NOTIFY_NONE) | 0);  /* check that GIT_CHECKOUT_NOTIFY_NONE is an integer */
  return n;
}

static int _cffi_const_GIT_CHECKOUT_NOTIFY_CONFLICT(unsigned long long *o)
{
  int n = (GIT_CHECKOUT_NOTIFY_CONFLICT) <= 0;
  *o = (unsigned long long)((GIT_CHECKOUT_NOTIFY_CONFLICT) | 0);  /* check that GIT_CHECKOUT_NOTIFY_CONFLICT is an integer */
  return n;
}

static int _cffi_const_GIT_CHECKOUT_NOTIFY_DIRTY(unsigned long long *o)
{
  int n = (GIT_CHECKOUT_NOTIFY_DIRTY) <= 0;
  *o = (unsigned long long)((GIT_CHECKOUT_NOTIFY_DIRTY) | 0);  /* check that GIT_CHECKOUT_NOTIFY_DIRTY is an integer */
  return n;
}

static int _cffi_const_GIT_CHECKOUT_NOTIFY_UPDATED(unsigned long long *o)
{
  int n = (GIT_CHECKOUT_NOTIFY_UPDATED) <= 0;
  *o = (unsigned long long)((GIT_CHECKOUT_NOTIFY_UPDATED) | 0);  /* check that GIT_CHECKOUT_NOTIFY_UPDATED is an integer */
  return n;
}

static int _cffi_const_GIT_CHECKOUT_NOTIFY_UNTRACKED(unsigned long long *o)
{
  int n = (GIT_CHECKOUT_NOTIFY_UNTRACKED) <= 0;
  *o = (unsigned long long)((GIT_CHECKOUT_NOTIFY_UNTRACKED) | 0);  /* check that GIT_CHECKOUT_NOTIFY_UNTRACKED is an integer */
  return n;
}

static int _cffi_const_GIT_CHECKOUT_NOTIFY_IGNORED(unsigned long long *o)
{
  int n = (GIT_CHECKOUT_NOTIFY_IGNORED) <= 0;
  *o = (unsigned long long)((GIT_CHECKOUT_NOTIFY_IGNORED) | 0);  /* check that GIT_CHECKOUT_NOTIFY_IGNORED is an integer */
  return n;
}

static int _cffi_const_GIT_CHECKOUT_NOTIFY_ALL(unsigned long long *o)
{
  int n = (GIT_CHECKOUT_NOTIFY_ALL) <= 0;
  *o = (unsigned long long)((GIT_CHECKOUT_NOTIFY_ALL) | 0);  /* check that GIT_CHECKOUT_NOTIFY_ALL is an integer */
  return n;
}

_CFFI_UNUSED_FN
static void _cffi_checkfld_typedef_git_checkout_perfdata(git_checkout_perfdata *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  (void)((p->mkdir_calls) | 0);  /* check that 'git_checkout_perfdata.mkdir_calls' is an integer */
  (void)((p->stat_calls) | 0);  /* check that 'git_checkout_perfdata.stat_calls' is an integer */
  (void)((p->chmod_calls) | 0);  /* check that 'git_checkout_perfdata.chmod_calls' is an integer */
}
struct _cffi_align_typedef_git_checkout_perfdata { char x; git_checkout_perfdata y; };

static int _cffi_const_GIT_CLONE_LOCAL_AUTO(unsigned long long *o)
{
  int n = (GIT_CLONE_LOCAL_AUTO) <= 0;
  *o = (unsigned long long)((GIT_CLONE_LOCAL_AUTO) | 0);  /* check that GIT_CLONE_LOCAL_AUTO is an integer */
  return n;
}

static int _cffi_const_GIT_CLONE_LOCAL(unsigned long long *o)
{
  int n = (GIT_CLONE_LOCAL) <= 0;
  *o = (unsigned long long)((GIT_CLONE_LOCAL) | 0);  /* check that GIT_CLONE_LOCAL is an integer */
  return n;
}

static int _cffi_const_GIT_CLONE_NO_LOCAL(unsigned long long *o)
{
  int n = (GIT_CLONE_NO_LOCAL) <= 0;
  *o = (unsigned long long)((GIT_CLONE_NO_LOCAL) | 0);  /* check that GIT_CLONE_NO_LOCAL is an integer */
  return n;
}

static int _cffi_const_GIT_CLONE_LOCAL_NO_LINKS(unsigned long long *o)
{
  int n = (GIT_CLONE_LOCAL_NO_LINKS) <= 0;
  *o = (unsigned long long)((GIT_CLONE_LOCAL_NO_LINKS) | 0);  /* check that GIT_CLONE_LOCAL_NO_LINKS is an integer */
  return n;
}

static int _cffi_const_GIT_CONFIG_LEVEL_PROGRAMDATA(unsigned long long *o)
{
  int n = (GIT_CONFIG_LEVEL_PROGRAMDATA) <= 0;
  *o = (unsigned long long)((GIT_CONFIG_LEVEL_PROGRAMDATA) | 0);  /* check that GIT_CONFIG_LEVEL_PROGRAMDATA is an integer */
  return n;
}

static int _cffi_const_GIT_CONFIG_LEVEL_SYSTEM(unsigned long long *o)
{
  int n = (GIT_CONFIG_LEVEL_SYSTEM) <= 0;
  *o = (unsigned long long)((GIT_CONFIG_LEVEL_SYSTEM) | 0);  /* check that GIT_CONFIG_LEVEL_SYSTEM is an integer */
  return n;
}

static int _cffi_const_GIT_CONFIG_LEVEL_XDG(unsigned long long *o)
{
  int n = (GIT_CONFIG_LEVEL_XDG) <= 0;
  *o = (unsigned long long)((GIT_CONFIG_LEVEL_XDG) | 0);  /* check that GIT_CONFIG_LEVEL_XDG is an integer */
  return n;
}

static int _cffi_const_GIT_CONFIG_LEVEL_GLOBAL(unsigned long long *o)
{
  int n = (GIT_CONFIG_LEVEL_GLOBAL) <= 0;
  *o = (unsigned long long)((GIT_CONFIG_LEVEL_GLOBAL) | 0);  /* check that GIT_CONFIG_LEVEL_GLOBAL is an integer */
  return n;
}

static int _cffi_const_GIT_CONFIG_LEVEL_LOCAL(unsigned long long *o)
{
  int n = (GIT_CONFIG_LEVEL_LOCAL) <= 0;
  *o = (unsigned long long)((GIT_CONFIG_LEVEL_LOCAL) | 0);  /* check that GIT_CONFIG_LEVEL_LOCAL is an integer */
  return n;
}

static int _cffi_const_GIT_CONFIG_LEVEL_APP(unsigned long long *o)
{
  int n = (GIT_CONFIG_LEVEL_APP) <= 0;
  *o = (unsigned long long)((GIT_CONFIG_LEVEL_APP) | 0);  /* check that GIT_CONFIG_LEVEL_APP is an integer */
  return n;
}

static int _cffi_const_GIT_CONFIG_HIGHEST_LEVEL(unsigned long long *o)
{
  int n = (GIT_CONFIG_HIGHEST_LEVEL) <= 0;
  *o = (unsigned long long)((GIT_CONFIG_HIGHEST_LEVEL) | 0);  /* check that GIT_CONFIG_HIGHEST_LEVEL is an integer */
  return n;
}

static int _cffi_const_GIT_CREDTYPE_USERPASS_PLAINTEXT(unsigned long long *o)
{
  int n = (GIT_CREDTYPE_USERPASS_PLAINTEXT) <= 0;
  *o = (unsigned long long)((GIT_CREDTYPE_USERPASS_PLAINTEXT) | 0);  /* check that GIT_CREDTYPE_USERPASS_PLAINTEXT is an integer */
  return n;
}

static int _cffi_const_GIT_CREDTYPE_SSH_KEY(unsigned long long *o)
{
  int n = (GIT_CREDTYPE_SSH_KEY) <= 0;
  *o = (unsigned long long)((GIT_CREDTYPE_SSH_KEY) | 0);  /* check that GIT_CREDTYPE_SSH_KEY is an integer */
  return n;
}

static int _cffi_const_GIT_CREDTYPE_SSH_CUSTOM(unsigned long long *o)
{
  int n = (GIT_CREDTYPE_SSH_CUSTOM) <= 0;
  *o = (unsigned long long)((GIT_CREDTYPE_SSH_CUSTOM) | 0);  /* check that GIT_CREDTYPE_SSH_CUSTOM is an integer */
  return n;
}

static int _cffi_const_GIT_CREDTYPE_DEFAULT(unsigned long long *o)
{
  int n = (GIT_CREDTYPE_DEFAULT) <= 0;
  *o = (unsigned long long)((GIT_CREDTYPE_DEFAULT) | 0);  /* check that GIT_CREDTYPE_DEFAULT is an integer */
  return n;
}

static int _cffi_const_GIT_CREDTYPE_SSH_INTERACTIVE(unsigned long long *o)
{
  int n = (GIT_CREDTYPE_SSH_INTERACTIVE) <= 0;
  *o = (unsigned long long)((GIT_CREDTYPE_SSH_INTERACTIVE) | 0);  /* check that GIT_CREDTYPE_SSH_INTERACTIVE is an integer */
  return n;
}

static int _cffi_const_GIT_CREDTYPE_USERNAME(unsigned long long *o)
{
  int n = (GIT_CREDTYPE_USERNAME) <= 0;
  *o = (unsigned long long)((GIT_CREDTYPE_USERNAME) | 0);  /* check that GIT_CREDTYPE_USERNAME is an integer */
  return n;
}

static int _cffi_const_GIT_CREDTYPE_SSH_MEMORY(unsigned long long *o)
{
  int n = (GIT_CREDTYPE_SSH_MEMORY) <= 0;
  *o = (unsigned long long)((GIT_CREDTYPE_SSH_MEMORY) | 0);  /* check that GIT_CREDTYPE_SSH_MEMORY is an integer */
  return n;
}

static int _cffi_const_GIT_DELTA_UNMODIFIED(unsigned long long *o)
{
  int n = (GIT_DELTA_UNMODIFIED) <= 0;
  *o = (unsigned long long)((GIT_DELTA_UNMODIFIED) | 0);  /* check that GIT_DELTA_UNMODIFIED is an integer */
  return n;
}

static int _cffi_const_GIT_DELTA_ADDED(unsigned long long *o)
{
  int n = (GIT_DELTA_ADDED) <= 0;
  *o = (unsigned long long)((GIT_DELTA_ADDED) | 0);  /* check that GIT_DELTA_ADDED is an integer */
  return n;
}

static int _cffi_const_GIT_DELTA_DELETED(unsigned long long *o)
{
  int n = (GIT_DELTA_DELETED) <= 0;
  *o = (unsigned long long)((GIT_DELTA_DELETED) | 0);  /* check that GIT_DELTA_DELETED is an integer */
  return n;
}

static int _cffi_const_GIT_DELTA_MODIFIED(unsigned long long *o)
{
  int n = (GIT_DELTA_MODIFIED) <= 0;
  *o = (unsigned long long)((GIT_DELTA_MODIFIED) | 0);  /* check that GIT_DELTA_MODIFIED is an integer */
  return n;
}

static int _cffi_const_GIT_DELTA_RENAMED(unsigned long long *o)
{
  int n = (GIT_DELTA_RENAMED) <= 0;
  *o = (unsigned long long)((GIT_DELTA_RENAMED) | 0);  /* check that GIT_DELTA_RENAMED is an integer */
  return n;
}

static int _cffi_const_GIT_DELTA_COPIED(unsigned long long *o)
{
  int n = (GIT_DELTA_COPIED) <= 0;
  *o = (unsigned long long)((GIT_DELTA_COPIED) | 0);  /* check that GIT_DELTA_COPIED is an integer */
  return n;
}

static int _cffi_const_GIT_DELTA_IGNORED(unsigned long long *o)
{
  int n = (GIT_DELTA_IGNORED) <= 0;
  *o = (unsigned long long)((GIT_DELTA_IGNORED) | 0);  /* check that GIT_DELTA_IGNORED is an integer */
  return n;
}

static int _cffi_const_GIT_DELTA_UNTRACKED(unsigned long long *o)
{
  int n = (GIT_DELTA_UNTRACKED) <= 0;
  *o = (unsigned long long)((GIT_DELTA_UNTRACKED) | 0);  /* check that GIT_DELTA_UNTRACKED is an integer */
  return n;
}

static int _cffi_const_GIT_DELTA_TYPECHANGE(unsigned long long *o)
{
  int n = (GIT_DELTA_TYPECHANGE) <= 0;
  *o = (unsigned long long)((GIT_DELTA_TYPECHANGE) | 0);  /* check that GIT_DELTA_TYPECHANGE is an integer */
  return n;
}

static int _cffi_const_GIT_DELTA_UNREADABLE(unsigned long long *o)
{
  int n = (GIT_DELTA_UNREADABLE) <= 0;
  *o = (unsigned long long)((GIT_DELTA_UNREADABLE) | 0);  /* check that GIT_DELTA_UNREADABLE is an integer */
  return n;
}

static int _cffi_const_GIT_DELTA_CONFLICTED(unsigned long long *o)
{
  int n = (GIT_DELTA_CONFLICTED) <= 0;
  *o = (unsigned long long)((GIT_DELTA_CONFLICTED) | 0);  /* check that GIT_DELTA_CONFLICTED is an integer */
  return n;
}

_CFFI_UNUSED_FN
static void _cffi_checkfld_typedef_git_describe_format_options(git_describe_format_options *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  (void)((p->version) | 0);  /* check that 'git_describe_format_options.version' is an integer */
  (void)((p->abbreviated_size) | 0);  /* check that 'git_describe_format_options.abbreviated_size' is an integer */
  (void)((p->always_use_long_format) | 0);  /* check that 'git_describe_format_options.always_use_long_format' is an integer */
  { char const * *tmp = &p->dirty_suffix; (void)tmp; }
}
struct _cffi_align_typedef_git_describe_format_options { char x; git_describe_format_options y; };

static int _cffi_const_GIT_DESCRIBE_DEFAULT(unsigned long long *o)
{
  int n = (GIT_DESCRIBE_DEFAULT) <= 0;
  *o = (unsigned long long)((GIT_DESCRIBE_DEFAULT) | 0);  /* check that GIT_DESCRIBE_DEFAULT is an integer */
  return n;
}

static int _cffi_const_GIT_DESCRIBE_TAGS(unsigned long long *o)
{
  int n = (GIT_DESCRIBE_TAGS) <= 0;
  *o = (unsigned long long)((GIT_DESCRIBE_TAGS) | 0);  /* check that GIT_DESCRIBE_TAGS is an integer */
  return n;
}

static int _cffi_const_GIT_DESCRIBE_ALL(unsigned long long *o)
{
  int n = (GIT_DESCRIBE_ALL) <= 0;
  *o = (unsigned long long)((GIT_DESCRIBE_ALL) | 0);  /* check that GIT_DESCRIBE_ALL is an integer */
  return n;
}

_CFFI_UNUSED_FN
static void _cffi_checkfld_typedef_git_diff_delta(git_diff_delta *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { git_delta_t *tmp = &p->status; (void)tmp; }
  (void)((p->flags) | 0);  /* check that 'git_diff_delta.flags' is an integer */
  (void)((p->similarity) | 0);  /* check that 'git_diff_delta.similarity' is an integer */
  (void)((p->nfiles) | 0);  /* check that 'git_diff_delta.nfiles' is an integer */
  { git_diff_file *tmp = &p->old_file; (void)tmp; }
  { git_diff_file *tmp = &p->new_file; (void)tmp; }
}
struct _cffi_align_typedef_git_diff_delta { char x; git_diff_delta y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld_typedef_git_diff_file(git_diff_file *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { git_oid *tmp = &p->id; (void)tmp; }
  { char const * *tmp = &p->path; (void)tmp; }
  (void)((p->size) | 0);  /* check that 'git_diff_file.size' is an integer */
  (void)((p->flags) | 0);  /* check that 'git_diff_file.flags' is an integer */
  (void)((p->mode) | 0);  /* check that 'git_diff_file.mode' is an integer */
  (void)((p->id_abbrev) | 0);  /* check that 'git_diff_file.id_abbrev' is an integer */
}
struct _cffi_align_typedef_git_diff_file { char x; git_diff_file y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld_typedef_git_diff_options(git_diff_options *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  (void)((p->version) | 0);  /* check that 'git_diff_options.version' is an integer */
  (void)((p->flags) | 0);  /* check that 'git_diff_options.flags' is an integer */
  { git_submodule_ignore_t *tmp = &p->ignore_submodules; (void)tmp; }
  { git_strarray *tmp = &p->pathspec; (void)tmp; }
  { int(* *tmp)(git_diff const *, git_diff_delta const *, char const *, void *) = &p->notify_cb; (void)tmp; }
  { int(* *tmp)(git_diff const *, char const *, char const *, void *) = &p->progress_cb; (void)tmp; }
  { void * *tmp = &p->payload; (void)tmp; }
  (void)((p->context_lines) | 0);  /* check that 'git_diff_options.context_lines' is an integer */
  (void)((p->interhunk_lines) | 0);  /* check that 'git_diff_options.interhunk_lines' is an integer */
  (void)((p->id_abbrev) | 0);  /* check that 'git_diff_options.id_abbrev' is an integer */
  (void)((p->max_size) | 0);  /* check that 'git_diff_options.max_size' is an integer */
  { char const * *tmp = &p->old_prefix; (void)tmp; }
  { char const * *tmp = &p->new_prefix; (void)tmp; }
}
struct _cffi_align_typedef_git_diff_options { char x; git_diff_options y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld_typedef_git_diff_similarity_metric(git_diff_similarity_metric *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { int(* *tmp)(void * *, git_diff_file const *, char const *, void *) = &p->file_signature; (void)tmp; }
  { int(* *tmp)(void * *, git_diff_file const *, char const *, size_t, void *) = &p->buffer_signature; (void)tmp; }
  { void(* *tmp)(void *, void *) = &p->free_signature; (void)tmp; }
  { int(* *tmp)(int *, void *, void *, void *) = &p->similarity; (void)tmp; }
  { void * *tmp = &p->payload; (void)tmp; }
}
struct _cffi_align_typedef_git_diff_similarity_metric { char x; git_diff_similarity_metric y; };

static int _cffi_const_GIT_DIRECTION_FETCH(unsigned long long *o)
{
  int n = (GIT_DIRECTION_FETCH) <= 0;
  *o = (unsigned long long)((GIT_DIRECTION_FETCH) | 0);  /* check that GIT_DIRECTION_FETCH is an integer */
  return n;
}

static int _cffi_const_GIT_DIRECTION_PUSH(unsigned long long *o)
{
  int n = (GIT_DIRECTION_PUSH) <= 0;
  *o = (unsigned long long)((GIT_DIRECTION_PUSH) | 0);  /* check that GIT_DIRECTION_PUSH is an integer */
  return n;
}

_CFFI_UNUSED_FN
static void _cffi_checkfld_typedef_git_error(git_error *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { char * *tmp = &p->message; (void)tmp; }
  (void)((p->klass) | 0);  /* check that 'git_error.klass' is an integer */
}
struct _cffi_align_typedef_git_error { char x; git_error y; };

static int _cffi_const_GIT_OK(unsigned long long *o)
{
  int n = (GIT_OK) <= 0;
  *o = (unsigned long long)((GIT_OK) | 0);  /* check that GIT_OK is an integer */
  return n;
}

static int _cffi_const_GIT_ERROR(unsigned long long *o)
{
  int n = (GIT_ERROR) <= 0;
  *o = (unsigned long long)((GIT_ERROR) | 0);  /* check that GIT_ERROR is an integer */
  return n;
}

static int _cffi_const_GIT_ENOTFOUND(unsigned long long *o)
{
  int n = (GIT_ENOTFOUND) <= 0;
  *o = (unsigned long long)((GIT_ENOTFOUND) | 0);  /* check that GIT_ENOTFOUND is an integer */
  return n;
}

static int _cffi_const_GIT_EEXISTS(unsigned long long *o)
{
  int n = (GIT_EEXISTS) <= 0;
  *o = (unsigned long long)((GIT_EEXISTS) | 0);  /* check that GIT_EEXISTS is an integer */
  return n;
}

static int _cffi_const_GIT_EAMBIGUOUS(unsigned long long *o)
{
  int n = (GIT_EAMBIGUOUS) <= 0;
  *o = (unsigned long long)((GIT_EAMBIGUOUS) | 0);  /* check that GIT_EAMBIGUOUS is an integer */
  return n;
}

static int _cffi_const_GIT_EBUFS(unsigned long long *o)
{
  int n = (GIT_EBUFS) <= 0;
  *o = (unsigned long long)((GIT_EBUFS) | 0);  /* check that GIT_EBUFS is an integer */
  return n;
}

static int _cffi_const_GIT_EUSER(unsigned long long *o)
{
  int n = (GIT_EUSER) <= 0;
  *o = (unsigned long long)((GIT_EUSER) | 0);  /* check that GIT_EUSER is an integer */
  return n;
}

static int _cffi_const_GIT_EBAREREPO(unsigned long long *o)
{
  int n = (GIT_EBAREREPO) <= 0;
  *o = (unsigned long long)((GIT_EBAREREPO) | 0);  /* check that GIT_EBAREREPO is an integer */
  return n;
}

static int _cffi_const_GIT_EUNBORNBRANCH(unsigned long long *o)
{
  int n = (GIT_EUNBORNBRANCH) <= 0;
  *o = (unsigned long long)((GIT_EUNBORNBRANCH) | 0);  /* check that GIT_EUNBORNBRANCH is an integer */
  return n;
}

static int _cffi_const_GIT_EUNMERGED(unsigned long long *o)
{
  int n = (GIT_EUNMERGED) <= 0;
  *o = (unsigned long long)((GIT_EUNMERGED) | 0);  /* check that GIT_EUNMERGED is an integer */
  return n;
}

static int _cffi_const_GIT_ENONFASTFORWARD(unsigned long long *o)
{
  int n = (GIT_ENONFASTFORWARD) <= 0;
  *o = (unsigned long long)((GIT_ENONFASTFORWARD) | 0);  /* check that GIT_ENONFASTFORWARD is an integer */
  return n;
}

static int _cffi_const_GIT_EINVALIDSPEC(unsigned long long *o)
{
  int n = (GIT_EINVALIDSPEC) <= 0;
  *o = (unsigned long long)((GIT_EINVALIDSPEC) | 0);  /* check that GIT_EINVALIDSPEC is an integer */
  return n;
}

static int _cffi_const_GIT_ECONFLICT(unsigned long long *o)
{
  int n = (GIT_ECONFLICT) <= 0;
  *o = (unsigned long long)((GIT_ECONFLICT) | 0);  /* check that GIT_ECONFLICT is an integer */
  return n;
}

static int _cffi_const_GIT_ELOCKED(unsigned long long *o)
{
  int n = (GIT_ELOCKED) <= 0;
  *o = (unsigned long long)((GIT_ELOCKED) | 0);  /* check that GIT_ELOCKED is an integer */
  return n;
}

static int _cffi_const_GIT_EMODIFIED(unsigned long long *o)
{
  int n = (GIT_EMODIFIED) <= 0;
  *o = (unsigned long long)((GIT_EMODIFIED) | 0);  /* check that GIT_EMODIFIED is an integer */
  return n;
}

static int _cffi_const_GIT_EAUTH(unsigned long long *o)
{
  int n = (GIT_EAUTH) <= 0;
  *o = (unsigned long long)((GIT_EAUTH) | 0);  /* check that GIT_EAUTH is an integer */
  return n;
}

static int _cffi_const_GIT_ECERTIFICATE(unsigned long long *o)
{
  int n = (GIT_ECERTIFICATE) <= 0;
  *o = (unsigned long long)((GIT_ECERTIFICATE) | 0);  /* check that GIT_ECERTIFICATE is an integer */
  return n;
}

static int _cffi_const_GIT_EAPPLIED(unsigned long long *o)
{
  int n = (GIT_EAPPLIED) <= 0;
  *o = (unsigned long long)((GIT_EAPPLIED) | 0);  /* check that GIT_EAPPLIED is an integer */
  return n;
}

static int _cffi_const_GIT_EPEEL(unsigned long long *o)
{
  int n = (GIT_EPEEL) <= 0;
  *o = (unsigned long long)((GIT_EPEEL) | 0);  /* check that GIT_EPEEL is an integer */
  return n;
}

static int _cffi_const_GIT_EEOF(unsigned long long *o)
{
  int n = (GIT_EEOF) <= 0;
  *o = (unsigned long long)((GIT_EEOF) | 0);  /* check that GIT_EEOF is an integer */
  return n;
}

static int _cffi_const_GIT_EINVALID(unsigned long long *o)
{
  int n = (GIT_EINVALID) <= 0;
  *o = (unsigned long long)((GIT_EINVALID) | 0);  /* check that GIT_EINVALID is an integer */
  return n;
}

static int _cffi_const_GIT_EUNCOMMITTED(unsigned long long *o)
{
  int n = (GIT_EUNCOMMITTED) <= 0;
  *o = (unsigned long long)((GIT_EUNCOMMITTED) | 0);  /* check that GIT_EUNCOMMITTED is an integer */
  return n;
}

static int _cffi_const_GIT_EDIRECTORY(unsigned long long *o)
{
  int n = (GIT_EDIRECTORY) <= 0;
  *o = (unsigned long long)((GIT_EDIRECTORY) | 0);  /* check that GIT_EDIRECTORY is an integer */
  return n;
}

static int _cffi_const_GIT_EMERGECONFLICT(unsigned long long *o)
{
  int n = (GIT_EMERGECONFLICT) <= 0;
  *o = (unsigned long long)((GIT_EMERGECONFLICT) | 0);  /* check that GIT_EMERGECONFLICT is an integer */
  return n;
}

static int _cffi_const_GIT_PASSTHROUGH(unsigned long long *o)
{
  int n = (GIT_PASSTHROUGH) <= 0;
  *o = (unsigned long long)((GIT_PASSTHROUGH) | 0);  /* check that GIT_PASSTHROUGH is an integer */
  return n;
}

static int _cffi_const_GIT_ITEROVER(unsigned long long *o)
{
  int n = (GIT_ITEROVER) <= 0;
  *o = (unsigned long long)((GIT_ITEROVER) | 0);  /* check that GIT_ITEROVER is an integer */
  return n;
}

static int _cffi_const_GIT_RETRY(unsigned long long *o)
{
  int n = (GIT_RETRY) <= 0;
  *o = (unsigned long long)((GIT_RETRY) | 0);  /* check that GIT_RETRY is an integer */
  return n;
}

static int _cffi_const_GIT_EMISMATCH(unsigned long long *o)
{
  int n = (GIT_EMISMATCH) <= 0;
  *o = (unsigned long long)((GIT_EMISMATCH) | 0);  /* check that GIT_EMISMATCH is an integer */
  return n;
}

static int _cffi_const_GIT_EINDEXDIRTY(unsigned long long *o)
{
  int n = (GIT_EINDEXDIRTY) <= 0;
  *o = (unsigned long long)((GIT_EINDEXDIRTY) | 0);  /* check that GIT_EINDEXDIRTY is an integer */
  return n;
}

static int _cffi_const_GIT_EAPPLYFAIL(unsigned long long *o)
{
  int n = (GIT_EAPPLYFAIL) <= 0;
  *o = (unsigned long long)((GIT_EAPPLYFAIL) | 0);  /* check that GIT_EAPPLYFAIL is an integer */
  return n;
}

static int _cffi_const_GIT_FEATURE_THREADS(unsigned long long *o)
{
  int n = (GIT_FEATURE_THREADS) <= 0;
  *o = (unsigned long long)((GIT_FEATURE_THREADS) | 0);  /* check that GIT_FEATURE_THREADS is an integer */
  return n;
}

static int _cffi_const_GIT_FEATURE_HTTPS(unsigned long long *o)
{
  int n = (GIT_FEATURE_HTTPS) <= 0;
  *o = (unsigned long long)((GIT_FEATURE_HTTPS) | 0);  /* check that GIT_FEATURE_HTTPS is an integer */
  return n;
}

static int _cffi_const_GIT_FEATURE_SSH(unsigned long long *o)
{
  int n = (GIT_FEATURE_SSH) <= 0;
  *o = (unsigned long long)((GIT_FEATURE_SSH) | 0);  /* check that GIT_FEATURE_SSH is an integer */
  return n;
}

static int _cffi_const_GIT_FEATURE_NSEC(unsigned long long *o)
{
  int n = (GIT_FEATURE_NSEC) <= 0;
  *o = (unsigned long long)((GIT_FEATURE_NSEC) | 0);  /* check that GIT_FEATURE_NSEC is an integer */
  return n;
}

_CFFI_UNUSED_FN
static void _cffi_checkfld_typedef_git_fetch_options(git_fetch_options *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  (void)((p->version) | 0);  /* check that 'git_fetch_options.version' is an integer */
  { git_remote_callbacks *tmp = &p->callbacks; (void)tmp; }
  { git_fetch_prune_t *tmp = &p->prune; (void)tmp; }
  (void)((p->update_fetchhead) | 0);  /* check that 'git_fetch_options.update_fetchhead' is an integer */
  { git_remote_autotag_option_t *tmp = &p->download_tags; (void)tmp; }
  { git_proxy_options *tmp = &p->proxy_opts; (void)tmp; }
  { git_strarray *tmp = &p->custom_headers; (void)tmp; }
}
struct _cffi_align_typedef_git_fetch_options { char x; git_fetch_options y; };

static int _cffi_const_GIT_FETCH_PRUNE_UNSPECIFIED(unsigned long long *o)
{
  int n = (GIT_FETCH_PRUNE_UNSPECIFIED) <= 0;
  *o = (unsigned long long)((GIT_FETCH_PRUNE_UNSPECIFIED) | 0);  /* check that GIT_FETCH_PRUNE_UNSPECIFIED is an integer */
  return n;
}

static int _cffi_const_GIT_FETCH_PRUNE(unsigned long long *o)
{
  int n = (GIT_FETCH_PRUNE) <= 0;
  *o = (unsigned long long)((GIT_FETCH_PRUNE) | 0);  /* check that GIT_FETCH_PRUNE is an integer */
  return n;
}

static int _cffi_const_GIT_FETCH_NO_PRUNE(unsigned long long *o)
{
  int n = (GIT_FETCH_NO_PRUNE) <= 0;
  *o = (unsigned long long)((GIT_FETCH_NO_PRUNE) | 0);  /* check that GIT_FETCH_NO_PRUNE is an integer */
  return n;
}

_CFFI_UNUSED_FN
static void _cffi_checkfld_typedef_git_index_time(git_index_time *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  (void)((p->seconds) | 0);  /* check that 'git_index_time.seconds' is an integer */
  (void)((p->nanoseconds) | 0);  /* check that 'git_index_time.nanoseconds' is an integer */
}
struct _cffi_align_typedef_git_index_time { char x; git_index_time y; };

static int _cffi_const_GIT_MERGE_FILE_FAVOR_NORMAL(unsigned long long *o)
{
  int n = (GIT_MERGE_FILE_FAVOR_NORMAL) <= 0;
  *o = (unsigned long long)((GIT_MERGE_FILE_FAVOR_NORMAL) | 0);  /* check that GIT_MERGE_FILE_FAVOR_NORMAL is an integer */
  return n;
}

static int _cffi_const_GIT_MERGE_FILE_FAVOR_OURS(unsigned long long *o)
{
  int n = (GIT_MERGE_FILE_FAVOR_OURS) <= 0;
  *o = (unsigned long long)((GIT_MERGE_FILE_FAVOR_OURS) | 0);  /* check that GIT_MERGE_FILE_FAVOR_OURS is an integer */
  return n;
}

static int _cffi_const_GIT_MERGE_FILE_FAVOR_THEIRS(unsigned long long *o)
{
  int n = (GIT_MERGE_FILE_FAVOR_THEIRS) <= 0;
  *o = (unsigned long long)((GIT_MERGE_FILE_FAVOR_THEIRS) | 0);  /* check that GIT_MERGE_FILE_FAVOR_THEIRS is an integer */
  return n;
}

static int _cffi_const_GIT_MERGE_FILE_FAVOR_UNION(unsigned long long *o)
{
  int n = (GIT_MERGE_FILE_FAVOR_UNION) <= 0;
  *o = (unsigned long long)((GIT_MERGE_FILE_FAVOR_UNION) | 0);  /* check that GIT_MERGE_FILE_FAVOR_UNION is an integer */
  return n;
}

static int _cffi_const_GIT_MERGE_FILE_DEFAULT(unsigned long long *o)
{
  int n = (GIT_MERGE_FILE_DEFAULT) <= 0;
  *o = (unsigned long long)((GIT_MERGE_FILE_DEFAULT) | 0);  /* check that GIT_MERGE_FILE_DEFAULT is an integer */
  return n;
}

static int _cffi_const_GIT_MERGE_FILE_STYLE_MERGE(unsigned long long *o)
{
  int n = (GIT_MERGE_FILE_STYLE_MERGE) <= 0;
  *o = (unsigned long long)((GIT_MERGE_FILE_STYLE_MERGE) | 0);  /* check that GIT_MERGE_FILE_STYLE_MERGE is an integer */
  return n;
}

static int _cffi_const_GIT_MERGE_FILE_STYLE_DIFF3(unsigned long long *o)
{
  int n = (GIT_MERGE_FILE_STYLE_DIFF3) <= 0;
  *o = (unsigned long long)((GIT_MERGE_FILE_STYLE_DIFF3) | 0);  /* check that GIT_MERGE_FILE_STYLE_DIFF3 is an integer */
  return n;
}

static int _cffi_const_GIT_MERGE_FILE_SIMPLIFY_ALNUM(unsigned long long *o)
{
  int n = (GIT_MERGE_FILE_SIMPLIFY_ALNUM) <= 0;
  *o = (unsigned long long)((GIT_MERGE_FILE_SIMPLIFY_ALNUM) | 0);  /* check that GIT_MERGE_FILE_SIMPLIFY_ALNUM is an integer */
  return n;
}

static int _cffi_const_GIT_MERGE_FILE_IGNORE_WHITESPACE(unsigned long long *o)
{
  int n = (GIT_MERGE_FILE_IGNORE_WHITESPACE) <= 0;
  *o = (unsigned long long)((GIT_MERGE_FILE_IGNORE_WHITESPACE) | 0);  /* check that GIT_MERGE_FILE_IGNORE_WHITESPACE is an integer */
  return n;
}

static int _cffi_const_GIT_MERGE_FILE_IGNORE_WHITESPACE_CHANGE(unsigned long long *o)
{
  int n = (GIT_MERGE_FILE_IGNORE_WHITESPACE_CHANGE) <= 0;
  *o = (unsigned long long)((GIT_MERGE_FILE_IGNORE_WHITESPACE_CHANGE) | 0);  /* check that GIT_MERGE_FILE_IGNORE_WHITESPACE_CHANGE is an integer */
  return n;
}

static int _cffi_const_GIT_MERGE_FILE_IGNORE_WHITESPACE_EOL(unsigned long long *o)
{
  int n = (GIT_MERGE_FILE_IGNORE_WHITESPACE_EOL) <= 0;
  *o = (unsigned long long)((GIT_MERGE_FILE_IGNORE_WHITESPACE_EOL) | 0);  /* check that GIT_MERGE_FILE_IGNORE_WHITESPACE_EOL is an integer */
  return n;
}

static int _cffi_const_GIT_MERGE_FILE_DIFF_PATIENCE(unsigned long long *o)
{
  int n = (GIT_MERGE_FILE_DIFF_PATIENCE) <= 0;
  *o = (unsigned long long)((GIT_MERGE_FILE_DIFF_PATIENCE) | 0);  /* check that GIT_MERGE_FILE_DIFF_PATIENCE is an integer */
  return n;
}

static int _cffi_const_GIT_MERGE_FILE_DIFF_MINIMAL(unsigned long long *o)
{
  int n = (GIT_MERGE_FILE_DIFF_MINIMAL) <= 0;
  *o = (unsigned long long)((GIT_MERGE_FILE_DIFF_MINIMAL) | 0);  /* check that GIT_MERGE_FILE_DIFF_MINIMAL is an integer */
  return n;
}

_CFFI_UNUSED_FN
static void _cffi_checkfld_typedef_git_merge_file_options(git_merge_file_options *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  (void)((p->version) | 0);  /* check that 'git_merge_file_options.version' is an integer */
  { char const * *tmp = &p->ancestor_label; (void)tmp; }
  { char const * *tmp = &p->our_label; (void)tmp; }
  { char const * *tmp = &p->their_label; (void)tmp; }
  { git_merge_file_favor_t *tmp = &p->favor; (void)tmp; }
  { git_merge_file_flag_t *tmp = &p->flags; (void)tmp; }
  (void)((p->marker_size) | 0);  /* check that 'git_merge_file_options.marker_size' is an integer */
}
struct _cffi_align_typedef_git_merge_file_options { char x; git_merge_file_options y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld_typedef_git_merge_file_result(git_merge_file_result *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  (void)((p->automergeable) | 0);  /* check that 'git_merge_file_result.automergeable' is an integer */
  { char const * *tmp = &p->path; (void)tmp; }
  (void)((p->mode) | 0);  /* check that 'git_merge_file_result.mode' is an integer */
  { char const * *tmp = &p->ptr; (void)tmp; }
  (void)((p->len) | 0);  /* check that 'git_merge_file_result.len' is an integer */
}
struct _cffi_align_typedef_git_merge_file_result { char x; git_merge_file_result y; };

static int _cffi_const_GIT_MERGE_FIND_RENAMES(unsigned long long *o)
{
  int n = (GIT_MERGE_FIND_RENAMES) <= 0;
  *o = (unsigned long long)((GIT_MERGE_FIND_RENAMES) | 0);  /* check that GIT_MERGE_FIND_RENAMES is an integer */
  return n;
}

static int _cffi_const_GIT_MERGE_FAIL_ON_CONFLICT(unsigned long long *o)
{
  int n = (GIT_MERGE_FAIL_ON_CONFLICT) <= 0;
  *o = (unsigned long long)((GIT_MERGE_FAIL_ON_CONFLICT) | 0);  /* check that GIT_MERGE_FAIL_ON_CONFLICT is an integer */
  return n;
}

static int _cffi_const_GIT_MERGE_SKIP_REUC(unsigned long long *o)
{
  int n = (GIT_MERGE_SKIP_REUC) <= 0;
  *o = (unsigned long long)((GIT_MERGE_SKIP_REUC) | 0);  /* check that GIT_MERGE_SKIP_REUC is an integer */
  return n;
}

static int _cffi_const_GIT_MERGE_NO_RECURSIVE(unsigned long long *o)
{
  int n = (GIT_MERGE_NO_RECURSIVE) <= 0;
  *o = (unsigned long long)((GIT_MERGE_NO_RECURSIVE) | 0);  /* check that GIT_MERGE_NO_RECURSIVE is an integer */
  return n;
}

_CFFI_UNUSED_FN
static void _cffi_checkfld_typedef_git_merge_options(git_merge_options *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  (void)((p->version) | 0);  /* check that 'git_merge_options.version' is an integer */
  { git_merge_flag_t *tmp = &p->flags; (void)tmp; }
  (void)((p->rename_threshold) | 0);  /* check that 'git_merge_options.rename_threshold' is an integer */
  (void)((p->target_limit) | 0);  /* check that 'git_merge_options.target_limit' is an integer */
  { git_diff_similarity_metric * *tmp = &p->metric; (void)tmp; }
  (void)((p->recursion_limit) | 0);  /* check that 'git_merge_options.recursion_limit' is an integer */
  { char const * *tmp = &p->default_driver; (void)tmp; }
  { git_merge_file_favor_t *tmp = &p->file_favor; (void)tmp; }
  { git_merge_file_flag_t *tmp = &p->file_flags; (void)tmp; }
}
struct _cffi_align_typedef_git_merge_options { char x; git_merge_options y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld_typedef_git_proxy_options(git_proxy_options *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  (void)((p->version) | 0);  /* check that 'git_proxy_options.version' is an integer */
  { git_proxy_t *tmp = &p->type; (void)tmp; }
  { char const * *tmp = &p->url; (void)tmp; }
  { int(* *tmp)(git_cred * *, char const *, char const *, unsigned int, void *) = &p->credentials; (void)tmp; }
  { int(* *tmp)(git_cert *, int, char const *, void *) = &p->certificate_check; (void)tmp; }
  { void * *tmp = &p->payload; (void)tmp; }
}
struct _cffi_align_typedef_git_proxy_options { char x; git_proxy_options y; };

static int _cffi_const_GIT_PROXY_NONE(unsigned long long *o)
{
  int n = (GIT_PROXY_NONE) <= 0;
  *o = (unsigned long long)((GIT_PROXY_NONE) | 0);  /* check that GIT_PROXY_NONE is an integer */
  return n;
}

static int _cffi_const_GIT_PROXY_AUTO(unsigned long long *o)
{
  int n = (GIT_PROXY_AUTO) <= 0;
  *o = (unsigned long long)((GIT_PROXY_AUTO) | 0);  /* check that GIT_PROXY_AUTO is an integer */
  return n;
}

static int _cffi_const_GIT_PROXY_SPECIFIED(unsigned long long *o)
{
  int n = (GIT_PROXY_SPECIFIED) <= 0;
  *o = (unsigned long long)((GIT_PROXY_SPECIFIED) | 0);  /* check that GIT_PROXY_SPECIFIED is an integer */
  return n;
}

_CFFI_UNUSED_FN
static void _cffi_checkfld_typedef_git_push_options(git_push_options *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  (void)((p->version) | 0);  /* check that 'git_push_options.version' is an integer */
  (void)((p->pb_parallelism) | 0);  /* check that 'git_push_options.pb_parallelism' is an integer */
  { git_remote_callbacks *tmp = &p->callbacks; (void)tmp; }
  { git_proxy_options *tmp = &p->proxy_opts; (void)tmp; }
  { git_strarray *tmp = &p->custom_headers; (void)tmp; }
}
struct _cffi_align_typedef_git_push_options { char x; git_push_options y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld_typedef_git_push_update(git_push_update *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { char * *tmp = &p->src_refname; (void)tmp; }
  { char * *tmp = &p->dst_refname; (void)tmp; }
  { git_oid *tmp = &p->src; (void)tmp; }
  { git_oid *tmp = &p->dst; (void)tmp; }
}
struct _cffi_align_typedef_git_push_update { char x; git_push_update y; };

static int _cffi_const_GIT_REFERENCE_INVALID(unsigned long long *o)
{
  int n = (GIT_REFERENCE_INVALID) <= 0;
  *o = (unsigned long long)((GIT_REFERENCE_INVALID) | 0);  /* check that GIT_REFERENCE_INVALID is an integer */
  return n;
}

static int _cffi_const_GIT_REFERENCE_DIRECT(unsigned long long *o)
{
  int n = (GIT_REFERENCE_DIRECT) <= 0;
  *o = (unsigned long long)((GIT_REFERENCE_DIRECT) | 0);  /* check that GIT_REFERENCE_DIRECT is an integer */
  return n;
}

static int _cffi_const_GIT_REFERENCE_SYMBOLIC(unsigned long long *o)
{
  int n = (GIT_REFERENCE_SYMBOLIC) <= 0;
  *o = (unsigned long long)((GIT_REFERENCE_SYMBOLIC) | 0);  /* check that GIT_REFERENCE_SYMBOLIC is an integer */
  return n;
}

static int _cffi_const_GIT_REFERENCE_ALL(unsigned long long *o)
{
  int n = (GIT_REFERENCE_ALL) <= 0;
  *o = (unsigned long long)((GIT_REFERENCE_ALL) | 0);  /* check that GIT_REFERENCE_ALL is an integer */
  return n;
}

static int _cffi_const_GIT_REMOTE_DOWNLOAD_TAGS_UNSPECIFIED(unsigned long long *o)
{
  int n = (GIT_REMOTE_DOWNLOAD_TAGS_UNSPECIFIED) <= 0;
  *o = (unsigned long long)((GIT_REMOTE_DOWNLOAD_TAGS_UNSPECIFIED) | 0);  /* check that GIT_REMOTE_DOWNLOAD_TAGS_UNSPECIFIED is an integer */
  return n;
}

static int _cffi_const_GIT_REMOTE_DOWNLOAD_TAGS_AUTO(unsigned long long *o)
{
  int n = (GIT_REMOTE_DOWNLOAD_TAGS_AUTO) <= 0;
  *o = (unsigned long long)((GIT_REMOTE_DOWNLOAD_TAGS_AUTO) | 0);  /* check that GIT_REMOTE_DOWNLOAD_TAGS_AUTO is an integer */
  return n;
}

static int _cffi_const_GIT_REMOTE_DOWNLOAD_TAGS_NONE(unsigned long long *o)
{
  int n = (GIT_REMOTE_DOWNLOAD_TAGS_NONE) <= 0;
  *o = (unsigned long long)((GIT_REMOTE_DOWNLOAD_TAGS_NONE) | 0);  /* check that GIT_REMOTE_DOWNLOAD_TAGS_NONE is an integer */
  return n;
}

static int _cffi_const_GIT_REMOTE_DOWNLOAD_TAGS_ALL(unsigned long long *o)
{
  int n = (GIT_REMOTE_DOWNLOAD_TAGS_ALL) <= 0;
  *o = (unsigned long long)((GIT_REMOTE_DOWNLOAD_TAGS_ALL) | 0);  /* check that GIT_REMOTE_DOWNLOAD_TAGS_ALL is an integer */
  return n;
}

static int _cffi_const_GIT_REPOSITORY_INIT_BARE(unsigned long long *o)
{
  int n = (GIT_REPOSITORY_INIT_BARE) <= 0;
  *o = (unsigned long long)((GIT_REPOSITORY_INIT_BARE) | 0);  /* check that GIT_REPOSITORY_INIT_BARE is an integer */
  return n;
}

static int _cffi_const_GIT_REPOSITORY_INIT_NO_REINIT(unsigned long long *o)
{
  int n = (GIT_REPOSITORY_INIT_NO_REINIT) <= 0;
  *o = (unsigned long long)((GIT_REPOSITORY_INIT_NO_REINIT) | 0);  /* check that GIT_REPOSITORY_INIT_NO_REINIT is an integer */
  return n;
}

static int _cffi_const_GIT_REPOSITORY_INIT_NO_DOTGIT_DIR(unsigned long long *o)
{
  int n = (GIT_REPOSITORY_INIT_NO_DOTGIT_DIR) <= 0;
  *o = (unsigned long long)((GIT_REPOSITORY_INIT_NO_DOTGIT_DIR) | 0);  /* check that GIT_REPOSITORY_INIT_NO_DOTGIT_DIR is an integer */
  return n;
}

static int _cffi_const_GIT_REPOSITORY_INIT_MKDIR(unsigned long long *o)
{
  int n = (GIT_REPOSITORY_INIT_MKDIR) <= 0;
  *o = (unsigned long long)((GIT_REPOSITORY_INIT_MKDIR) | 0);  /* check that GIT_REPOSITORY_INIT_MKDIR is an integer */
  return n;
}

static int _cffi_const_GIT_REPOSITORY_INIT_MKPATH(unsigned long long *o)
{
  int n = (GIT_REPOSITORY_INIT_MKPATH) <= 0;
  *o = (unsigned long long)((GIT_REPOSITORY_INIT_MKPATH) | 0);  /* check that GIT_REPOSITORY_INIT_MKPATH is an integer */
  return n;
}

static int _cffi_const_GIT_REPOSITORY_INIT_EXTERNAL_TEMPLATE(unsigned long long *o)
{
  int n = (GIT_REPOSITORY_INIT_EXTERNAL_TEMPLATE) <= 0;
  *o = (unsigned long long)((GIT_REPOSITORY_INIT_EXTERNAL_TEMPLATE) | 0);  /* check that GIT_REPOSITORY_INIT_EXTERNAL_TEMPLATE is an integer */
  return n;
}

static int _cffi_const_GIT_REPOSITORY_INIT_RELATIVE_GITLINK(unsigned long long *o)
{
  int n = (GIT_REPOSITORY_INIT_RELATIVE_GITLINK) <= 0;
  *o = (unsigned long long)((GIT_REPOSITORY_INIT_RELATIVE_GITLINK) | 0);  /* check that GIT_REPOSITORY_INIT_RELATIVE_GITLINK is an integer */
  return n;
}

static int _cffi_const_GIT_REPOSITORY_INIT_SHARED_UMASK(unsigned long long *o)
{
  int n = (GIT_REPOSITORY_INIT_SHARED_UMASK) <= 0;
  *o = (unsigned long long)((GIT_REPOSITORY_INIT_SHARED_UMASK) | 0);  /* check that GIT_REPOSITORY_INIT_SHARED_UMASK is an integer */
  return n;
}

static int _cffi_const_GIT_REPOSITORY_INIT_SHARED_GROUP(unsigned long long *o)
{
  int n = (GIT_REPOSITORY_INIT_SHARED_GROUP) <= 0;
  *o = (unsigned long long)((GIT_REPOSITORY_INIT_SHARED_GROUP) | 0);  /* check that GIT_REPOSITORY_INIT_SHARED_GROUP is an integer */
  return n;
}

static int _cffi_const_GIT_REPOSITORY_INIT_SHARED_ALL(unsigned long long *o)
{
  int n = (GIT_REPOSITORY_INIT_SHARED_ALL) <= 0;
  *o = (unsigned long long)((GIT_REPOSITORY_INIT_SHARED_ALL) | 0);  /* check that GIT_REPOSITORY_INIT_SHARED_ALL is an integer */
  return n;
}

_CFFI_UNUSED_FN
static void _cffi_checkfld_typedef_git_repository_init_options(git_repository_init_options *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  (void)((p->version) | 0);  /* check that 'git_repository_init_options.version' is an integer */
  (void)((p->flags) | 0);  /* check that 'git_repository_init_options.flags' is an integer */
  (void)((p->mode) | 0);  /* check that 'git_repository_init_options.mode' is an integer */
  { char const * *tmp = &p->workdir_path; (void)tmp; }
  { char const * *tmp = &p->description; (void)tmp; }
  { char const * *tmp = &p->template_path; (void)tmp; }
  { char const * *tmp = &p->initial_head; (void)tmp; }
  { char const * *tmp = &p->origin_url; (void)tmp; }
}
struct _cffi_align_typedef_git_repository_init_options { char x; git_repository_init_options y; };

static int _cffi_const_GIT_STASH_APPLY_DEFAULT(unsigned long long *o)
{
  int n = (GIT_STASH_APPLY_DEFAULT) <= 0;
  *o = (unsigned long long)((GIT_STASH_APPLY_DEFAULT) | 0);  /* check that GIT_STASH_APPLY_DEFAULT is an integer */
  return n;
}

static int _cffi_const_GIT_STASH_APPLY_REINSTATE_INDEX(unsigned long long *o)
{
  int n = (GIT_STASH_APPLY_REINSTATE_INDEX) <= 0;
  *o = (unsigned long long)((GIT_STASH_APPLY_REINSTATE_INDEX) | 0);  /* check that GIT_STASH_APPLY_REINSTATE_INDEX is an integer */
  return n;
}

static int _cffi_const_GIT_STASH_APPLY_PROGRESS_NONE(unsigned long long *o)
{
  int n = (GIT_STASH_APPLY_PROGRESS_NONE) <= 0;
  *o = (unsigned long long)((GIT_STASH_APPLY_PROGRESS_NONE) | 0);  /* check that GIT_STASH_APPLY_PROGRESS_NONE is an integer */
  return n;
}

static int _cffi_const_GIT_STASH_APPLY_PROGRESS_LOADING_STASH(unsigned long long *o)
{
  int n = (GIT_STASH_APPLY_PROGRESS_LOADING_STASH) <= 0;
  *o = (unsigned long long)((GIT_STASH_APPLY_PROGRESS_LOADING_STASH) | 0);  /* check that GIT_STASH_APPLY_PROGRESS_LOADING_STASH is an integer */
  return n;
}

static int _cffi_const_GIT_STASH_APPLY_PROGRESS_ANALYZE_INDEX(unsigned long long *o)
{
  int n = (GIT_STASH_APPLY_PROGRESS_ANALYZE_INDEX) <= 0;
  *o = (unsigned long long)((GIT_STASH_APPLY_PROGRESS_ANALYZE_INDEX) | 0);  /* check that GIT_STASH_APPLY_PROGRESS_ANALYZE_INDEX is an integer */
  return n;
}

static int _cffi_const_GIT_STASH_APPLY_PROGRESS_ANALYZE_MODIFIED(unsigned long long *o)
{
  int n = (GIT_STASH_APPLY_PROGRESS_ANALYZE_MODIFIED) <= 0;
  *o = (unsigned long long)((GIT_STASH_APPLY_PROGRESS_ANALYZE_MODIFIED) | 0);  /* check that GIT_STASH_APPLY_PROGRESS_ANALYZE_MODIFIED is an integer */
  return n;
}

static int _cffi_const_GIT_STASH_APPLY_PROGRESS_ANALYZE_UNTRACKED(unsigned long long *o)
{
  int n = (GIT_STASH_APPLY_PROGRESS_ANALYZE_UNTRACKED) <= 0;
  *o = (unsigned long long)((GIT_STASH_APPLY_PROGRESS_ANALYZE_UNTRACKED) | 0);  /* check that GIT_STASH_APPLY_PROGRESS_ANALYZE_UNTRACKED is an integer */
  return n;
}

static int _cffi_const_GIT_STASH_APPLY_PROGRESS_CHECKOUT_UNTRACKED(unsigned long long *o)
{
  int n = (GIT_STASH_APPLY_PROGRESS_CHECKOUT_UNTRACKED) <= 0;
  *o = (unsigned long long)((GIT_STASH_APPLY_PROGRESS_CHECKOUT_UNTRACKED) | 0);  /* check that GIT_STASH_APPLY_PROGRESS_CHECKOUT_UNTRACKED is an integer */
  return n;
}

static int _cffi_const_GIT_STASH_APPLY_PROGRESS_CHECKOUT_MODIFIED(unsigned long long *o)
{
  int n = (GIT_STASH_APPLY_PROGRESS_CHECKOUT_MODIFIED) <= 0;
  *o = (unsigned long long)((GIT_STASH_APPLY_PROGRESS_CHECKOUT_MODIFIED) | 0);  /* check that GIT_STASH_APPLY_PROGRESS_CHECKOUT_MODIFIED is an integer */
  return n;
}

static int _cffi_const_GIT_STASH_APPLY_PROGRESS_DONE(unsigned long long *o)
{
  int n = (GIT_STASH_APPLY_PROGRESS_DONE) <= 0;
  *o = (unsigned long long)((GIT_STASH_APPLY_PROGRESS_DONE) | 0);  /* check that GIT_STASH_APPLY_PROGRESS_DONE is an integer */
  return n;
}

static int _cffi_const_GIT_STASH_DEFAULT(unsigned long long *o)
{
  int n = (GIT_STASH_DEFAULT) <= 0;
  *o = (unsigned long long)((GIT_STASH_DEFAULT) | 0);  /* check that GIT_STASH_DEFAULT is an integer */
  return n;
}

static int _cffi_const_GIT_STASH_KEEP_INDEX(unsigned long long *o)
{
  int n = (GIT_STASH_KEEP_INDEX) <= 0;
  *o = (unsigned long long)((GIT_STASH_KEEP_INDEX) | 0);  /* check that GIT_STASH_KEEP_INDEX is an integer */
  return n;
}

static int _cffi_const_GIT_STASH_INCLUDE_UNTRACKED(unsigned long long *o)
{
  int n = (GIT_STASH_INCLUDE_UNTRACKED) <= 0;
  *o = (unsigned long long)((GIT_STASH_INCLUDE_UNTRACKED) | 0);  /* check that GIT_STASH_INCLUDE_UNTRACKED is an integer */
  return n;
}

static int _cffi_const_GIT_STASH_INCLUDE_IGNORED(unsigned long long *o)
{
  int n = (GIT_STASH_INCLUDE_IGNORED) <= 0;
  *o = (unsigned long long)((GIT_STASH_INCLUDE_IGNORED) | 0);  /* check that GIT_STASH_INCLUDE_IGNORED is an integer */
  return n;
}

static int _cffi_const_GIT_SUBMODULE_IGNORE_UNSPECIFIED(unsigned long long *o)
{
  int n = (GIT_SUBMODULE_IGNORE_UNSPECIFIED) <= 0;
  *o = (unsigned long long)((GIT_SUBMODULE_IGNORE_UNSPECIFIED) | 0);  /* check that GIT_SUBMODULE_IGNORE_UNSPECIFIED is an integer */
  return n;
}

static int _cffi_const_GIT_SUBMODULE_IGNORE_NONE(unsigned long long *o)
{
  int n = (GIT_SUBMODULE_IGNORE_NONE) <= 0;
  *o = (unsigned long long)((GIT_SUBMODULE_IGNORE_NONE) | 0);  /* check that GIT_SUBMODULE_IGNORE_NONE is an integer */
  return n;
}

static int _cffi_const_GIT_SUBMODULE_IGNORE_UNTRACKED(unsigned long long *o)
{
  int n = (GIT_SUBMODULE_IGNORE_UNTRACKED) <= 0;
  *o = (unsigned long long)((GIT_SUBMODULE_IGNORE_UNTRACKED) | 0);  /* check that GIT_SUBMODULE_IGNORE_UNTRACKED is an integer */
  return n;
}

static int _cffi_const_GIT_SUBMODULE_IGNORE_DIRTY(unsigned long long *o)
{
  int n = (GIT_SUBMODULE_IGNORE_DIRTY) <= 0;
  *o = (unsigned long long)((GIT_SUBMODULE_IGNORE_DIRTY) | 0);  /* check that GIT_SUBMODULE_IGNORE_DIRTY is an integer */
  return n;
}

static int _cffi_const_GIT_SUBMODULE_IGNORE_ALL(unsigned long long *o)
{
  int n = (GIT_SUBMODULE_IGNORE_ALL) <= 0;
  *o = (unsigned long long)((GIT_SUBMODULE_IGNORE_ALL) | 0);  /* check that GIT_SUBMODULE_IGNORE_ALL is an integer */
  return n;
}

static int _cffi_const_GIT_CERT_NONE(unsigned long long *o)
{
  int n = (GIT_CERT_NONE) <= 0;
  *o = (unsigned long long)((GIT_CERT_NONE) | 0);  /* check that GIT_CERT_NONE is an integer */
  return n;
}

static int _cffi_const_GIT_CERT_X509(unsigned long long *o)
{
  int n = (GIT_CERT_X509) <= 0;
  *o = (unsigned long long)((GIT_CERT_X509) | 0);  /* check that GIT_CERT_X509 is an integer */
  return n;
}

static int _cffi_const_GIT_CERT_HOSTKEY_LIBSSH2(unsigned long long *o)
{
  int n = (GIT_CERT_HOSTKEY_LIBSSH2) <= 0;
  *o = (unsigned long long)((GIT_CERT_HOSTKEY_LIBSSH2) | 0);  /* check that GIT_CERT_HOSTKEY_LIBSSH2 is an integer */
  return n;
}

static int _cffi_const_GIT_CERT_STRARRAY(unsigned long long *o)
{
  int n = (GIT_CERT_STRARRAY) <= 0;
  *o = (unsigned long long)((GIT_CERT_STRARRAY) | 0);  /* check that GIT_CERT_STRARRAY is an integer */
  return n;
}

static int _cffi_const_GIT_REMOTE_COMPLETION_DOWNLOAD(unsigned long long *o)
{
  int n = (GIT_REMOTE_COMPLETION_DOWNLOAD) <= 0;
  *o = (unsigned long long)((GIT_REMOTE_COMPLETION_DOWNLOAD) | 0);  /* check that GIT_REMOTE_COMPLETION_DOWNLOAD is an integer */
  return n;
}

static int _cffi_const_GIT_REMOTE_COMPLETION_INDEXING(unsigned long long *o)
{
  int n = (GIT_REMOTE_COMPLETION_INDEXING) <= 0;
  *o = (unsigned long long)((GIT_REMOTE_COMPLETION_INDEXING) | 0);  /* check that GIT_REMOTE_COMPLETION_INDEXING is an integer */
  return n;
}

static int _cffi_const_GIT_REMOTE_COMPLETION_ERROR(unsigned long long *o)
{
  int n = (GIT_REMOTE_COMPLETION_ERROR) <= 0;
  *o = (unsigned long long)((GIT_REMOTE_COMPLETION_ERROR) | 0);  /* check that GIT_REMOTE_COMPLETION_ERROR is an integer */
  return n;
}

static int _cffi_d_git_attr_get(char const * * x0, git_repository * x1, uint32_t x2, char const * x3, char const * x4)
{
  return git_attr_get(x0, x1, x2, x3, x4);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_attr_get(PyObject *self, PyObject *args)
{
  char const * * x0;
  git_repository * x1;
  uint32_t x2;
  char const * x3;
  char const * x4;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;

  if (!PyArg_UnpackTuple(args, "git_attr_get", 5, 5, &arg0, &arg1, &arg2, &arg3, &arg4))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(45), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (char const * *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(45), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(56), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (git_repository *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(56), arg1) < 0)
      return NULL;
  }

  x2 = _cffi_to_c_int(arg2, uint32_t);
  if (x2 == (uint32_t)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg3, (char **)&x3);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x3 = (char const *)alloca((size_t)datasize);
    memset((void *)x3, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x3, _cffi_type(10), arg3) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg4, (char **)&x4);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x4 = (char const *)alloca((size_t)datasize);
    memset((void *)x4, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x4, _cffi_type(10), arg4) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_attr_get(x0, x1, x2, x3, x4); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_attr_get _cffi_d_git_attr_get
#endif

static git_attr_t _cffi_d_git_attr_value(char const * x0)
{
  return git_attr_value(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_attr_value(PyObject *self, PyObject *arg0)
{
  char const * x0;
  Py_ssize_t datasize;
  git_attr_t result;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (char const *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(10), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_attr_value(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_deref((char *)&result, _cffi_type(683));
}
#else
#  define _cffi_f_git_attr_value _cffi_d_git_attr_value
#endif

static int _cffi_d_git_blame_file(git_blame * * x0, git_repository * x1, char const * x2, git_blame_options * x3)
{
  return git_blame_file(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_blame_file(PyObject *self, PyObject *args)
{
  git_blame * * x0;
  git_repository * x1;
  char const * x2;
  git_blame_options * x3;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "git_blame_file", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(78), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_blame * *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(78), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(56), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (git_repository *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(56), arg1) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg2, (char **)&x2);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x2 = (char const *)alloca((size_t)datasize);
    memset((void *)x2, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x2, _cffi_type(10), arg2) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(81), arg3, (char **)&x3);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x3 = (git_blame_options *)alloca((size_t)datasize);
    memset((void *)x3, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x3, _cffi_type(81), arg3) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_blame_file(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_blame_file _cffi_d_git_blame_file
#endif

static void _cffi_d_git_blame_free(git_blame * x0)
{
  git_blame_free(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_blame_free(PyObject *self, PyObject *arg0)
{
  git_blame * x0;
  Py_ssize_t datasize;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(13), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_blame *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(13), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { git_blame_free(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_git_blame_free _cffi_d_git_blame_free
#endif

static git_blame_hunk const * _cffi_d_git_blame_get_hunk_byindex(git_blame * x0, uint32_t x1)
{
  return git_blame_get_hunk_byindex(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_blame_get_hunk_byindex(PyObject *self, PyObject *args)
{
  git_blame * x0;
  uint32_t x1;
  Py_ssize_t datasize;
  git_blame_hunk const * result;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "git_blame_get_hunk_byindex", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(13), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_blame *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(13), arg0) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, uint32_t);
  if (x1 == (uint32_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_blame_get_hunk_byindex(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_pointer((char *)result, _cffi_type(685));
}
#else
#  define _cffi_f_git_blame_get_hunk_byindex _cffi_d_git_blame_get_hunk_byindex
#endif

static git_blame_hunk const * _cffi_d_git_blame_get_hunk_byline(git_blame * x0, size_t x1)
{
  return git_blame_get_hunk_byline(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_blame_get_hunk_byline(PyObject *self, PyObject *args)
{
  git_blame * x0;
  size_t x1;
  Py_ssize_t datasize;
  git_blame_hunk const * result;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "git_blame_get_hunk_byline", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(13), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_blame *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(13), arg0) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, size_t);
  if (x1 == (size_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_blame_get_hunk_byline(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_pointer((char *)result, _cffi_type(685));
}
#else
#  define _cffi_f_git_blame_get_hunk_byline _cffi_d_git_blame_get_hunk_byline
#endif

static uint32_t _cffi_d_git_blame_get_hunk_count(git_blame * x0)
{
  return git_blame_get_hunk_count(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_blame_get_hunk_count(PyObject *self, PyObject *arg0)
{
  git_blame * x0;
  Py_ssize_t datasize;
  uint32_t result;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(13), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_blame *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(13), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_blame_get_hunk_count(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, uint32_t);
}
#else
#  define _cffi_f_git_blame_get_hunk_count _cffi_d_git_blame_get_hunk_count
#endif

static int _cffi_d_git_blame_init_options(git_blame_options * x0, unsigned int x1)
{
  return git_blame_init_options(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_blame_init_options(PyObject *self, PyObject *args)
{
  git_blame_options * x0;
  unsigned int x1;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "git_blame_init_options", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(81), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_blame_options *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(81), arg0) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, unsigned int);
  if (x1 == (unsigned int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_blame_init_options(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_blame_init_options _cffi_d_git_blame_init_options
#endif

static void _cffi_d_git_buf_dispose(git_buf * x0)
{
  git_buf_dispose(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_buf_dispose(PyObject *self, PyObject *arg0)
{
  git_buf * x0;
  Py_ssize_t datasize;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(88), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_buf *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(88), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { git_buf_dispose(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_git_buf_dispose _cffi_d_git_buf_dispose
#endif

static int _cffi_d_git_checkout_head(git_repository * x0, git_checkout_options const * x1)
{
  return git_checkout_head(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_checkout_head(PyObject *self, PyObject *args)
{
  git_repository * x0;
  git_checkout_options const * x1;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "git_checkout_head", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(56), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_repository *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(56), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(480), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (git_checkout_options const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(480), arg1) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_checkout_head(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_checkout_head _cffi_d_git_checkout_head
#endif

static int _cffi_d_git_checkout_index(git_repository * x0, git_index * x1, git_checkout_options const * x2)
{
  return git_checkout_index(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_checkout_index(PyObject *self, PyObject *args)
{
  git_repository * x0;
  git_index * x1;
  git_checkout_options const * x2;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "git_checkout_index", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(56), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_repository *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(56), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(26), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (git_index *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(26), arg1) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(480), arg2, (char **)&x2);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x2 = (git_checkout_options const *)alloca((size_t)datasize);
    memset((void *)x2, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x2, _cffi_type(480), arg2) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_checkout_index(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_checkout_index _cffi_d_git_checkout_index
#endif

static int _cffi_d_git_checkout_init_options(git_checkout_options * x0, unsigned int x1)
{
  return git_checkout_init_options(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_checkout_init_options(PyObject *self, PyObject *args)
{
  git_checkout_options * x0;
  unsigned int x1;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "git_checkout_init_options", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(115), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_checkout_options *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(115), arg0) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, unsigned int);
  if (x1 == (unsigned int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_checkout_init_options(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_checkout_init_options _cffi_d_git_checkout_init_options
#endif

static int _cffi_d_git_checkout_tree(git_repository * x0, git_object const * x1, git_checkout_options const * x2)
{
  return git_checkout_tree(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_checkout_tree(PyObject *self, PyObject *args)
{
  git_repository * x0;
  git_object const * x1;
  git_checkout_options const * x2;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "git_checkout_tree", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(56), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_repository *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(56), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(489), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (git_object const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(489), arg1) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(480), arg2, (char **)&x2);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x2 = (git_checkout_options const *)alloca((size_t)datasize);
    memset((void *)x2, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x2, _cffi_type(480), arg2) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_checkout_tree(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_checkout_tree _cffi_d_git_checkout_tree
#endif

static int _cffi_d_git_clone(git_repository * * x0, char const * x1, char const * x2, git_clone_options const * x3)
{
  return git_clone(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_clone(PyObject *self, PyObject *args)
{
  git_repository * * x0;
  char const * x1;
  char const * x2;
  git_clone_options const * x3;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "git_clone", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(441), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_repository * *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(441), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (char const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(10), arg1) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg2, (char **)&x2);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x2 = (char const *)alloca((size_t)datasize);
    memset((void *)x2, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x2, _cffi_type(10), arg2) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(444), arg3, (char **)&x3);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x3 = (git_clone_options const *)alloca((size_t)datasize);
    memset((void *)x3, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x3, _cffi_type(444), arg3) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_clone(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_clone _cffi_d_git_clone
#endif

static int _cffi_d_git_clone_init_options(git_clone_options * x0, unsigned int x1)
{
  return git_clone_init_options(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_clone_init_options(PyObject *self, PyObject *args)
{
  git_clone_options * x0;
  unsigned int x1;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "git_clone_init_options", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(119), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_clone_options *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(119), arg0) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, unsigned int);
  if (x1 == (unsigned int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_clone_init_options(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_clone_init_options _cffi_d_git_clone_init_options
#endif

static int _cffi_d_git_config_add_file_ondisk(git_config * x0, char const * x1, git_config_level_t x2, git_repository const * x3, int x4)
{
  return git_config_add_file_ondisk(x0, x1, x2, x3, x4);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_config_add_file_ondisk(PyObject *self, PyObject *args)
{
  git_config * x0;
  char const * x1;
  git_config_level_t x2;
  git_repository const * x3;
  int x4;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;

  if (!PyArg_UnpackTuple(args, "git_config_add_file_ondisk", 5, 5, &arg0, &arg1, &arg2, &arg3, &arg4))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(131), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_config *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(131), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (char const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(10), arg1) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x2, _cffi_type(155), arg2) < 0)
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(47), arg3, (char **)&x3);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x3 = (git_repository const *)alloca((size_t)datasize);
    memset((void *)x3, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x3, _cffi_type(47), arg3) < 0)
      return NULL;
  }

  x4 = _cffi_to_c_int(arg4, int);
  if (x4 == (int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_config_add_file_ondisk(x0, x1, x2, x3, x4); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_config_add_file_ondisk _cffi_d_git_config_add_file_ondisk
#endif

static int _cffi_d_git_config_delete_entry(git_config * x0, char const * x1)
{
  return git_config_delete_entry(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_config_delete_entry(PyObject *self, PyObject *args)
{
  git_config * x0;
  char const * x1;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "git_config_delete_entry", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(131), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_config *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(131), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (char const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(10), arg1) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_config_delete_entry(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_config_delete_entry _cffi_d_git_config_delete_entry
#endif

static void _cffi_d_git_config_entry_free(git_config_entry * x0)
{
  git_config_entry_free(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_config_entry_free(PyObject *self, PyObject *arg0)
{
  git_config_entry * x0;
  Py_ssize_t datasize;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(647), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_config_entry *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(647), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { git_config_entry_free(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_git_config_entry_free _cffi_d_git_config_entry_free
#endif

static int _cffi_d_git_config_find_global(git_buf * x0)
{
  return git_config_find_global(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_config_find_global(PyObject *self, PyObject *arg0)
{
  git_buf * x0;
  Py_ssize_t datasize;
  int result;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(88), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_buf *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(88), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_config_find_global(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_config_find_global _cffi_d_git_config_find_global
#endif

static int _cffi_d_git_config_find_system(git_buf * x0)
{
  return git_config_find_system(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_config_find_system(PyObject *self, PyObject *arg0)
{
  git_buf * x0;
  Py_ssize_t datasize;
  int result;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(88), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_buf *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(88), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_config_find_system(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_config_find_system _cffi_d_git_config_find_system
#endif

static int _cffi_d_git_config_find_xdg(git_buf * x0)
{
  return git_config_find_xdg(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_config_find_xdg(PyObject *self, PyObject *arg0)
{
  git_buf * x0;
  Py_ssize_t datasize;
  int result;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(88), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_buf *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(88), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_config_find_xdg(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_config_find_xdg _cffi_d_git_config_find_xdg
#endif

static void _cffi_d_git_config_free(git_config * x0)
{
  git_config_free(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_config_free(PyObject *self, PyObject *arg0)
{
  git_config * x0;
  Py_ssize_t datasize;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(131), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_config *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(131), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { git_config_free(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_git_config_free _cffi_d_git_config_free
#endif

static int _cffi_d_git_config_get_entry(git_config_entry * * x0, git_config const * x1, char const * x2)
{
  return git_config_get_entry(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_config_get_entry(PyObject *self, PyObject *args)
{
  git_config_entry * * x0;
  git_config const * x1;
  char const * x2;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "git_config_get_entry", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(170), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_config_entry * *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(170), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(51), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (git_config const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(51), arg1) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg2, (char **)&x2);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x2 = (char const *)alloca((size_t)datasize);
    memset((void *)x2, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x2, _cffi_type(10), arg2) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_config_get_entry(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_config_get_entry _cffi_d_git_config_get_entry
#endif

static int _cffi_d_git_config_get_string(char const * * x0, git_config const * x1, char const * x2)
{
  return git_config_get_string(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_config_get_string(PyObject *self, PyObject *args)
{
  char const * * x0;
  git_config const * x1;
  char const * x2;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "git_config_get_string", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(45), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (char const * *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(45), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(51), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (git_config const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(51), arg1) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg2, (char **)&x2);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x2 = (char const *)alloca((size_t)datasize);
    memset((void *)x2, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x2, _cffi_type(10), arg2) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_config_get_string(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_config_get_string _cffi_d_git_config_get_string
#endif

static void _cffi_d_git_config_iterator_free(git_config_iterator * x0)
{
  git_config_iterator_free(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_config_iterator_free(PyObject *self, PyObject *arg0)
{
  git_config_iterator * x0;
  Py_ssize_t datasize;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(176), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_config_iterator *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(176), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { git_config_iterator_free(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_git_config_iterator_free _cffi_d_git_config_iterator_free
#endif

static int _cffi_d_git_config_iterator_new(git_config_iterator * * x0, git_config const * x1)
{
  return git_config_iterator_new(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_config_iterator_new(PyObject *self, PyObject *args)
{
  git_config_iterator * * x0;
  git_config const * x1;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "git_config_iterator_new", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(179), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_config_iterator * *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(179), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(51), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (git_config const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(51), arg1) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_config_iterator_new(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_config_iterator_new _cffi_d_git_config_iterator_new
#endif

static int _cffi_d_git_config_multivar_iterator_new(git_config_iterator * * x0, git_config const * x1, char const * x2, char const * x3)
{
  return git_config_multivar_iterator_new(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_config_multivar_iterator_new(PyObject *self, PyObject *args)
{
  git_config_iterator * * x0;
  git_config const * x1;
  char const * x2;
  char const * x3;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "git_config_multivar_iterator_new", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(179), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_config_iterator * *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(179), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(51), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (git_config const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(51), arg1) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg2, (char **)&x2);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x2 = (char const *)alloca((size_t)datasize);
    memset((void *)x2, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x2, _cffi_type(10), arg2) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg3, (char **)&x3);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x3 = (char const *)alloca((size_t)datasize);
    memset((void *)x3, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x3, _cffi_type(10), arg3) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_config_multivar_iterator_new(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_config_multivar_iterator_new _cffi_d_git_config_multivar_iterator_new
#endif

static int _cffi_d_git_config_new(git_config * * x0)
{
  return git_config_new(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_config_new(PyObject *self, PyObject *arg0)
{
  git_config * * x0;
  Py_ssize_t datasize;
  int result;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(123), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_config * *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(123), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_config_new(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_config_new _cffi_d_git_config_new
#endif

static int _cffi_d_git_config_next(git_config_entry * * x0, git_config_iterator * x1)
{
  return git_config_next(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_config_next(PyObject *self, PyObject *args)
{
  git_config_entry * * x0;
  git_config_iterator * x1;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "git_config_next", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(170), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_config_entry * *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(170), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(176), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (git_config_iterator *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(176), arg1) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_config_next(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_config_next _cffi_d_git_config_next
#endif

static int _cffi_d_git_config_open_ondisk(git_config * * x0, char const * x1)
{
  return git_config_open_ondisk(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_config_open_ondisk(PyObject *self, PyObject *args)
{
  git_config * * x0;
  char const * x1;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "git_config_open_ondisk", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(123), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_config * *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(123), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (char const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(10), arg1) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_config_open_ondisk(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_config_open_ondisk _cffi_d_git_config_open_ondisk
#endif

static int _cffi_d_git_config_parse_bool(int * x0, char const * x1)
{
  return git_config_parse_bool(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_config_parse_bool(PyObject *self, PyObject *args)
{
  int * x0;
  char const * x1;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "git_config_parse_bool", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(560), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (int *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(560), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (char const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(10), arg1) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_config_parse_bool(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_config_parse_bool _cffi_d_git_config_parse_bool
#endif

static int _cffi_d_git_config_parse_int64(int64_t * x0, char const * x1)
{
  return git_config_parse_int64(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_config_parse_int64(PyObject *self, PyObject *args)
{
  int64_t * x0;
  char const * x1;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "git_config_parse_int64", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(576), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (int64_t *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(576), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (char const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(10), arg1) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_config_parse_int64(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_config_parse_int64 _cffi_d_git_config_parse_int64
#endif

static int _cffi_d_git_config_set_bool(git_config * x0, char const * x1, int x2)
{
  return git_config_set_bool(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_config_set_bool(PyObject *self, PyObject *args)
{
  git_config * x0;
  char const * x1;
  int x2;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "git_config_set_bool", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(131), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_config *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(131), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (char const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(10), arg1) < 0)
      return NULL;
  }

  x2 = _cffi_to_c_int(arg2, int);
  if (x2 == (int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_config_set_bool(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_config_set_bool _cffi_d_git_config_set_bool
#endif

static int _cffi_d_git_config_set_int64(git_config * x0, char const * x1, int64_t x2)
{
  return git_config_set_int64(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_config_set_int64(PyObject *self, PyObject *args)
{
  git_config * x0;
  char const * x1;
  int64_t x2;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "git_config_set_int64", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(131), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_config *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(131), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (char const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(10), arg1) < 0)
      return NULL;
  }

  x2 = _cffi_to_c_int(arg2, int64_t);
  if (x2 == (int64_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_config_set_int64(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_config_set_int64 _cffi_d_git_config_set_int64
#endif

static int _cffi_d_git_config_set_multivar(git_config * x0, char const * x1, char const * x2, char const * x3)
{
  return git_config_set_multivar(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_config_set_multivar(PyObject *self, PyObject *args)
{
  git_config * x0;
  char const * x1;
  char const * x2;
  char const * x3;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "git_config_set_multivar", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(131), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_config *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(131), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (char const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(10), arg1) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg2, (char **)&x2);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x2 = (char const *)alloca((size_t)datasize);
    memset((void *)x2, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x2, _cffi_type(10), arg2) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg3, (char **)&x3);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x3 = (char const *)alloca((size_t)datasize);
    memset((void *)x3, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x3, _cffi_type(10), arg3) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_config_set_multivar(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_config_set_multivar _cffi_d_git_config_set_multivar
#endif

static int _cffi_d_git_config_set_string(git_config * x0, char const * x1, char const * x2)
{
  return git_config_set_string(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_config_set_string(PyObject *self, PyObject *args)
{
  git_config * x0;
  char const * x1;
  char const * x2;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "git_config_set_string", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(131), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_config *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(131), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (char const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(10), arg1) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg2, (char **)&x2);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x2 = (char const *)alloca((size_t)datasize);
    memset((void *)x2, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x2, _cffi_type(10), arg2) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_config_set_string(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_config_set_string _cffi_d_git_config_set_string
#endif

static int _cffi_d_git_config_snapshot(git_config * * x0, git_config * x1)
{
  return git_config_snapshot(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_config_snapshot(PyObject *self, PyObject *args)
{
  git_config * * x0;
  git_config * x1;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "git_config_snapshot", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(123), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_config * *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(123), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(131), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (git_config *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(131), arg1) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_config_snapshot(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_config_snapshot _cffi_d_git_config_snapshot
#endif

static int _cffi_d_git_cred_ssh_key_from_agent(git_cred * * x0, char const * x1)
{
  return git_cred_ssh_key_from_agent(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_cred_ssh_key_from_agent(PyObject *self, PyObject *args)
{
  git_cred * * x0;
  char const * x1;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "git_cred_ssh_key_from_agent", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(189), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_cred * *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(189), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (char const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(10), arg1) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_cred_ssh_key_from_agent(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_cred_ssh_key_from_agent _cffi_d_git_cred_ssh_key_from_agent
#endif

static int _cffi_d_git_cred_ssh_key_memory_new(git_cred * * x0, char const * x1, char const * x2, char const * x3, char const * x4)
{
  return git_cred_ssh_key_memory_new(x0, x1, x2, x3, x4);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_cred_ssh_key_memory_new(PyObject *self, PyObject *args)
{
  git_cred * * x0;
  char const * x1;
  char const * x2;
  char const * x3;
  char const * x4;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;

  if (!PyArg_UnpackTuple(args, "git_cred_ssh_key_memory_new", 5, 5, &arg0, &arg1, &arg2, &arg3, &arg4))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(189), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_cred * *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(189), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (char const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(10), arg1) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg2, (char **)&x2);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x2 = (char const *)alloca((size_t)datasize);
    memset((void *)x2, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x2, _cffi_type(10), arg2) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg3, (char **)&x3);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x3 = (char const *)alloca((size_t)datasize);
    memset((void *)x3, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x3, _cffi_type(10), arg3) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg4, (char **)&x4);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x4 = (char const *)alloca((size_t)datasize);
    memset((void *)x4, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x4, _cffi_type(10), arg4) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_cred_ssh_key_memory_new(x0, x1, x2, x3, x4); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_cred_ssh_key_memory_new _cffi_d_git_cred_ssh_key_memory_new
#endif

static int _cffi_d_git_cred_ssh_key_new(git_cred * * x0, char const * x1, char const * x2, char const * x3, char const * x4)
{
  return git_cred_ssh_key_new(x0, x1, x2, x3, x4);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_cred_ssh_key_new(PyObject *self, PyObject *args)
{
  git_cred * * x0;
  char const * x1;
  char const * x2;
  char const * x3;
  char const * x4;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;

  if (!PyArg_UnpackTuple(args, "git_cred_ssh_key_new", 5, 5, &arg0, &arg1, &arg2, &arg3, &arg4))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(189), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_cred * *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(189), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (char const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(10), arg1) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg2, (char **)&x2);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x2 = (char const *)alloca((size_t)datasize);
    memset((void *)x2, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x2, _cffi_type(10), arg2) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg3, (char **)&x3);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x3 = (char const *)alloca((size_t)datasize);
    memset((void *)x3, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x3, _cffi_type(10), arg3) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg4, (char **)&x4);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x4 = (char const *)alloca((size_t)datasize);
    memset((void *)x4, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x4, _cffi_type(10), arg4) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_cred_ssh_key_new(x0, x1, x2, x3, x4); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_cred_ssh_key_new _cffi_d_git_cred_ssh_key_new
#endif

static int _cffi_d_git_cred_username_new(git_cred * * x0, char const * x1)
{
  return git_cred_username_new(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_cred_username_new(PyObject *self, PyObject *args)
{
  git_cred * * x0;
  char const * x1;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "git_cred_username_new", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(189), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_cred * *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(189), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (char const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(10), arg1) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_cred_username_new(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_cred_username_new _cffi_d_git_cred_username_new
#endif

static int _cffi_d_git_cred_userpass_plaintext_new(git_cred * * x0, char const * x1, char const * x2)
{
  return git_cred_userpass_plaintext_new(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_cred_userpass_plaintext_new(PyObject *self, PyObject *args)
{
  git_cred * * x0;
  char const * x1;
  char const * x2;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "git_cred_userpass_plaintext_new", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(189), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_cred * *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(189), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (char const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(10), arg1) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg2, (char **)&x2);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x2 = (char const *)alloca((size_t)datasize);
    memset((void *)x2, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x2, _cffi_type(10), arg2) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_cred_userpass_plaintext_new(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_cred_userpass_plaintext_new _cffi_d_git_cred_userpass_plaintext_new
#endif

static int _cffi_d_git_describe_commit(git_describe_result * * x0, git_object * x1, git_describe_options * x2)
{
  return git_describe_commit(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_describe_commit(PyObject *self, PyObject *args)
{
  git_describe_result * * x0;
  git_object * x1;
  git_describe_options * x2;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "git_describe_commit", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(220), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_describe_result * *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(220), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(221), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (git_object *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(221), arg1) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(216), arg2, (char **)&x2);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x2 = (git_describe_options *)alloca((size_t)datasize);
    memset((void *)x2, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x2, _cffi_type(216), arg2) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_describe_commit(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_describe_commit _cffi_d_git_describe_commit
#endif

static int _cffi_d_git_describe_format(git_buf * x0, git_describe_result const * x1, git_describe_format_options const * x2)
{
  return git_describe_format(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_describe_format(PyObject *self, PyObject *args)
{
  git_buf * x0;
  git_describe_result const * x1;
  git_describe_format_options const * x2;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "git_describe_format", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(88), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_buf *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(88), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(92), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (git_describe_result const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(92), arg1) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(93), arg2, (char **)&x2);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x2 = (git_describe_format_options const *)alloca((size_t)datasize);
    memset((void *)x2, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x2, _cffi_type(93), arg2) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_describe_format(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_describe_format _cffi_d_git_describe_format
#endif

static int _cffi_d_git_describe_init_format_options(git_describe_format_options * x0, unsigned int x1)
{
  return git_describe_init_format_options(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_describe_init_format_options(PyObject *self, PyObject *args)
{
  git_describe_format_options * x0;
  unsigned int x1;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "git_describe_init_format_options", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(212), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_describe_format_options *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(212), arg0) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, unsigned int);
  if (x1 == (unsigned int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_describe_init_format_options(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_describe_init_format_options _cffi_d_git_describe_init_format_options
#endif

static int _cffi_d_git_describe_init_options(git_describe_options * x0, unsigned int x1)
{
  return git_describe_init_options(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_describe_init_options(PyObject *self, PyObject *args)
{
  git_describe_options * x0;
  unsigned int x1;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "git_describe_init_options", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(216), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_describe_options *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(216), arg0) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, unsigned int);
  if (x1 == (unsigned int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_describe_init_options(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_describe_init_options _cffi_d_git_describe_init_options
#endif

static void _cffi_d_git_describe_result_free(git_describe_result * x0)
{
  git_describe_result_free(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_describe_result_free(PyObject *self, PyObject *arg0)
{
  git_describe_result * x0;
  Py_ssize_t datasize;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(653), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_describe_result *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(653), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { git_describe_result_free(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_git_describe_result_free _cffi_d_git_describe_result_free
#endif

static int _cffi_d_git_describe_workdir(git_describe_result * * x0, git_repository * x1, git_describe_options * x2)
{
  return git_describe_workdir(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_describe_workdir(PyObject *self, PyObject *args)
{
  git_describe_result * * x0;
  git_repository * x1;
  git_describe_options * x2;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "git_describe_workdir", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(220), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_describe_result * *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(220), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(56), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (git_repository *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(56), arg1) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(216), arg2, (char **)&x2);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x2 = (git_describe_options *)alloca((size_t)datasize);
    memset((void *)x2, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x2, _cffi_type(216), arg2) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_describe_workdir(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_describe_workdir _cffi_d_git_describe_workdir
#endif

static int _cffi_d_git_diff_index_to_workdir(git_diff * * x0, git_repository * x1, git_index * x2, git_diff_options const * x3)
{
  return git_diff_index_to_workdir(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_diff_index_to_workdir(PyObject *self, PyObject *args)
{
  git_diff * * x0;
  git_repository * x1;
  git_index * x2;
  git_diff_options const * x3;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "git_diff_index_to_workdir", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(230), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_diff * *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(230), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(56), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (git_repository *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(56), arg1) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(26), arg2, (char **)&x2);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x2 = (git_index *)alloca((size_t)datasize);
    memset((void *)x2, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x2, _cffi_type(26), arg2) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(233), arg3, (char **)&x3);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x3 = (git_diff_options const *)alloca((size_t)datasize);
    memset((void *)x3, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x3, _cffi_type(233), arg3) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_diff_index_to_workdir(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_diff_index_to_workdir _cffi_d_git_diff_index_to_workdir
#endif

static int _cffi_d_git_diff_init_options(git_diff_options * x0, unsigned int x1)
{
  return git_diff_init_options(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_diff_init_options(PyObject *self, PyObject *args)
{
  git_diff_options * x0;
  unsigned int x1;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "git_diff_init_options", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(255), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_diff_options *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(255), arg0) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, unsigned int);
  if (x1 == (unsigned int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_diff_init_options(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_diff_init_options _cffi_d_git_diff_init_options
#endif

static int _cffi_d_git_diff_tree_to_index(git_diff * * x0, git_repository * x1, git_tree * x2, git_index * x3, git_diff_options const * x4)
{
  return git_diff_tree_to_index(x0, x1, x2, x3, x4);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_diff_tree_to_index(PyObject *self, PyObject *args)
{
  git_diff * * x0;
  git_repository * x1;
  git_tree * x2;
  git_index * x3;
  git_diff_options const * x4;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;

  if (!PyArg_UnpackTuple(args, "git_diff_tree_to_index", 5, 5, &arg0, &arg1, &arg2, &arg3, &arg4))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(230), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_diff * *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(230), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(56), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (git_repository *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(56), arg1) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(238), arg2, (char **)&x2);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x2 = (git_tree *)alloca((size_t)datasize);
    memset((void *)x2, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x2, _cffi_type(238), arg2) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(26), arg3, (char **)&x3);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x3 = (git_index *)alloca((size_t)datasize);
    memset((void *)x3, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x3, _cffi_type(26), arg3) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(233), arg4, (char **)&x4);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x4 = (git_diff_options const *)alloca((size_t)datasize);
    memset((void *)x4, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x4, _cffi_type(233), arg4) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_diff_tree_to_index(x0, x1, x2, x3, x4); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_diff_tree_to_index _cffi_d_git_diff_tree_to_index
#endif

static git_error const * _cffi_d_git_error_last(void)
{
  return git_error_last();
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_error_last(PyObject *self, PyObject *noarg)
{
  git_error const * result;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_error_last(); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  (void)noarg; /* unused */
  return _cffi_from_c_pointer((char *)result, _cffi_type(718));
}
#else
#  define _cffi_f_git_error_last _cffi_d_git_error_last
#endif

static int _cffi_d_git_fetch_init_options(git_fetch_options * x0, unsigned int x1)
{
  return git_fetch_init_options(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_fetch_init_options(PyObject *self, PyObject *args)
{
  git_fetch_options * x0;
  unsigned int x1;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "git_fetch_init_options", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(259), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_fetch_options *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(259), arg0) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, unsigned int);
  if (x1 == (unsigned int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_fetch_init_options(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_fetch_init_options _cffi_d_git_fetch_init_options
#endif

static int _cffi_d_git_graph_ahead_behind(size_t * x0, size_t * x1, git_repository * x2, git_oid const * x3, git_oid const * x4)
{
  return git_graph_ahead_behind(x0, x1, x2, x3, x4);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_graph_ahead_behind(PyObject *self, PyObject *args)
{
  size_t * x0;
  size_t * x1;
  git_repository * x2;
  git_oid const * x3;
  git_oid const * x4;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;

  if (!PyArg_UnpackTuple(args, "git_graph_ahead_behind", 5, 5, &arg0, &arg1, &arg2, &arg3, &arg4))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(580), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (size_t *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(580), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(580), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (size_t *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(580), arg1) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(56), arg2, (char **)&x2);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x2 = (git_repository *)alloca((size_t)datasize);
    memset((void *)x2, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x2, _cffi_type(56), arg2) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(68), arg3, (char **)&x3);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x3 = (git_oid const *)alloca((size_t)datasize);
    memset((void *)x3, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x3, _cffi_type(68), arg3) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(68), arg4, (char **)&x4);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x4 = (git_oid const *)alloca((size_t)datasize);
    memset((void *)x4, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x4, _cffi_type(68), arg4) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_graph_ahead_behind(x0, x1, x2, x3, x4); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_graph_ahead_behind _cffi_d_git_graph_ahead_behind
#endif

static int _cffi_d_git_index_add(git_index * x0, git_index_entry const * x1)
{
  return git_index_add(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_index_add(PyObject *self, PyObject *args)
{
  git_index * x0;
  git_index_entry const * x1;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "git_index_add", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(26), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_index *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(26), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(307), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (git_index_entry const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(307), arg1) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_index_add(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_index_add _cffi_d_git_index_add
#endif

static int _cffi_d_git_index_add_all(git_index * x0, git_strarray const * x1, unsigned int x2, int(* x3)(char const *, char const *, void *), void * x4)
{
  return git_index_add_all(x0, x1, x2, x3, x4);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_index_add_all(PyObject *self, PyObject *args)
{
  git_index * x0;
  git_strarray const * x1;
  unsigned int x2;
  int(* x3)(char const *, char const *, void *);
  void * x4;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;

  if (!PyArg_UnpackTuple(args, "git_index_add_all", 5, 5, &arg0, &arg1, &arg2, &arg3, &arg4))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(26), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_index *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(26), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(311), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (git_strarray const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(311), arg1) < 0)
      return NULL;
  }

  x2 = _cffi_to_c_int(arg2, unsigned int);
  if (x2 == (unsigned int)-1 && PyErr_Occurred())
    return NULL;

  x3 = (int(*)(char const *, char const *, void *))_cffi_to_c_pointer(arg3, _cffi_type(313));
  if (x3 == (int(*)(char const *, char const *, void *))NULL && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(64), arg4, (char **)&x4);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x4 = (void *)alloca((size_t)datasize);
    memset((void *)x4, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x4, _cffi_type(64), arg4) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_index_add_all(x0, x1, x2, x3, x4); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_index_add_all _cffi_d_git_index_add_all
#endif

static int _cffi_d_git_index_add_bypath(git_index * x0, char const * x1)
{
  return git_index_add_bypath(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_index_add_bypath(PyObject *self, PyObject *args)
{
  git_index * x0;
  char const * x1;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "git_index_add_bypath", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(26), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_index *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(26), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (char const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(10), arg1) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_index_add_bypath(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_index_add_bypath _cffi_d_git_index_add_bypath
#endif

static int _cffi_d_git_index_clear(git_index * x0)
{
  return git_index_clear(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_index_clear(PyObject *self, PyObject *arg0)
{
  git_index * x0;
  Py_ssize_t datasize;
  int result;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(26), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_index *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(26), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_index_clear(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_index_clear _cffi_d_git_index_clear
#endif

static int _cffi_d_git_index_conflict_get(git_index_entry const * * x0, git_index_entry const * * x1, git_index_entry const * * x2, git_index * x3, char const * x4)
{
  return git_index_conflict_get(x0, x1, x2, x3, x4);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_index_conflict_get(PyObject *self, PyObject *args)
{
  git_index_entry const * * x0;
  git_index_entry const * * x1;
  git_index_entry const * * x2;
  git_index * x3;
  char const * x4;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;

  if (!PyArg_UnpackTuple(args, "git_index_conflict_get", 5, 5, &arg0, &arg1, &arg2, &arg3, &arg4))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(332), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_index_entry const * *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(332), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(332), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (git_index_entry const * *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(332), arg1) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(332), arg2, (char **)&x2);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x2 = (git_index_entry const * *)alloca((size_t)datasize);
    memset((void *)x2, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x2, _cffi_type(332), arg2) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(26), arg3, (char **)&x3);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x3 = (git_index *)alloca((size_t)datasize);
    memset((void *)x3, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x3, _cffi_type(26), arg3) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg4, (char **)&x4);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x4 = (char const *)alloca((size_t)datasize);
    memset((void *)x4, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x4, _cffi_type(10), arg4) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_index_conflict_get(x0, x1, x2, x3, x4); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_index_conflict_get _cffi_d_git_index_conflict_get
#endif

static void _cffi_d_git_index_conflict_iterator_free(git_index_conflict_iterator * x0)
{
  git_index_conflict_iterator_free(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_index_conflict_iterator_free(PyObject *self, PyObject *arg0)
{
  git_index_conflict_iterator * x0;
  Py_ssize_t datasize;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(342), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_index_conflict_iterator *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(342), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { git_index_conflict_iterator_free(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_git_index_conflict_iterator_free _cffi_d_git_index_conflict_iterator_free
#endif

static int _cffi_d_git_index_conflict_iterator_new(git_index_conflict_iterator * * x0, git_index * x1)
{
  return git_index_conflict_iterator_new(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_index_conflict_iterator_new(PyObject *self, PyObject *args)
{
  git_index_conflict_iterator * * x0;
  git_index * x1;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "git_index_conflict_iterator_new", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(328), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_index_conflict_iterator * *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(328), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(26), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (git_index *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(26), arg1) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_index_conflict_iterator_new(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_index_conflict_iterator_new _cffi_d_git_index_conflict_iterator_new
#endif

static int _cffi_d_git_index_conflict_next(git_index_entry const * * x0, git_index_entry const * * x1, git_index_entry const * * x2, git_index_conflict_iterator * x3)
{
  return git_index_conflict_next(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_index_conflict_next(PyObject *self, PyObject *args)
{
  git_index_entry const * * x0;
  git_index_entry const * * x1;
  git_index_entry const * * x2;
  git_index_conflict_iterator * x3;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "git_index_conflict_next", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(332), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_index_entry const * *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(332), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(332), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (git_index_entry const * *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(332), arg1) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(332), arg2, (char **)&x2);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x2 = (git_index_entry const * *)alloca((size_t)datasize);
    memset((void *)x2, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x2, _cffi_type(332), arg2) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(342), arg3, (char **)&x3);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x3 = (git_index_conflict_iterator *)alloca((size_t)datasize);
    memset((void *)x3, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x3, _cffi_type(342), arg3) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_index_conflict_next(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_index_conflict_next _cffi_d_git_index_conflict_next
#endif

static int _cffi_d_git_index_conflict_remove(git_index * x0, char const * x1)
{
  return git_index_conflict_remove(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_index_conflict_remove(PyObject *self, PyObject *args)
{
  git_index * x0;
  char const * x1;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "git_index_conflict_remove", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(26), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_index *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(26), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (char const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(10), arg1) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_index_conflict_remove(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_index_conflict_remove _cffi_d_git_index_conflict_remove
#endif

static size_t _cffi_d_git_index_entrycount(git_index const * x0)
{
  return git_index_entrycount(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_index_entrycount(PyObject *self, PyObject *arg0)
{
  git_index const * x0;
  Py_ssize_t datasize;
  size_t result;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(325), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_index const *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(325), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_index_entrycount(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, size_t);
}
#else
#  define _cffi_f_git_index_entrycount _cffi_d_git_index_entrycount
#endif

static int _cffi_d_git_index_find(size_t * x0, git_index * x1, char const * x2)
{
  return git_index_find(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_index_find(PyObject *self, PyObject *args)
{
  size_t * x0;
  git_index * x1;
  char const * x2;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "git_index_find", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(580), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (size_t *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(580), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(26), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (git_index *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(26), arg1) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg2, (char **)&x2);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x2 = (char const *)alloca((size_t)datasize);
    memset((void *)x2, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x2, _cffi_type(10), arg2) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_index_find(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_index_find _cffi_d_git_index_find
#endif

static void _cffi_d_git_index_free(git_index * x0)
{
  git_index_free(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_index_free(PyObject *self, PyObject *arg0)
{
  git_index * x0;
  Py_ssize_t datasize;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(26), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_index *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(26), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { git_index_free(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_git_index_free _cffi_d_git_index_free
#endif

static git_index_entry const * _cffi_d_git_index_get_byindex(git_index * x0, size_t x1)
{
  return git_index_get_byindex(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_index_get_byindex(PyObject *self, PyObject *args)
{
  git_index * x0;
  size_t x1;
  Py_ssize_t datasize;
  git_index_entry const * result;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "git_index_get_byindex", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(26), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_index *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(26), arg0) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, size_t);
  if (x1 == (size_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_index_get_byindex(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_pointer((char *)result, _cffi_type(307));
}
#else
#  define _cffi_f_git_index_get_byindex _cffi_d_git_index_get_byindex
#endif

static git_index_entry const * _cffi_d_git_index_get_bypath(git_index * x0, char const * x1, int x2)
{
  return git_index_get_bypath(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_index_get_bypath(PyObject *self, PyObject *args)
{
  git_index * x0;
  char const * x1;
  int x2;
  Py_ssize_t datasize;
  git_index_entry const * result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "git_index_get_bypath", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(26), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_index *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(26), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (char const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(10), arg1) < 0)
      return NULL;
  }

  x2 = _cffi_to_c_int(arg2, int);
  if (x2 == (int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_index_get_bypath(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_pointer((char *)result, _cffi_type(307));
}
#else
#  define _cffi_f_git_index_get_bypath _cffi_d_git_index_get_bypath
#endif

static int _cffi_d_git_index_has_conflicts(git_index const * x0)
{
  return git_index_has_conflicts(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_index_has_conflicts(PyObject *self, PyObject *arg0)
{
  git_index const * x0;
  Py_ssize_t datasize;
  int result;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(325), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_index const *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(325), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_index_has_conflicts(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_index_has_conflicts _cffi_d_git_index_has_conflicts
#endif

static int _cffi_d_git_index_open(git_index * * x0, char const * x1)
{
  return git_index_open(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_index_open(PyObject *self, PyObject *args)
{
  git_index * * x0;
  char const * x1;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "git_index_open", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(263), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_index * *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(263), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (char const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(10), arg1) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_index_open(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_index_open _cffi_d_git_index_open
#endif

static int _cffi_d_git_index_read(git_index * x0, int x1)
{
  return git_index_read(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_index_read(PyObject *self, PyObject *args)
{
  git_index * x0;
  int x1;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "git_index_read", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(26), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_index *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(26), arg0) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, int);
  if (x1 == (int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_index_read(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_index_read _cffi_d_git_index_read
#endif

static int _cffi_d_git_index_read_tree(git_index * x0, git_tree const * x1)
{
  return git_index_read_tree(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_index_read_tree(PyObject *self, PyObject *args)
{
  git_index * x0;
  git_tree const * x1;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "git_index_read_tree", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(26), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_index *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(26), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(288), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (git_tree const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(288), arg1) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_index_read_tree(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_index_read_tree _cffi_d_git_index_read_tree
#endif

static int _cffi_d_git_index_remove(git_index * x0, char const * x1, int x2)
{
  return git_index_remove(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_index_remove(PyObject *self, PyObject *args)
{
  git_index * x0;
  char const * x1;
  int x2;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "git_index_remove", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(26), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_index *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(26), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (char const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(10), arg1) < 0)
      return NULL;
  }

  x2 = _cffi_to_c_int(arg2, int);
  if (x2 == (int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_index_remove(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_index_remove _cffi_d_git_index_remove
#endif

static int _cffi_d_git_index_write(git_index * x0)
{
  return git_index_write(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_index_write(PyObject *self, PyObject *arg0)
{
  git_index * x0;
  Py_ssize_t datasize;
  int result;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(26), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_index *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(26), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_index_write(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_index_write _cffi_d_git_index_write
#endif

static int _cffi_d_git_index_write_tree(git_oid * x0, git_index * x1)
{
  return git_index_write_tree(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_index_write_tree(PyObject *self, PyObject *args)
{
  git_oid * x0;
  git_index * x1;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "git_index_write_tree", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(357), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_oid *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(357), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(26), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (git_index *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(26), arg1) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_index_write_tree(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_index_write_tree _cffi_d_git_index_write_tree
#endif

static int _cffi_d_git_index_write_tree_to(git_oid * x0, git_index * x1, git_repository * x2)
{
  return git_index_write_tree_to(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_index_write_tree_to(PyObject *self, PyObject *args)
{
  git_oid * x0;
  git_index * x1;
  git_repository * x2;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "git_index_write_tree_to", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(357), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_oid *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(357), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(26), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (git_index *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(26), arg1) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(56), arg2, (char **)&x2);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x2 = (git_repository *)alloca((size_t)datasize);
    memset((void *)x2, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x2, _cffi_type(56), arg2) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_index_write_tree_to(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_index_write_tree_to _cffi_d_git_index_write_tree_to
#endif

static int _cffi_d_git_libgit2_features(void)
{
  return git_libgit2_features();
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_libgit2_features(PyObject *self, PyObject *noarg)
{
  int result;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_libgit2_features(); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  (void)noarg; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_libgit2_features _cffi_d_git_libgit2_features
#endif

static int _cffi_d_git_merge_commits(git_index * * x0, git_repository * x1, git_commit const * x2, git_commit const * x3, git_merge_options const * x4)
{
  return git_merge_commits(x0, x1, x2, x3, x4);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_merge_commits(PyObject *self, PyObject *args)
{
  git_index * * x0;
  git_repository * x1;
  git_commit const * x2;
  git_commit const * x3;
  git_merge_options const * x4;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;

  if (!PyArg_UnpackTuple(args, "git_merge_commits", 5, 5, &arg0, &arg1, &arg2, &arg3, &arg4))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(263), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_index * *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(263), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(56), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (git_repository *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(56), arg1) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(281), arg2, (char **)&x2);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x2 = (git_commit const *)alloca((size_t)datasize);
    memset((void *)x2, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x2, _cffi_type(281), arg2) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(281), arg3, (char **)&x3);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x3 = (git_commit const *)alloca((size_t)datasize);
    memset((void *)x3, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x3, _cffi_type(281), arg3) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(276), arg4, (char **)&x4);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x4 = (git_merge_options const *)alloca((size_t)datasize);
    memset((void *)x4, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x4, _cffi_type(276), arg4) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_merge_commits(x0, x1, x2, x3, x4); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_merge_commits _cffi_d_git_merge_commits
#endif

static int _cffi_d_git_merge_file_from_index(git_merge_file_result * x0, git_repository * x1, git_index_entry const * x2, git_index_entry const * x3, git_index_entry const * x4, git_merge_file_options const * x5)
{
  return git_merge_file_from_index(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_merge_file_from_index(PyObject *self, PyObject *args)
{
  git_merge_file_result * x0;
  git_repository * x1;
  git_index_entry const * x2;
  git_index_entry const * x3;
  git_index_entry const * x4;
  git_merge_file_options const * x5;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "git_merge_file_from_index", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(345), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_merge_file_result *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(345), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(56), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (git_repository *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(56), arg1) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(307), arg2, (char **)&x2);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x2 = (git_index_entry const *)alloca((size_t)datasize);
    memset((void *)x2, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x2, _cffi_type(307), arg2) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(307), arg3, (char **)&x3);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x3 = (git_index_entry const *)alloca((size_t)datasize);
    memset((void *)x3, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x3, _cffi_type(307), arg3) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(307), arg4, (char **)&x4);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x4 = (git_index_entry const *)alloca((size_t)datasize);
    memset((void *)x4, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x4, _cffi_type(307), arg4) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(350), arg5, (char **)&x5);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x5 = (git_merge_file_options const *)alloca((size_t)datasize);
    memset((void *)x5, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x5, _cffi_type(350), arg5) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_merge_file_from_index(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_merge_file_from_index _cffi_d_git_merge_file_from_index
#endif

static void _cffi_d_git_merge_file_result_free(git_merge_file_result * x0)
{
  git_merge_file_result_free(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_merge_file_result_free(PyObject *self, PyObject *arg0)
{
  git_merge_file_result * x0;
  Py_ssize_t datasize;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(345), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_merge_file_result *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(345), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { git_merge_file_result_free(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_git_merge_file_result_free _cffi_d_git_merge_file_result_free
#endif

static int _cffi_d_git_merge_init_options(git_merge_options * x0, unsigned int x1)
{
  return git_merge_init_options(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_merge_init_options(PyObject *self, PyObject *args)
{
  git_merge_options * x0;
  unsigned int x1;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "git_merge_init_options", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(353), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_merge_options *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(353), arg0) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, unsigned int);
  if (x1 == (unsigned int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_merge_init_options(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_merge_init_options _cffi_d_git_merge_init_options
#endif

static int _cffi_d_git_merge_trees(git_index * * x0, git_repository * x1, git_tree const * x2, git_tree const * x3, git_tree const * x4, git_merge_options const * x5)
{
  return git_merge_trees(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_merge_trees(PyObject *self, PyObject *args)
{
  git_index * * x0;
  git_repository * x1;
  git_tree const * x2;
  git_tree const * x3;
  git_tree const * x4;
  git_merge_options const * x5;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "git_merge_trees", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(263), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_index * *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(263), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(56), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (git_repository *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(56), arg1) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(288), arg2, (char **)&x2);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x2 = (git_tree const *)alloca((size_t)datasize);
    memset((void *)x2, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x2, _cffi_type(288), arg2) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(288), arg3, (char **)&x3);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x3 = (git_tree const *)alloca((size_t)datasize);
    memset((void *)x3, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x3, _cffi_type(288), arg3) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(288), arg4, (char **)&x4);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x4 = (git_tree const *)alloca((size_t)datasize);
    memset((void *)x4, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x4, _cffi_type(288), arg4) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(276), arg5, (char **)&x5);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x5 = (git_merge_options const *)alloca((size_t)datasize);
    memset((void *)x5, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x5, _cffi_type(276), arg5) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_merge_trees(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_merge_trees _cffi_d_git_merge_trees
#endif

static int _cffi_d_git_proxy_init_options(git_proxy_options * x0, unsigned int x1)
{
  return git_proxy_init_options(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_proxy_init_options(PyObject *self, PyObject *args)
{
  git_proxy_options * x0;
  unsigned int x1;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "git_proxy_init_options", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(373), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_proxy_options *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(373), arg0) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, unsigned int);
  if (x1 == (unsigned int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_proxy_init_options(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_proxy_init_options _cffi_d_git_proxy_init_options
#endif

static int _cffi_d_git_push_init_options(git_push_options * x0, unsigned int x1)
{
  return git_push_init_options(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_push_init_options(PyObject *self, PyObject *args)
{
  git_push_options * x0;
  unsigned int x1;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "git_push_init_options", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(377), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_push_options *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(377), arg0) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, unsigned int);
  if (x1 == (unsigned int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_push_init_options(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_push_init_options _cffi_d_git_push_init_options
#endif

static git_direction _cffi_d_git_refspec_direction(git_refspec const * x0)
{
  return git_refspec_direction(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_refspec_direction(PyObject *self, PyObject *arg0)
{
  git_refspec const * x0;
  Py_ssize_t datasize;
  git_direction result;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_refspec const *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(1), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_refspec_direction(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_deref((char *)&result, _cffi_type(717));
}
#else
#  define _cffi_f_git_refspec_direction _cffi_d_git_refspec_direction
#endif

static char const * _cffi_d_git_refspec_dst(git_refspec const * x0)
{
  return git_refspec_dst(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_refspec_dst(PyObject *self, PyObject *arg0)
{
  git_refspec const * x0;
  Py_ssize_t datasize;
  char const * result;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_refspec const *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(1), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_refspec_dst(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_pointer((char *)result, _cffi_type(10));
}
#else
#  define _cffi_f_git_refspec_dst _cffi_d_git_refspec_dst
#endif

static int _cffi_d_git_refspec_dst_matches(git_refspec const * x0, char const * x1)
{
  return git_refspec_dst_matches(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_refspec_dst_matches(PyObject *self, PyObject *args)
{
  git_refspec const * x0;
  char const * x1;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "git_refspec_dst_matches", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_refspec const *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(1), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (char const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(10), arg1) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_refspec_dst_matches(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_refspec_dst_matches _cffi_d_git_refspec_dst_matches
#endif

static int _cffi_d_git_refspec_force(git_refspec const * x0)
{
  return git_refspec_force(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_refspec_force(PyObject *self, PyObject *arg0)
{
  git_refspec const * x0;
  Py_ssize_t datasize;
  int result;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_refspec const *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(1), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_refspec_force(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_refspec_force _cffi_d_git_refspec_force
#endif

static int _cffi_d_git_refspec_rtransform(git_buf * x0, git_refspec const * x1, char const * x2)
{
  return git_refspec_rtransform(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_refspec_rtransform(PyObject *self, PyObject *args)
{
  git_buf * x0;
  git_refspec const * x1;
  char const * x2;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "git_refspec_rtransform", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(88), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_buf *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(88), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (git_refspec const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(1), arg1) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg2, (char **)&x2);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x2 = (char const *)alloca((size_t)datasize);
    memset((void *)x2, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x2, _cffi_type(10), arg2) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_refspec_rtransform(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_refspec_rtransform _cffi_d_git_refspec_rtransform
#endif

static char const * _cffi_d_git_refspec_src(git_refspec const * x0)
{
  return git_refspec_src(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_refspec_src(PyObject *self, PyObject *arg0)
{
  git_refspec const * x0;
  Py_ssize_t datasize;
  char const * result;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_refspec const *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(1), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_refspec_src(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_pointer((char *)result, _cffi_type(10));
}
#else
#  define _cffi_f_git_refspec_src _cffi_d_git_refspec_src
#endif

static int _cffi_d_git_refspec_src_matches(git_refspec const * x0, char const * x1)
{
  return git_refspec_src_matches(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_refspec_src_matches(PyObject *self, PyObject *args)
{
  git_refspec const * x0;
  char const * x1;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "git_refspec_src_matches", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_refspec const *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(1), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (char const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(10), arg1) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_refspec_src_matches(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_refspec_src_matches _cffi_d_git_refspec_src_matches
#endif

static char const * _cffi_d_git_refspec_string(git_refspec const * x0)
{
  return git_refspec_string(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_refspec_string(PyObject *self, PyObject *arg0)
{
  git_refspec const * x0;
  Py_ssize_t datasize;
  char const * result;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_refspec const *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(1), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_refspec_string(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_pointer((char *)result, _cffi_type(10));
}
#else
#  define _cffi_f_git_refspec_string _cffi_d_git_refspec_string
#endif

static int _cffi_d_git_refspec_transform(git_buf * x0, git_refspec const * x1, char const * x2)
{
  return git_refspec_transform(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_refspec_transform(PyObject *self, PyObject *args)
{
  git_buf * x0;
  git_refspec const * x1;
  char const * x2;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "git_refspec_transform", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(88), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_buf *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(88), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (git_refspec const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(1), arg1) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg2, (char **)&x2);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x2 = (char const *)alloca((size_t)datasize);
    memset((void *)x2, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x2, _cffi_type(10), arg2) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_refspec_transform(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_refspec_transform _cffi_d_git_refspec_transform
#endif

static int _cffi_d_git_remote_add_fetch(git_repository * x0, char const * x1, char const * x2)
{
  return git_remote_add_fetch(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_remote_add_fetch(PyObject *self, PyObject *args)
{
  git_repository * x0;
  char const * x1;
  char const * x2;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "git_remote_add_fetch", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(56), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_repository *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(56), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (char const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(10), arg1) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg2, (char **)&x2);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x2 = (char const *)alloca((size_t)datasize);
    memset((void *)x2, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x2, _cffi_type(10), arg2) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_remote_add_fetch(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_remote_add_fetch _cffi_d_git_remote_add_fetch
#endif

static int _cffi_d_git_remote_add_push(git_repository * x0, char const * x1, char const * x2)
{
  return git_remote_add_push(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_remote_add_push(PyObject *self, PyObject *args)
{
  git_repository * x0;
  char const * x1;
  char const * x2;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "git_remote_add_push", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(56), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_repository *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(56), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (char const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(10), arg1) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg2, (char **)&x2);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x2 = (char const *)alloca((size_t)datasize);
    memset((void *)x2, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x2, _cffi_type(10), arg2) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_remote_add_push(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_remote_add_push _cffi_d_git_remote_add_push
#endif

static int _cffi_d_git_remote_create(git_remote * * x0, git_repository * x1, char const * x2, char const * x3)
{
  return git_remote_create(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_remote_create(PyObject *self, PyObject *args)
{
  git_remote * * x0;
  git_repository * x1;
  char const * x2;
  char const * x3;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "git_remote_create", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(393), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_remote * *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(393), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(56), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (git_repository *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(56), arg1) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg2, (char **)&x2);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x2 = (char const *)alloca((size_t)datasize);
    memset((void *)x2, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x2, _cffi_type(10), arg2) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg3, (char **)&x3);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x3 = (char const *)alloca((size_t)datasize);
    memset((void *)x3, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x3, _cffi_type(10), arg3) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_remote_create(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_remote_create _cffi_d_git_remote_create
#endif

static int _cffi_d_git_remote_create_with_fetchspec(git_remote * * x0, git_repository * x1, char const * x2, char const * x3, char const * x4)
{
  return git_remote_create_with_fetchspec(x0, x1, x2, x3, x4);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_remote_create_with_fetchspec(PyObject *self, PyObject *args)
{
  git_remote * * x0;
  git_repository * x1;
  char const * x2;
  char const * x3;
  char const * x4;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;

  if (!PyArg_UnpackTuple(args, "git_remote_create_with_fetchspec", 5, 5, &arg0, &arg1, &arg2, &arg3, &arg4))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(393), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_remote * *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(393), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(56), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (git_repository *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(56), arg1) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg2, (char **)&x2);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x2 = (char const *)alloca((size_t)datasize);
    memset((void *)x2, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x2, _cffi_type(10), arg2) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg3, (char **)&x3);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x3 = (char const *)alloca((size_t)datasize);
    memset((void *)x3, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x3, _cffi_type(10), arg3) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg4, (char **)&x4);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x4 = (char const *)alloca((size_t)datasize);
    memset((void *)x4, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x4, _cffi_type(10), arg4) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_remote_create_with_fetchspec(x0, x1, x2, x3, x4); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_remote_create_with_fetchspec _cffi_d_git_remote_create_with_fetchspec
#endif

static int _cffi_d_git_remote_delete(git_repository * x0, char const * x1)
{
  return git_remote_delete(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_remote_delete(PyObject *self, PyObject *args)
{
  git_repository * x0;
  char const * x1;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "git_remote_delete", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(56), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_repository *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(56), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (char const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(10), arg1) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_remote_delete(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_remote_delete _cffi_d_git_remote_delete
#endif

static int _cffi_d_git_remote_fetch(git_remote * x0, git_strarray const * x1, git_fetch_options const * x2, char const * x3)
{
  return git_remote_fetch(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_remote_fetch(PyObject *self, PyObject *args)
{
  git_remote * x0;
  git_strarray const * x1;
  git_fetch_options const * x2;
  char const * x3;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "git_remote_fetch", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(42), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_remote *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(42), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(311), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (git_strarray const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(311), arg1) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(424), arg2, (char **)&x2);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x2 = (git_fetch_options const *)alloca((size_t)datasize);
    memset((void *)x2, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x2, _cffi_type(424), arg2) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg3, (char **)&x3);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x3 = (char const *)alloca((size_t)datasize);
    memset((void *)x3, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x3, _cffi_type(10), arg3) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_remote_fetch(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_remote_fetch _cffi_d_git_remote_fetch
#endif

static void _cffi_d_git_remote_free(git_remote * x0)
{
  git_remote_free(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_remote_free(PyObject *self, PyObject *arg0)
{
  git_remote * x0;
  Py_ssize_t datasize;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(42), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_remote *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(42), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { git_remote_free(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_git_remote_free _cffi_d_git_remote_free
#endif

static int _cffi_d_git_remote_get_fetch_refspecs(git_strarray * x0, git_remote const * x1)
{
  return git_remote_get_fetch_refspecs(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_remote_get_fetch_refspecs(PyObject *self, PyObject *args)
{
  git_strarray * x0;
  git_remote const * x1;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "git_remote_get_fetch_refspecs", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(523), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_strarray *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(523), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(4), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (git_remote const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(4), arg1) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_remote_get_fetch_refspecs(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_remote_get_fetch_refspecs _cffi_d_git_remote_get_fetch_refspecs
#endif

static int _cffi_d_git_remote_get_push_refspecs(git_strarray * x0, git_remote const * x1)
{
  return git_remote_get_push_refspecs(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_remote_get_push_refspecs(PyObject *self, PyObject *args)
{
  git_strarray * x0;
  git_remote const * x1;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "git_remote_get_push_refspecs", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(523), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_strarray *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(523), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(4), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (git_remote const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(4), arg1) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_remote_get_push_refspecs(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_remote_get_push_refspecs _cffi_d_git_remote_get_push_refspecs
#endif

static git_refspec const * _cffi_d_git_remote_get_refspec(git_remote const * x0, size_t x1)
{
  return git_remote_get_refspec(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_remote_get_refspec(PyObject *self, PyObject *args)
{
  git_remote const * x0;
  size_t x1;
  Py_ssize_t datasize;
  git_refspec const * result;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "git_remote_get_refspec", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(4), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_remote const *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(4), arg0) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, size_t);
  if (x1 == (size_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_remote_get_refspec(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_pointer((char *)result, _cffi_type(1));
}
#else
#  define _cffi_f_git_remote_get_refspec _cffi_d_git_remote_get_refspec
#endif

static int _cffi_d_git_remote_init_callbacks(git_remote_callbacks * x0, unsigned int x1)
{
  return git_remote_init_callbacks(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_remote_init_callbacks(PyObject *self, PyObject *args)
{
  git_remote_callbacks * x0;
  unsigned int x1;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "git_remote_init_callbacks", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(433), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_remote_callbacks *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(433), arg0) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, unsigned int);
  if (x1 == (unsigned int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_remote_init_callbacks(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_remote_init_callbacks _cffi_d_git_remote_init_callbacks
#endif

static int _cffi_d_git_remote_list(git_strarray * x0, git_repository * x1)
{
  return git_remote_list(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_remote_list(PyObject *self, PyObject *args)
{
  git_strarray * x0;
  git_repository * x1;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "git_remote_list", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(523), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_strarray *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(523), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(56), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (git_repository *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(56), arg1) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_remote_list(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_remote_list _cffi_d_git_remote_list
#endif

static int _cffi_d_git_remote_lookup(git_remote * * x0, git_repository * x1, char const * x2)
{
  return git_remote_lookup(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_remote_lookup(PyObject *self, PyObject *args)
{
  git_remote * * x0;
  git_repository * x1;
  char const * x2;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "git_remote_lookup", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(393), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_remote * *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(393), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(56), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (git_repository *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(56), arg1) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg2, (char **)&x2);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x2 = (char const *)alloca((size_t)datasize);
    memset((void *)x2, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x2, _cffi_type(10), arg2) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_remote_lookup(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_remote_lookup _cffi_d_git_remote_lookup
#endif

static char const * _cffi_d_git_remote_name(git_remote const * x0)
{
  return git_remote_name(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_remote_name(PyObject *self, PyObject *arg0)
{
  git_remote const * x0;
  Py_ssize_t datasize;
  char const * result;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(4), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_remote const *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(4), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_remote_name(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_pointer((char *)result, _cffi_type(10));
}
#else
#  define _cffi_f_git_remote_name _cffi_d_git_remote_name
#endif

static int _cffi_d_git_remote_prune(git_remote * x0, git_remote_callbacks const * x1)
{
  return git_remote_prune(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_remote_prune(PyObject *self, PyObject *args)
{
  git_remote * x0;
  git_remote_callbacks const * x1;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "git_remote_prune", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(42), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_remote *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(42), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(419), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (git_remote_callbacks const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(419), arg1) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_remote_prune(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_remote_prune _cffi_d_git_remote_prune
#endif

static int _cffi_d_git_remote_push(git_remote * x0, git_strarray const * x1, git_push_options const * x2)
{
  return git_remote_push(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_remote_push(PyObject *self, PyObject *args)
{
  git_remote * x0;
  git_strarray const * x1;
  git_push_options const * x2;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "git_remote_push", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(42), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_remote *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(42), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(311), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (git_strarray const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(311), arg1) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(430), arg2, (char **)&x2);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x2 = (git_push_options const *)alloca((size_t)datasize);
    memset((void *)x2, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x2, _cffi_type(430), arg2) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_remote_push(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_remote_push _cffi_d_git_remote_push
#endif

static char const * _cffi_d_git_remote_pushurl(git_remote const * x0)
{
  return git_remote_pushurl(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_remote_pushurl(PyObject *self, PyObject *arg0)
{
  git_remote const * x0;
  Py_ssize_t datasize;
  char const * result;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(4), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_remote const *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(4), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_remote_pushurl(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_pointer((char *)result, _cffi_type(10));
}
#else
#  define _cffi_f_git_remote_pushurl _cffi_d_git_remote_pushurl
#endif

static size_t _cffi_d_git_remote_refspec_count(git_remote const * x0)
{
  return git_remote_refspec_count(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_remote_refspec_count(PyObject *self, PyObject *arg0)
{
  git_remote const * x0;
  Py_ssize_t datasize;
  size_t result;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(4), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_remote const *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(4), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_remote_refspec_count(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, size_t);
}
#else
#  define _cffi_f_git_remote_refspec_count _cffi_d_git_remote_refspec_count
#endif

static int _cffi_d_git_remote_rename(git_strarray * x0, git_repository * x1, char const * x2, char const * x3)
{
  return git_remote_rename(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_remote_rename(PyObject *self, PyObject *args)
{
  git_strarray * x0;
  git_repository * x1;
  char const * x2;
  char const * x3;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "git_remote_rename", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(523), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_strarray *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(523), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(56), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (git_repository *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(56), arg1) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg2, (char **)&x2);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x2 = (char const *)alloca((size_t)datasize);
    memset((void *)x2, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x2, _cffi_type(10), arg2) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg3, (char **)&x3);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x3 = (char const *)alloca((size_t)datasize);
    memset((void *)x3, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x3, _cffi_type(10), arg3) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_remote_rename(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_remote_rename _cffi_d_git_remote_rename
#endif

static int _cffi_d_git_remote_set_pushurl(git_repository * x0, char const * x1, char const * x2)
{
  return git_remote_set_pushurl(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_remote_set_pushurl(PyObject *self, PyObject *args)
{
  git_repository * x0;
  char const * x1;
  char const * x2;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "git_remote_set_pushurl", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(56), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_repository *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(56), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (char const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(10), arg1) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg2, (char **)&x2);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x2 = (char const *)alloca((size_t)datasize);
    memset((void *)x2, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x2, _cffi_type(10), arg2) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_remote_set_pushurl(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_remote_set_pushurl _cffi_d_git_remote_set_pushurl
#endif

static int _cffi_d_git_remote_set_url(git_repository * x0, char const * x1, char const * x2)
{
  return git_remote_set_url(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_remote_set_url(PyObject *self, PyObject *args)
{
  git_repository * x0;
  char const * x1;
  char const * x2;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "git_remote_set_url", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(56), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_repository *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(56), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (char const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(10), arg1) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg2, (char **)&x2);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x2 = (char const *)alloca((size_t)datasize);
    memset((void *)x2, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x2, _cffi_type(10), arg2) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_remote_set_url(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_remote_set_url _cffi_d_git_remote_set_url
#endif

static git_transfer_progress const * _cffi_d_git_remote_stats(git_remote * x0)
{
  return git_remote_stats(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_remote_stats(PyObject *self, PyObject *arg0)
{
  git_remote * x0;
  Py_ssize_t datasize;
  git_transfer_progress const * result;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(42), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_remote *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(42), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_remote_stats(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_pointer((char *)result, _cffi_type(551));
}
#else
#  define _cffi_f_git_remote_stats _cffi_d_git_remote_stats
#endif

static char const * _cffi_d_git_remote_url(git_remote const * x0)
{
  return git_remote_url(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_remote_url(PyObject *self, PyObject *arg0)
{
  git_remote const * x0;
  Py_ssize_t datasize;
  char const * result;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(4), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_remote const *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(4), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_remote_url(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_pointer((char *)result, _cffi_type(10));
}
#else
#  define _cffi_f_git_remote_url _cffi_d_git_remote_url
#endif

static int _cffi_d_git_repository_config(git_config * * x0, git_repository * x1)
{
  return git_repository_config(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_repository_config(PyObject *self, PyObject *args)
{
  git_config * * x0;
  git_repository * x1;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "git_repository_config", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(123), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_config * *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(123), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(56), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (git_repository *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(56), arg1) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_repository_config(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_repository_config _cffi_d_git_repository_config
#endif

static int _cffi_d_git_repository_config_snapshot(git_config * * x0, git_repository * x1)
{
  return git_repository_config_snapshot(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_repository_config_snapshot(PyObject *self, PyObject *args)
{
  git_config * * x0;
  git_repository * x1;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "git_repository_config_snapshot", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(123), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_config * *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(123), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(56), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (git_repository *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(56), arg1) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_repository_config_snapshot(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_repository_config_snapshot _cffi_d_git_repository_config_snapshot
#endif

static void _cffi_d_git_repository_free(git_repository * x0)
{
  git_repository_free(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_repository_free(PyObject *self, PyObject *arg0)
{
  git_repository * x0;
  Py_ssize_t datasize;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(56), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_repository *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(56), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { git_repository_free(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_git_repository_free _cffi_d_git_repository_free
#endif

static int _cffi_d_git_repository_ident(char const * * x0, char const * * x1, git_repository const * x2)
{
  return git_repository_ident(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_repository_ident(PyObject *self, PyObject *args)
{
  char const * * x0;
  char const * * x1;
  git_repository const * x2;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "git_repository_ident", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(45), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (char const * *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(45), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(45), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (char const * *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(45), arg1) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(47), arg2, (char **)&x2);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x2 = (git_repository const *)alloca((size_t)datasize);
    memset((void *)x2, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x2, _cffi_type(47), arg2) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_repository_ident(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_repository_ident _cffi_d_git_repository_ident
#endif

static int _cffi_d_git_repository_index(git_index * * x0, git_repository * x1)
{
  return git_repository_index(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_repository_index(PyObject *self, PyObject *args)
{
  git_index * * x0;
  git_repository * x1;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "git_repository_index", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(263), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_index * *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(263), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(56), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (git_repository *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(56), arg1) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_repository_index(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_repository_index _cffi_d_git_repository_index
#endif

static int _cffi_d_git_repository_init(git_repository * * x0, char const * x1, unsigned int x2)
{
  return git_repository_init(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_repository_init(PyObject *self, PyObject *args)
{
  git_repository * * x0;
  char const * x1;
  unsigned int x2;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "git_repository_init", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(441), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_repository * *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(441), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (char const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(10), arg1) < 0)
      return NULL;
  }

  x2 = _cffi_to_c_int(arg2, unsigned int);
  if (x2 == (unsigned int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_repository_init(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_repository_init _cffi_d_git_repository_init
#endif

static int _cffi_d_git_repository_init_ext(git_repository * * x0, char const * x1, git_repository_init_options * x2)
{
  return git_repository_init_ext(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_repository_init_ext(PyObject *self, PyObject *args)
{
  git_repository * * x0;
  char const * x1;
  git_repository_init_options * x2;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "git_repository_init_ext", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(441), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_repository * *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(441), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (char const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(10), arg1) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(449), arg2, (char **)&x2);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x2 = (git_repository_init_options *)alloca((size_t)datasize);
    memset((void *)x2, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x2, _cffi_type(449), arg2) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_repository_init_ext(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_repository_init_ext _cffi_d_git_repository_init_ext
#endif

static int _cffi_d_git_repository_init_init_options(git_repository_init_options * x0, unsigned int x1)
{
  return git_repository_init_init_options(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_repository_init_init_options(PyObject *self, PyObject *args)
{
  git_repository_init_options * x0;
  unsigned int x1;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "git_repository_init_init_options", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(449), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_repository_init_options *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(449), arg0) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, unsigned int);
  if (x1 == (unsigned int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_repository_init_init_options(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_repository_init_init_options _cffi_d_git_repository_init_init_options
#endif

static int _cffi_d_git_repository_set_head(git_repository * x0, char const * x1)
{
  return git_repository_set_head(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_repository_set_head(PyObject *self, PyObject *args)
{
  git_repository * x0;
  char const * x1;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "git_repository_set_head", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(56), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_repository *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(56), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (char const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(10), arg1) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_repository_set_head(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_repository_set_head _cffi_d_git_repository_set_head
#endif

static int _cffi_d_git_repository_set_head_detached(git_repository * x0, git_oid const * x1)
{
  return git_repository_set_head_detached(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_repository_set_head_detached(PyObject *self, PyObject *args)
{
  git_repository * x0;
  git_oid const * x1;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "git_repository_set_head_detached", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(56), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_repository *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(56), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(68), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (git_oid const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(68), arg1) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_repository_set_head_detached(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_repository_set_head_detached _cffi_d_git_repository_set_head_detached
#endif

static int _cffi_d_git_repository_set_ident(git_repository * x0, char const * x1, char const * x2)
{
  return git_repository_set_ident(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_repository_set_ident(PyObject *self, PyObject *args)
{
  git_repository * x0;
  char const * x1;
  char const * x2;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "git_repository_set_ident", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(56), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_repository *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(56), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (char const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(10), arg1) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg2, (char **)&x2);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x2 = (char const *)alloca((size_t)datasize);
    memset((void *)x2, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x2, _cffi_type(10), arg2) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_repository_set_ident(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_repository_set_ident _cffi_d_git_repository_set_ident
#endif

static int _cffi_d_git_repository_state_cleanup(git_repository * x0)
{
  return git_repository_state_cleanup(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_repository_state_cleanup(PyObject *self, PyObject *arg0)
{
  git_repository * x0;
  Py_ssize_t datasize;
  int result;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(56), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_repository *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(56), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_repository_state_cleanup(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_repository_state_cleanup _cffi_d_git_repository_state_cleanup
#endif

static int _cffi_d_git_revert_commit(git_index * * x0, git_repository * x1, git_commit * x2, git_commit * x3, unsigned int x4, git_merge_options const * x5)
{
  return git_revert_commit(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_revert_commit(PyObject *self, PyObject *args)
{
  git_index * * x0;
  git_repository * x1;
  git_commit * x2;
  git_commit * x3;
  unsigned int x4;
  git_merge_options const * x5;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "git_revert_commit", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(263), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_index * *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(263), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(56), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (git_repository *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(56), arg1) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(273), arg2, (char **)&x2);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x2 = (git_commit *)alloca((size_t)datasize);
    memset((void *)x2, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x2, _cffi_type(273), arg2) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(273), arg3, (char **)&x3);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x3 = (git_commit *)alloca((size_t)datasize);
    memset((void *)x3, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x3, _cffi_type(273), arg3) < 0)
      return NULL;
  }

  x4 = _cffi_to_c_int(arg4, unsigned int);
  if (x4 == (unsigned int)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(276), arg5, (char **)&x5);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x5 = (git_merge_options const *)alloca((size_t)datasize);
    memset((void *)x5, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x5, _cffi_type(276), arg5) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_revert_commit(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_revert_commit _cffi_d_git_revert_commit
#endif

static int _cffi_d_git_stash_apply(git_repository * x0, size_t x1, git_stash_apply_options const * x2)
{
  return git_stash_apply(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_stash_apply(PyObject *self, PyObject *args)
{
  git_repository * x0;
  size_t x1;
  git_stash_apply_options const * x2;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "git_stash_apply", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(56), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_repository *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(56), arg0) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, size_t);
  if (x1 == (size_t)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(508), arg2, (char **)&x2);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x2 = (git_stash_apply_options const *)alloca((size_t)datasize);
    memset((void *)x2, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x2, _cffi_type(508), arg2) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_stash_apply(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_stash_apply _cffi_d_git_stash_apply
#endif

static int _cffi_d_git_stash_apply_init_options(git_stash_apply_options * x0, unsigned int x1)
{
  return git_stash_apply_init_options(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_stash_apply_init_options(PyObject *self, PyObject *args)
{
  git_stash_apply_options * x0;
  unsigned int x1;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "git_stash_apply_init_options", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(515), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_stash_apply_options *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(515), arg0) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, unsigned int);
  if (x1 == (unsigned int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_stash_apply_init_options(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_stash_apply_init_options _cffi_d_git_stash_apply_init_options
#endif

static int _cffi_d_git_stash_drop(git_repository * x0, size_t x1)
{
  return git_stash_drop(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_stash_drop(PyObject *self, PyObject *args)
{
  git_repository * x0;
  size_t x1;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "git_stash_drop", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(56), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_repository *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(56), arg0) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, size_t);
  if (x1 == (size_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_stash_drop(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_stash_drop _cffi_d_git_stash_drop
#endif

static int _cffi_d_git_stash_foreach(git_repository * x0, int(* x1)(size_t, char const *, git_oid const *, void *), void * x2)
{
  return git_stash_foreach(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_stash_foreach(PyObject *self, PyObject *args)
{
  git_repository * x0;
  int(* x1)(size_t, char const *, git_oid const *, void *);
  void * x2;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "git_stash_foreach", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(56), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_repository *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(56), arg0) < 0)
      return NULL;
  }

  x1 = (int(*)(size_t, char const *, git_oid const *, void *))_cffi_to_c_pointer(arg1, _cffi_type(498));
  if (x1 == (int(*)(size_t, char const *, git_oid const *, void *))NULL && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(64), arg2, (char **)&x2);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x2 = (void *)alloca((size_t)datasize);
    memset((void *)x2, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x2, _cffi_type(64), arg2) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_stash_foreach(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_stash_foreach _cffi_d_git_stash_foreach
#endif

static int _cffi_d_git_stash_pop(git_repository * x0, size_t x1, git_stash_apply_options const * x2)
{
  return git_stash_pop(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_stash_pop(PyObject *self, PyObject *args)
{
  git_repository * x0;
  size_t x1;
  git_stash_apply_options const * x2;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "git_stash_pop", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(56), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_repository *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(56), arg0) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, size_t);
  if (x1 == (size_t)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(508), arg2, (char **)&x2);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x2 = (git_stash_apply_options const *)alloca((size_t)datasize);
    memset((void *)x2, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x2, _cffi_type(508), arg2) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_stash_pop(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_stash_pop _cffi_d_git_stash_pop
#endif

static int _cffi_d_git_stash_save(git_oid * x0, git_repository * x1, git_signature const * x2, char const * x3, uint32_t x4)
{
  return git_stash_save(x0, x1, x2, x3, x4);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_stash_save(PyObject *self, PyObject *args)
{
  git_oid * x0;
  git_repository * x1;
  git_signature const * x2;
  char const * x3;
  uint32_t x4;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;

  if (!PyArg_UnpackTuple(args, "git_stash_save", 5, 5, &arg0, &arg1, &arg2, &arg3, &arg4))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(357), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_oid *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(357), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(56), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (git_repository *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(56), arg1) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(368), arg2, (char **)&x2);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x2 = (git_signature const *)alloca((size_t)datasize);
    memset((void *)x2, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x2, _cffi_type(368), arg2) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg3, (char **)&x3);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x3 = (char const *)alloca((size_t)datasize);
    memset((void *)x3, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x3, _cffi_type(10), arg3) < 0)
      return NULL;
  }

  x4 = _cffi_to_c_int(arg4, uint32_t);
  if (x4 == (uint32_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_stash_save(x0, x1, x2, x3, x4); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_stash_save _cffi_d_git_stash_save
#endif

static void _cffi_d_git_strarray_free(git_strarray * x0)
{
  git_strarray_free(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_strarray_free(PyObject *self, PyObject *arg0)
{
  git_strarray * x0;
  Py_ssize_t datasize;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(523), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_strarray *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(523), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { git_strarray_free(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_git_strarray_free _cffi_d_git_strarray_free
#endif

static char const * _cffi_d_git_submodule_branch(git_submodule * x0)
{
  return git_submodule_branch(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_submodule_branch(PyObject *self, PyObject *arg0)
{
  git_submodule * x0;
  Py_ssize_t datasize;
  char const * result;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(7), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_submodule *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(7), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_submodule_branch(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_pointer((char *)result, _cffi_type(10));
}
#else
#  define _cffi_f_git_submodule_branch _cffi_d_git_submodule_branch
#endif

static void _cffi_d_git_submodule_free(git_submodule * x0)
{
  git_submodule_free(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_submodule_free(PyObject *self, PyObject *arg0)
{
  git_submodule * x0;
  Py_ssize_t datasize;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(7), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_submodule *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(7), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { git_submodule_free(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_git_submodule_free _cffi_d_git_submodule_free
#endif

static git_oid const * _cffi_d_git_submodule_head_id(git_submodule * x0)
{
  return git_submodule_head_id(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_submodule_head_id(PyObject *self, PyObject *arg0)
{
  git_submodule * x0;
  Py_ssize_t datasize;
  git_oid const * result;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(7), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_submodule *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(7), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_submodule_head_id(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_pointer((char *)result, _cffi_type(68));
}
#else
#  define _cffi_f_git_submodule_head_id _cffi_d_git_submodule_head_id
#endif

static int _cffi_d_git_submodule_lookup(git_submodule * * x0, git_repository * x1, char const * x2)
{
  return git_submodule_lookup(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_submodule_lookup(PyObject *self, PyObject *args)
{
  git_submodule * * x0;
  git_repository * x1;
  char const * x2;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "git_submodule_lookup", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(537), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_submodule * *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(537), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(56), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (git_repository *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(56), arg1) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg2, (char **)&x2);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x2 = (char const *)alloca((size_t)datasize);
    memset((void *)x2, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x2, _cffi_type(10), arg2) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_submodule_lookup(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_submodule_lookup _cffi_d_git_submodule_lookup
#endif

static char const * _cffi_d_git_submodule_name(git_submodule * x0)
{
  return git_submodule_name(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_submodule_name(PyObject *self, PyObject *arg0)
{
  git_submodule * x0;
  Py_ssize_t datasize;
  char const * result;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(7), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_submodule *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(7), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_submodule_name(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_pointer((char *)result, _cffi_type(10));
}
#else
#  define _cffi_f_git_submodule_name _cffi_d_git_submodule_name
#endif

static int _cffi_d_git_submodule_open(git_repository * * x0, git_submodule * x1)
{
  return git_submodule_open(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_submodule_open(PyObject *self, PyObject *args)
{
  git_repository * * x0;
  git_submodule * x1;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "git_submodule_open", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(441), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_repository * *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(441), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(7), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (git_submodule *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(7), arg1) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_submodule_open(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_submodule_open _cffi_d_git_submodule_open
#endif

static char const * _cffi_d_git_submodule_path(git_submodule * x0)
{
  return git_submodule_path(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_submodule_path(PyObject *self, PyObject *arg0)
{
  git_submodule * x0;
  Py_ssize_t datasize;
  char const * result;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(7), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_submodule *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(7), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_submodule_path(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_pointer((char *)result, _cffi_type(10));
}
#else
#  define _cffi_f_git_submodule_path _cffi_d_git_submodule_path
#endif

static int _cffi_d_git_submodule_update(git_submodule * x0, int x1, git_submodule_update_options * x2)
{
  return git_submodule_update(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_submodule_update(PyObject *self, PyObject *args)
{
  git_submodule * x0;
  int x1;
  git_submodule_update_options * x2;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "git_submodule_update", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(7), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_submodule *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(7), arg0) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, int);
  if (x1 == (int)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(544), arg2, (char **)&x2);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x2 = (git_submodule_update_options *)alloca((size_t)datasize);
    memset((void *)x2, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x2, _cffi_type(544), arg2) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_submodule_update(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_submodule_update _cffi_d_git_submodule_update
#endif

static int _cffi_d_git_submodule_update_init_options(git_submodule_update_options * x0, unsigned int x1)
{
  return git_submodule_update_init_options(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_submodule_update_init_options(PyObject *self, PyObject *args)
{
  git_submodule_update_options * x0;
  unsigned int x1;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "git_submodule_update_init_options", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(544), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_submodule_update_options *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(544), arg0) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, unsigned int);
  if (x1 == (unsigned int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_submodule_update_init_options(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_submodule_update_init_options _cffi_d_git_submodule_update_init_options
#endif

static char const * _cffi_d_git_submodule_url(git_submodule * x0)
{
  return git_submodule_url(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_submodule_url(PyObject *self, PyObject *arg0)
{
  git_submodule * x0;
  Py_ssize_t datasize;
  char const * result;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(7), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_submodule *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(7), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_submodule_url(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_pointer((char *)result, _cffi_type(10));
}
#else
#  define _cffi_f_git_submodule_url _cffi_d_git_submodule_url
#endif

static int _cffi_const_GIT_ATTR_CHECK_FILE_THEN_INDEX(unsigned long long *o)
{
  int n = (GIT_ATTR_CHECK_FILE_THEN_INDEX) <= 0;
  *o = (unsigned long long)((GIT_ATTR_CHECK_FILE_THEN_INDEX) | 0);  /* check that GIT_ATTR_CHECK_FILE_THEN_INDEX is an integer */
  if (!_cffi_check_int(*o, n, 0))
    n |= 2;
  return n;
}

static int _cffi_const_GIT_ATTR_CHECK_INDEX_ONLY(unsigned long long *o)
{
  int n = (GIT_ATTR_CHECK_INDEX_ONLY) <= 0;
  *o = (unsigned long long)((GIT_ATTR_CHECK_INDEX_ONLY) | 0);  /* check that GIT_ATTR_CHECK_INDEX_ONLY is an integer */
  if (!_cffi_check_int(*o, n, 2U))
    n |= 2;
  return n;
}

static int _cffi_const_GIT_ATTR_CHECK_INDEX_THEN_FILE(unsigned long long *o)
{
  int n = (GIT_ATTR_CHECK_INDEX_THEN_FILE) <= 0;
  *o = (unsigned long long)((GIT_ATTR_CHECK_INDEX_THEN_FILE) | 0);  /* check that GIT_ATTR_CHECK_INDEX_THEN_FILE is an integer */
  if (!_cffi_check_int(*o, n, 1U))
    n |= 2;
  return n;
}

static int _cffi_const_GIT_ATTR_CHECK_NO_SYSTEM(unsigned long long *o)
{
  int n = (GIT_ATTR_CHECK_NO_SYSTEM) <= 0;
  *o = (unsigned long long)((GIT_ATTR_CHECK_NO_SYSTEM) | 0);  /* check that GIT_ATTR_CHECK_NO_SYSTEM is an integer */
  if (!_cffi_check_int(*o, n, 4U))
    n |= 2;
  return n;
}

static int _cffi_const_GIT_BLAME_OPTIONS_VERSION(unsigned long long *o)
{
  int n = (GIT_BLAME_OPTIONS_VERSION) <= 0;
  *o = (unsigned long long)((GIT_BLAME_OPTIONS_VERSION) | 0);  /* check that GIT_BLAME_OPTIONS_VERSION is an integer */
  return n;
}

static int _cffi_const_GIT_CLONE_OPTIONS_VERSION(unsigned long long *o)
{
  int n = (GIT_CLONE_OPTIONS_VERSION) <= 0;
  *o = (unsigned long long)((GIT_CLONE_OPTIONS_VERSION) | 0);  /* check that GIT_CLONE_OPTIONS_VERSION is an integer */
  return n;
}

static int _cffi_const_GIT_DESCRIBE_FORMAT_OPTIONS_VERSION(unsigned long long *o)
{
  int n = (GIT_DESCRIBE_FORMAT_OPTIONS_VERSION) <= 0;
  *o = (unsigned long long)((GIT_DESCRIBE_FORMAT_OPTIONS_VERSION) | 0);  /* check that GIT_DESCRIBE_FORMAT_OPTIONS_VERSION is an integer */
  if (!_cffi_check_int(*o, n, 1U))
    n |= 2;
  return n;
}

static int _cffi_const_GIT_DESCRIBE_OPTIONS_VERSION(unsigned long long *o)
{
  int n = (GIT_DESCRIBE_OPTIONS_VERSION) <= 0;
  *o = (unsigned long long)((GIT_DESCRIBE_OPTIONS_VERSION) | 0);  /* check that GIT_DESCRIBE_OPTIONS_VERSION is an integer */
  if (!_cffi_check_int(*o, n, 1U))
    n |= 2;
  return n;
}

static int _cffi_const_GIT_FETCH_OPTIONS_VERSION(unsigned long long *o)
{
  int n = (GIT_FETCH_OPTIONS_VERSION) <= 0;
  *o = (unsigned long long)((GIT_FETCH_OPTIONS_VERSION) | 0);  /* check that GIT_FETCH_OPTIONS_VERSION is an integer */
  return n;
}

static int _cffi_const_GIT_MERGE_OPTIONS_VERSION(unsigned long long *o)
{
  int n = (GIT_MERGE_OPTIONS_VERSION) <= 0;
  *o = (unsigned long long)((GIT_MERGE_OPTIONS_VERSION) | 0);  /* check that GIT_MERGE_OPTIONS_VERSION is an integer */
  if (!_cffi_check_int(*o, n, 1U))
    n |= 2;
  return n;
}

static int _cffi_const_GIT_PATH_MAX(unsigned long long *o)
{
  int n = (GIT_PATH_MAX) <= 0;
  *o = (unsigned long long)((GIT_PATH_MAX) | 0);  /* check that GIT_PATH_MAX is an integer */
  return n;
}

static int _cffi_const_GIT_PROXY_OPTIONS_VERSION(unsigned long long *o)
{
  int n = (GIT_PROXY_OPTIONS_VERSION) <= 0;
  *o = (unsigned long long)((GIT_PROXY_OPTIONS_VERSION) | 0);  /* check that GIT_PROXY_OPTIONS_VERSION is an integer */
  return n;
}

static int _cffi_const_GIT_PUSH_OPTIONS_VERSION(unsigned long long *o)
{
  int n = (GIT_PUSH_OPTIONS_VERSION) <= 0;
  *o = (unsigned long long)((GIT_PUSH_OPTIONS_VERSION) | 0);  /* check that GIT_PUSH_OPTIONS_VERSION is an integer */
  return n;
}

static int _cffi_const_GIT_REMOTE_CALLBACKS_VERSION(unsigned long long *o)
{
  int n = (GIT_REMOTE_CALLBACKS_VERSION) <= 0;
  *o = (unsigned long long)((GIT_REMOTE_CALLBACKS_VERSION) | 0);  /* check that GIT_REMOTE_CALLBACKS_VERSION is an integer */
  return n;
}

static int _cffi_const_GIT_REPOSITORY_INIT_OPTIONS_VERSION(unsigned long long *o)
{
  int n = (GIT_REPOSITORY_INIT_OPTIONS_VERSION) <= 0;
  *o = (unsigned long long)((GIT_REPOSITORY_INIT_OPTIONS_VERSION) | 0);  /* check that GIT_REPOSITORY_INIT_OPTIONS_VERSION is an integer */
  return n;
}

static int _cffi_const_GIT_STASH_APPLY_OPTIONS_VERSION(unsigned long long *o)
{
  int n = (GIT_STASH_APPLY_OPTIONS_VERSION) <= 0;
  *o = (unsigned long long)((GIT_STASH_APPLY_OPTIONS_VERSION) | 0);  /* check that GIT_STASH_APPLY_OPTIONS_VERSION is an integer */
  if (!_cffi_check_int(*o, n, 1U))
    n |= 2;
  return n;
}

static int _cffi_const_GIT_SUBMODULE_UPDATE_OPTIONS_VERSION(unsigned long long *o)
{
  int n = (GIT_SUBMODULE_UPDATE_OPTIONS_VERSION) <= 0;
  *o = (unsigned long long)((GIT_SUBMODULE_UPDATE_OPTIONS_VERSION) | 0);  /* check that GIT_SUBMODULE_UPDATE_OPTIONS_VERSION is an integer */
  return n;
}

_CFFI_UNUSED_FN
static void _cffi_checkfld__git_blame_hunk(git_blame_hunk *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  (void)((p->lines_in_hunk) | 0);  /* check that 'git_blame_hunk.lines_in_hunk' is an integer */
  { git_oid *tmp = &p->final_commit_id; (void)tmp; }
  (void)((p->final_start_line_number) | 0);  /* check that 'git_blame_hunk.final_start_line_number' is an integer */
  { git_signature * *tmp = &p->final_signature; (void)tmp; }
  { git_oid *tmp = &p->orig_commit_id; (void)tmp; }
  { char const * *tmp = &p->orig_path; (void)tmp; }
  (void)((p->orig_start_line_number) | 0);  /* check that 'git_blame_hunk.orig_start_line_number' is an integer */
  { git_signature * *tmp = &p->orig_signature; (void)tmp; }
  { char *tmp = &p->boundary; (void)tmp; }
}
struct _cffi_align__git_blame_hunk { char x; git_blame_hunk y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld__git_blame_options(git_blame_options *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  (void)((p->version) | 0);  /* check that 'git_blame_options.version' is an integer */
  (void)((p->flags) | 0);  /* check that 'git_blame_options.flags' is an integer */
  (void)((p->min_match_characters) | 0);  /* check that 'git_blame_options.min_match_characters' is an integer */
  { git_oid *tmp = &p->newest_commit; (void)tmp; }
  { git_oid *tmp = &p->oldest_commit; (void)tmp; }
  (void)((p->min_line) | 0);  /* check that 'git_blame_options.min_line' is an integer */
  (void)((p->max_line) | 0);  /* check that 'git_blame_options.max_line' is an integer */
}
struct _cffi_align__git_blame_options { char x; git_blame_options y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld__git_checkout_options(git_checkout_options *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  (void)((p->version) | 0);  /* check that 'git_checkout_options.version' is an integer */
  (void)((p->checkout_strategy) | 0);  /* check that 'git_checkout_options.checkout_strategy' is an integer */
  (void)((p->disable_filters) | 0);  /* check that 'git_checkout_options.disable_filters' is an integer */
  (void)((p->dir_mode) | 0);  /* check that 'git_checkout_options.dir_mode' is an integer */
  (void)((p->file_mode) | 0);  /* check that 'git_checkout_options.file_mode' is an integer */
  (void)((p->file_open_flags) | 0);  /* check that 'git_checkout_options.file_open_flags' is an integer */
  (void)((p->notify_flags) | 0);  /* check that 'git_checkout_options.notify_flags' is an integer */
  { int(* *tmp)(git_checkout_notify_t, char const *, git_diff_file const *, git_diff_file const *, git_diff_file const *, void *) = &p->notify_cb; (void)tmp; }
  { void * *tmp = &p->notify_payload; (void)tmp; }
  { void(* *tmp)(char const *, size_t, size_t, void *) = &p->progress_cb; (void)tmp; }
  { void * *tmp = &p->progress_payload; (void)tmp; }
  { git_strarray *tmp = &p->paths; (void)tmp; }
  { git_tree * *tmp = &p->baseline; (void)tmp; }
  { git_index * *tmp = &p->baseline_index; (void)tmp; }
  { char const * *tmp = &p->target_directory; (void)tmp; }
  { char const * *tmp = &p->ancestor_label; (void)tmp; }
  { char const * *tmp = &p->our_label; (void)tmp; }
  { char const * *tmp = &p->their_label; (void)tmp; }
  { void(* *tmp)(git_checkout_perfdata const *, void *) = &p->perfdata_cb; (void)tmp; }
  { void * *tmp = &p->perfdata_payload; (void)tmp; }
}
struct _cffi_align__git_checkout_options { char x; git_checkout_options y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld__git_clone_options(git_clone_options *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  (void)((p->version) | 0);  /* check that 'git_clone_options.version' is an integer */
  { git_checkout_options *tmp = &p->checkout_opts; (void)tmp; }
  { git_fetch_options *tmp = &p->fetch_opts; (void)tmp; }
  (void)((p->bare) | 0);  /* check that 'git_clone_options.bare' is an integer */
  { git_clone_local_t *tmp = &p->local; (void)tmp; }
  { char const * *tmp = &p->checkout_branch; (void)tmp; }
  { int(* *tmp)(git_repository * *, char const *, int, void *) = &p->repository_cb; (void)tmp; }
  { void * *tmp = &p->repository_cb_payload; (void)tmp; }
  { int(* *tmp)(git_remote * *, git_repository *, char const *, char const *, void *) = &p->remote_cb; (void)tmp; }
  { void * *tmp = &p->remote_cb_payload; (void)tmp; }
}
struct _cffi_align__git_clone_options { char x; git_clone_options y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld__git_config_entry(git_config_entry *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { char const * *tmp = &p->name; (void)tmp; }
  { char const * *tmp = &p->value; (void)tmp; }
  (void)((p->include_depth) | 0);  /* check that 'git_config_entry.include_depth' is an integer */
  { git_config_level_t *tmp = &p->level; (void)tmp; }
  { void(* *tmp)(git_config_entry *) = &p->free; (void)tmp; }
  { void * *tmp = &p->payload; (void)tmp; }
}
struct _cffi_align__git_config_entry { char x; git_config_entry y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld__git_describe_options(git_describe_options *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  (void)((p->version) | 0);  /* check that 'git_describe_options.version' is an integer */
  (void)((p->max_candidates_tags) | 0);  /* check that 'git_describe_options.max_candidates_tags' is an integer */
  (void)((p->describe_strategy) | 0);  /* check that 'git_describe_options.describe_strategy' is an integer */
  { char const * *tmp = &p->pattern; (void)tmp; }
  (void)((p->only_follow_first_parent) | 0);  /* check that 'git_describe_options.only_follow_first_parent' is an integer */
  (void)((p->show_commit_oid_as_fallback) | 0);  /* check that 'git_describe_options.show_commit_oid_as_fallback' is an integer */
}
struct _cffi_align__git_describe_options { char x; git_describe_options y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld__git_index_entry(git_index_entry *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { git_index_time *tmp = &p->ctime; (void)tmp; }
  { git_index_time *tmp = &p->mtime; (void)tmp; }
  (void)((p->dev) | 0);  /* check that 'git_index_entry.dev' is an integer */
  (void)((p->ino) | 0);  /* check that 'git_index_entry.ino' is an integer */
  (void)((p->mode) | 0);  /* check that 'git_index_entry.mode' is an integer */
  (void)((p->uid) | 0);  /* check that 'git_index_entry.uid' is an integer */
  (void)((p->gid) | 0);  /* check that 'git_index_entry.gid' is an integer */
  (void)((p->file_size) | 0);  /* check that 'git_index_entry.file_size' is an integer */
  { git_oid *tmp = &p->id; (void)tmp; }
  (void)((p->flags) | 0);  /* check that 'git_index_entry.flags' is an integer */
  (void)((p->flags_extended) | 0);  /* check that 'git_index_entry.flags_extended' is an integer */
  { char const * *tmp = &p->path; (void)tmp; }
}
struct _cffi_align__git_index_entry { char x; git_index_entry y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld__git_oid(git_oid *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { unsigned char(*tmp)[20] = &p->id; (void)tmp; }
}
struct _cffi_align__git_oid { char x; git_oid y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld__git_remote_callbacks(git_remote_callbacks *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  (void)((p->version) | 0);  /* check that 'git_remote_callbacks.version' is an integer */
  { int(* *tmp)(char const *, int, void *) = &p->sideband_progress; (void)tmp; }
  { int(* *tmp)(git_remote_completion_type, void *) = &p->completion; (void)tmp; }
  { int(* *tmp)(git_cred * *, char const *, char const *, unsigned int, void *) = &p->credentials; (void)tmp; }
  { int(* *tmp)(git_cert *, int, char const *, void *) = &p->certificate_check; (void)tmp; }
  { int(* *tmp)(git_transfer_progress const *, void *) = &p->transfer_progress; (void)tmp; }
  { int(* *tmp)(char const *, git_oid const *, git_oid const *, void *) = &p->update_tips; (void)tmp; }
  { int(* *tmp)(int, uint32_t, uint32_t, void *) = &p->pack_progress; (void)tmp; }
  { int(* *tmp)(unsigned int, unsigned int, size_t, void *) = &p->push_transfer_progress; (void)tmp; }
  { int(* *tmp)(char const *, char const *, void *) = &p->push_update_reference; (void)tmp; }
  { int(* *tmp)(git_push_update const * *, size_t, void *) = &p->push_negotiation; (void)tmp; }
  { int(* *tmp)(git_transport * *, git_remote *, void *) = &p->transport; (void)tmp; }
  { void * *tmp = &p->payload; (void)tmp; }
}
struct _cffi_align__git_remote_callbacks { char x; git_remote_callbacks y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld__git_signature(git_signature *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { char * *tmp = &p->name; (void)tmp; }
  { char * *tmp = &p->email; (void)tmp; }
  { git_time *tmp = &p->when; (void)tmp; }
}
struct _cffi_align__git_signature { char x; git_signature y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld__git_stash_apply_options(git_stash_apply_options *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  (void)((p->version) | 0);  /* check that 'git_stash_apply_options.version' is an integer */
  { git_stash_apply_flags *tmp = &p->flags; (void)tmp; }
  { git_checkout_options *tmp = &p->checkout_options; (void)tmp; }
  { int(* *tmp)(git_stash_apply_progress_t, void *) = &p->progress_cb; (void)tmp; }
  { void * *tmp = &p->progress_payload; (void)tmp; }
}
struct _cffi_align__git_stash_apply_options { char x; git_stash_apply_options y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld__git_strarray(git_strarray *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { char * * *tmp = &p->strings; (void)tmp; }
  (void)((p->count) | 0);  /* check that 'git_strarray.count' is an integer */
}
struct _cffi_align__git_strarray { char x; git_strarray y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld__git_submodule_update_options(git_submodule_update_options *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  (void)((p->version) | 0);  /* check that 'git_submodule_update_options.version' is an integer */
  { git_checkout_options *tmp = &p->checkout_opts; (void)tmp; }
  { git_fetch_options *tmp = &p->fetch_opts; (void)tmp; }
  (void)((p->allow_fetch) | 0);  /* check that 'git_submodule_update_options.allow_fetch' is an integer */
}
struct _cffi_align__git_submodule_update_options { char x; git_submodule_update_options y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld__git_time(git_time *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  (void)((p->time) | 0);  /* check that 'git_time.time' is an integer */
  (void)((p->offset) | 0);  /* check that 'git_time.offset' is an integer */
  { char *tmp = &p->sign; (void)tmp; }
}
struct _cffi_align__git_time { char x; git_time y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld__git_transfer_progress(git_transfer_progress *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  (void)((p->total_objects) | 0);  /* check that 'git_transfer_progress.total_objects' is an integer */
  (void)((p->indexed_objects) | 0);  /* check that 'git_transfer_progress.indexed_objects' is an integer */
  (void)((p->received_objects) | 0);  /* check that 'git_transfer_progress.received_objects' is an integer */
  (void)((p->local_objects) | 0);  /* check that 'git_transfer_progress.local_objects' is an integer */
  (void)((p->total_deltas) | 0);  /* check that 'git_transfer_progress.total_deltas' is an integer */
  (void)((p->indexed_deltas) | 0);  /* check that 'git_transfer_progress.indexed_deltas' is an integer */
  (void)((p->received_bytes) | 0);  /* check that 'git_transfer_progress.received_bytes' is an integer */
}
struct _cffi_align__git_transfer_progress { char x; git_transfer_progress y; };

static const struct _cffi_global_s _cffi_globals[] = {
  { "GIT_ATTR_CHECK_FILE_THEN_INDEX", (void *)_cffi_const_GIT_ATTR_CHECK_FILE_THEN_INDEX, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "GIT_ATTR_CHECK_INDEX_ONLY", (void *)_cffi_const_GIT_ATTR_CHECK_INDEX_ONLY, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "GIT_ATTR_CHECK_INDEX_THEN_FILE", (void *)_cffi_const_GIT_ATTR_CHECK_INDEX_THEN_FILE, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "GIT_ATTR_CHECK_NO_SYSTEM", (void *)_cffi_const_GIT_ATTR_CHECK_NO_SYSTEM, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "GIT_ATTR_FALSE_T", (void *)_cffi_const_GIT_ATTR_FALSE_T, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_ATTR_TRUE_T", (void *)_cffi_const_GIT_ATTR_TRUE_T, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_ATTR_UNSPECIFIED_T", (void *)_cffi_const_GIT_ATTR_UNSPECIFIED_T, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_ATTR_VALUE_T", (void *)_cffi_const_GIT_ATTR_VALUE_T, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_BLAME_OPTIONS_VERSION", (void *)_cffi_const_GIT_BLAME_OPTIONS_VERSION, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "GIT_CERT_HOSTKEY_LIBSSH2", (void *)_cffi_const_GIT_CERT_HOSTKEY_LIBSSH2, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_CERT_NONE", (void *)_cffi_const_GIT_CERT_NONE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_CERT_SSH_MD5", (void *)_cffi_const_GIT_CERT_SSH_MD5, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_CERT_SSH_SHA1", (void *)_cffi_const_GIT_CERT_SSH_SHA1, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_CERT_STRARRAY", (void *)_cffi_const_GIT_CERT_STRARRAY, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_CERT_X509", (void *)_cffi_const_GIT_CERT_X509, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_CHECKOUT_NOTIFY_ALL", (void *)_cffi_const_GIT_CHECKOUT_NOTIFY_ALL, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_CHECKOUT_NOTIFY_CONFLICT", (void *)_cffi_const_GIT_CHECKOUT_NOTIFY_CONFLICT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_CHECKOUT_NOTIFY_DIRTY", (void *)_cffi_const_GIT_CHECKOUT_NOTIFY_DIRTY, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_CHECKOUT_NOTIFY_IGNORED", (void *)_cffi_const_GIT_CHECKOUT_NOTIFY_IGNORED, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_CHECKOUT_NOTIFY_NONE", (void *)_cffi_const_GIT_CHECKOUT_NOTIFY_NONE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_CHECKOUT_NOTIFY_UNTRACKED", (void *)_cffi_const_GIT_CHECKOUT_NOTIFY_UNTRACKED, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_CHECKOUT_NOTIFY_UPDATED", (void *)_cffi_const_GIT_CHECKOUT_NOTIFY_UPDATED, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_CLONE_LOCAL", (void *)_cffi_const_GIT_CLONE_LOCAL, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_CLONE_LOCAL_AUTO", (void *)_cffi_const_GIT_CLONE_LOCAL_AUTO, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_CLONE_LOCAL_NO_LINKS", (void *)_cffi_const_GIT_CLONE_LOCAL_NO_LINKS, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_CLONE_NO_LOCAL", (void *)_cffi_const_GIT_CLONE_NO_LOCAL, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_CLONE_OPTIONS_VERSION", (void *)_cffi_const_GIT_CLONE_OPTIONS_VERSION, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "GIT_CONFIG_HIGHEST_LEVEL", (void *)_cffi_const_GIT_CONFIG_HIGHEST_LEVEL, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_CONFIG_LEVEL_APP", (void *)_cffi_const_GIT_CONFIG_LEVEL_APP, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_CONFIG_LEVEL_GLOBAL", (void *)_cffi_const_GIT_CONFIG_LEVEL_GLOBAL, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_CONFIG_LEVEL_LOCAL", (void *)_cffi_const_GIT_CONFIG_LEVEL_LOCAL, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_CONFIG_LEVEL_PROGRAMDATA", (void *)_cffi_const_GIT_CONFIG_LEVEL_PROGRAMDATA, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_CONFIG_LEVEL_SYSTEM", (void *)_cffi_const_GIT_CONFIG_LEVEL_SYSTEM, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_CONFIG_LEVEL_XDG", (void *)_cffi_const_GIT_CONFIG_LEVEL_XDG, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_CREDTYPE_DEFAULT", (void *)_cffi_const_GIT_CREDTYPE_DEFAULT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_CREDTYPE_SSH_CUSTOM", (void *)_cffi_const_GIT_CREDTYPE_SSH_CUSTOM, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_CREDTYPE_SSH_INTERACTIVE", (void *)_cffi_const_GIT_CREDTYPE_SSH_INTERACTIVE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_CREDTYPE_SSH_KEY", (void *)_cffi_const_GIT_CREDTYPE_SSH_KEY, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_CREDTYPE_SSH_MEMORY", (void *)_cffi_const_GIT_CREDTYPE_SSH_MEMORY, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_CREDTYPE_USERNAME", (void *)_cffi_const_GIT_CREDTYPE_USERNAME, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_CREDTYPE_USERPASS_PLAINTEXT", (void *)_cffi_const_GIT_CREDTYPE_USERPASS_PLAINTEXT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_DELTA_ADDED", (void *)_cffi_const_GIT_DELTA_ADDED, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_DELTA_CONFLICTED", (void *)_cffi_const_GIT_DELTA_CONFLICTED, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_DELTA_COPIED", (void *)_cffi_const_GIT_DELTA_COPIED, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_DELTA_DELETED", (void *)_cffi_const_GIT_DELTA_DELETED, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_DELTA_IGNORED", (void *)_cffi_const_GIT_DELTA_IGNORED, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_DELTA_MODIFIED", (void *)_cffi_const_GIT_DELTA_MODIFIED, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_DELTA_RENAMED", (void *)_cffi_const_GIT_DELTA_RENAMED, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_DELTA_TYPECHANGE", (void *)_cffi_const_GIT_DELTA_TYPECHANGE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_DELTA_UNMODIFIED", (void *)_cffi_const_GIT_DELTA_UNMODIFIED, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_DELTA_UNREADABLE", (void *)_cffi_const_GIT_DELTA_UNREADABLE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_DELTA_UNTRACKED", (void *)_cffi_const_GIT_DELTA_UNTRACKED, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_DESCRIBE_ALL", (void *)_cffi_const_GIT_DESCRIBE_ALL, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_DESCRIBE_DEFAULT", (void *)_cffi_const_GIT_DESCRIBE_DEFAULT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_DESCRIBE_FORMAT_OPTIONS_VERSION", (void *)_cffi_const_GIT_DESCRIBE_FORMAT_OPTIONS_VERSION, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "GIT_DESCRIBE_OPTIONS_VERSION", (void *)_cffi_const_GIT_DESCRIBE_OPTIONS_VERSION, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "GIT_DESCRIBE_TAGS", (void *)_cffi_const_GIT_DESCRIBE_TAGS, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_DIRECTION_FETCH", (void *)_cffi_const_GIT_DIRECTION_FETCH, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_DIRECTION_PUSH", (void *)_cffi_const_GIT_DIRECTION_PUSH, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_EAMBIGUOUS", (void *)_cffi_const_GIT_EAMBIGUOUS, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_EAPPLIED", (void *)_cffi_const_GIT_EAPPLIED, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_EAPPLYFAIL", (void *)_cffi_const_GIT_EAPPLYFAIL, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_EAUTH", (void *)_cffi_const_GIT_EAUTH, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_EBAREREPO", (void *)_cffi_const_GIT_EBAREREPO, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_EBUFS", (void *)_cffi_const_GIT_EBUFS, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_ECERTIFICATE", (void *)_cffi_const_GIT_ECERTIFICATE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_ECONFLICT", (void *)_cffi_const_GIT_ECONFLICT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_EDIRECTORY", (void *)_cffi_const_GIT_EDIRECTORY, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_EEOF", (void *)_cffi_const_GIT_EEOF, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_EEXISTS", (void *)_cffi_const_GIT_EEXISTS, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_EINDEXDIRTY", (void *)_cffi_const_GIT_EINDEXDIRTY, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_EINVALID", (void *)_cffi_const_GIT_EINVALID, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_EINVALIDSPEC", (void *)_cffi_const_GIT_EINVALIDSPEC, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_ELOCKED", (void *)_cffi_const_GIT_ELOCKED, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_EMERGECONFLICT", (void *)_cffi_const_GIT_EMERGECONFLICT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_EMISMATCH", (void *)_cffi_const_GIT_EMISMATCH, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_EMODIFIED", (void *)_cffi_const_GIT_EMODIFIED, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_ENONFASTFORWARD", (void *)_cffi_const_GIT_ENONFASTFORWARD, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_ENOTFOUND", (void *)_cffi_const_GIT_ENOTFOUND, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_EPEEL", (void *)_cffi_const_GIT_EPEEL, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_ERROR", (void *)_cffi_const_GIT_ERROR, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_EUNBORNBRANCH", (void *)_cffi_const_GIT_EUNBORNBRANCH, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_EUNCOMMITTED", (void *)_cffi_const_GIT_EUNCOMMITTED, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_EUNMERGED", (void *)_cffi_const_GIT_EUNMERGED, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_EUSER", (void *)_cffi_const_GIT_EUSER, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_FEATURE_HTTPS", (void *)_cffi_const_GIT_FEATURE_HTTPS, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_FEATURE_NSEC", (void *)_cffi_const_GIT_FEATURE_NSEC, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_FEATURE_SSH", (void *)_cffi_const_GIT_FEATURE_SSH, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_FEATURE_THREADS", (void *)_cffi_const_GIT_FEATURE_THREADS, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_FETCH_NO_PRUNE", (void *)_cffi_const_GIT_FETCH_NO_PRUNE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_FETCH_OPTIONS_VERSION", (void *)_cffi_const_GIT_FETCH_OPTIONS_VERSION, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "GIT_FETCH_PRUNE", (void *)_cffi_const_GIT_FETCH_PRUNE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_FETCH_PRUNE_UNSPECIFIED", (void *)_cffi_const_GIT_FETCH_PRUNE_UNSPECIFIED, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_ITEROVER", (void *)_cffi_const_GIT_ITEROVER, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_MERGE_FAIL_ON_CONFLICT", (void *)_cffi_const_GIT_MERGE_FAIL_ON_CONFLICT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_MERGE_FILE_DEFAULT", (void *)_cffi_const_GIT_MERGE_FILE_DEFAULT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_MERGE_FILE_DIFF_MINIMAL", (void *)_cffi_const_GIT_MERGE_FILE_DIFF_MINIMAL, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_MERGE_FILE_DIFF_PATIENCE", (void *)_cffi_const_GIT_MERGE_FILE_DIFF_PATIENCE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_MERGE_FILE_FAVOR_NORMAL", (void *)_cffi_const_GIT_MERGE_FILE_FAVOR_NORMAL, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_MERGE_FILE_FAVOR_OURS", (void *)_cffi_const_GIT_MERGE_FILE_FAVOR_OURS, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_MERGE_FILE_FAVOR_THEIRS", (void *)_cffi_const_GIT_MERGE_FILE_FAVOR_THEIRS, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_MERGE_FILE_FAVOR_UNION", (void *)_cffi_const_GIT_MERGE_FILE_FAVOR_UNION, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_MERGE_FILE_IGNORE_WHITESPACE", (void *)_cffi_const_GIT_MERGE_FILE_IGNORE_WHITESPACE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_MERGE_FILE_IGNORE_WHITESPACE_CHANGE", (void *)_cffi_const_GIT_MERGE_FILE_IGNORE_WHITESPACE_CHANGE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_MERGE_FILE_IGNORE_WHITESPACE_EOL", (void *)_cffi_const_GIT_MERGE_FILE_IGNORE_WHITESPACE_EOL, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_MERGE_FILE_SIMPLIFY_ALNUM", (void *)_cffi_const_GIT_MERGE_FILE_SIMPLIFY_ALNUM, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_MERGE_FILE_STYLE_DIFF3", (void *)_cffi_const_GIT_MERGE_FILE_STYLE_DIFF3, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_MERGE_FILE_STYLE_MERGE", (void *)_cffi_const_GIT_MERGE_FILE_STYLE_MERGE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_MERGE_FIND_RENAMES", (void *)_cffi_const_GIT_MERGE_FIND_RENAMES, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_MERGE_NO_RECURSIVE", (void *)_cffi_const_GIT_MERGE_NO_RECURSIVE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_MERGE_OPTIONS_VERSION", (void *)_cffi_const_GIT_MERGE_OPTIONS_VERSION, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "GIT_MERGE_SKIP_REUC", (void *)_cffi_const_GIT_MERGE_SKIP_REUC, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_OK", (void *)_cffi_const_GIT_OK, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_PASSTHROUGH", (void *)_cffi_const_GIT_PASSTHROUGH, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_PATH_MAX", (void *)_cffi_const_GIT_PATH_MAX, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "GIT_PROXY_AUTO", (void *)_cffi_const_GIT_PROXY_AUTO, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_PROXY_NONE", (void *)_cffi_const_GIT_PROXY_NONE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_PROXY_OPTIONS_VERSION", (void *)_cffi_const_GIT_PROXY_OPTIONS_VERSION, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "GIT_PROXY_SPECIFIED", (void *)_cffi_const_GIT_PROXY_SPECIFIED, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_PUSH_OPTIONS_VERSION", (void *)_cffi_const_GIT_PUSH_OPTIONS_VERSION, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "GIT_REFERENCE_ALL", (void *)_cffi_const_GIT_REFERENCE_ALL, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_REFERENCE_DIRECT", (void *)_cffi_const_GIT_REFERENCE_DIRECT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_REFERENCE_INVALID", (void *)_cffi_const_GIT_REFERENCE_INVALID, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_REFERENCE_SYMBOLIC", (void *)_cffi_const_GIT_REFERENCE_SYMBOLIC, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_REMOTE_CALLBACKS_VERSION", (void *)_cffi_const_GIT_REMOTE_CALLBACKS_VERSION, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "GIT_REMOTE_COMPLETION_DOWNLOAD", (void *)_cffi_const_GIT_REMOTE_COMPLETION_DOWNLOAD, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_REMOTE_COMPLETION_ERROR", (void *)_cffi_const_GIT_REMOTE_COMPLETION_ERROR, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_REMOTE_COMPLETION_INDEXING", (void *)_cffi_const_GIT_REMOTE_COMPLETION_INDEXING, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_REMOTE_DOWNLOAD_TAGS_ALL", (void *)_cffi_const_GIT_REMOTE_DOWNLOAD_TAGS_ALL, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_REMOTE_DOWNLOAD_TAGS_AUTO", (void *)_cffi_const_GIT_REMOTE_DOWNLOAD_TAGS_AUTO, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_REMOTE_DOWNLOAD_TAGS_NONE", (void *)_cffi_const_GIT_REMOTE_DOWNLOAD_TAGS_NONE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_REMOTE_DOWNLOAD_TAGS_UNSPECIFIED", (void *)_cffi_const_GIT_REMOTE_DOWNLOAD_TAGS_UNSPECIFIED, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_REPOSITORY_INIT_BARE", (void *)_cffi_const_GIT_REPOSITORY_INIT_BARE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_REPOSITORY_INIT_EXTERNAL_TEMPLATE", (void *)_cffi_const_GIT_REPOSITORY_INIT_EXTERNAL_TEMPLATE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_REPOSITORY_INIT_MKDIR", (void *)_cffi_const_GIT_REPOSITORY_INIT_MKDIR, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_REPOSITORY_INIT_MKPATH", (void *)_cffi_const_GIT_REPOSITORY_INIT_MKPATH, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_REPOSITORY_INIT_NO_DOTGIT_DIR", (void *)_cffi_const_GIT_REPOSITORY_INIT_NO_DOTGIT_DIR, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_REPOSITORY_INIT_NO_REINIT", (void *)_cffi_const_GIT_REPOSITORY_INIT_NO_REINIT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_REPOSITORY_INIT_OPTIONS_VERSION", (void *)_cffi_const_GIT_REPOSITORY_INIT_OPTIONS_VERSION, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "GIT_REPOSITORY_INIT_RELATIVE_GITLINK", (void *)_cffi_const_GIT_REPOSITORY_INIT_RELATIVE_GITLINK, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_REPOSITORY_INIT_SHARED_ALL", (void *)_cffi_const_GIT_REPOSITORY_INIT_SHARED_ALL, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_REPOSITORY_INIT_SHARED_GROUP", (void *)_cffi_const_GIT_REPOSITORY_INIT_SHARED_GROUP, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_REPOSITORY_INIT_SHARED_UMASK", (void *)_cffi_const_GIT_REPOSITORY_INIT_SHARED_UMASK, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_RETRY", (void *)_cffi_const_GIT_RETRY, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_STASH_APPLY_DEFAULT", (void *)_cffi_const_GIT_STASH_APPLY_DEFAULT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_STASH_APPLY_OPTIONS_VERSION", (void *)_cffi_const_GIT_STASH_APPLY_OPTIONS_VERSION, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "GIT_STASH_APPLY_PROGRESS_ANALYZE_INDEX", (void *)_cffi_const_GIT_STASH_APPLY_PROGRESS_ANALYZE_INDEX, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_STASH_APPLY_PROGRESS_ANALYZE_MODIFIED", (void *)_cffi_const_GIT_STASH_APPLY_PROGRESS_ANALYZE_MODIFIED, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_STASH_APPLY_PROGRESS_ANALYZE_UNTRACKED", (void *)_cffi_const_GIT_STASH_APPLY_PROGRESS_ANALYZE_UNTRACKED, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_STASH_APPLY_PROGRESS_CHECKOUT_MODIFIED", (void *)_cffi_const_GIT_STASH_APPLY_PROGRESS_CHECKOUT_MODIFIED, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_STASH_APPLY_PROGRESS_CHECKOUT_UNTRACKED", (void *)_cffi_const_GIT_STASH_APPLY_PROGRESS_CHECKOUT_UNTRACKED, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_STASH_APPLY_PROGRESS_DONE", (void *)_cffi_const_GIT_STASH_APPLY_PROGRESS_DONE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_STASH_APPLY_PROGRESS_LOADING_STASH", (void *)_cffi_const_GIT_STASH_APPLY_PROGRESS_LOADING_STASH, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_STASH_APPLY_PROGRESS_NONE", (void *)_cffi_const_GIT_STASH_APPLY_PROGRESS_NONE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_STASH_APPLY_REINSTATE_INDEX", (void *)_cffi_const_GIT_STASH_APPLY_REINSTATE_INDEX, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_STASH_DEFAULT", (void *)_cffi_const_GIT_STASH_DEFAULT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_STASH_INCLUDE_IGNORED", (void *)_cffi_const_GIT_STASH_INCLUDE_IGNORED, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_STASH_INCLUDE_UNTRACKED", (void *)_cffi_const_GIT_STASH_INCLUDE_UNTRACKED, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_STASH_KEEP_INDEX", (void *)_cffi_const_GIT_STASH_KEEP_INDEX, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_SUBMODULE_IGNORE_ALL", (void *)_cffi_const_GIT_SUBMODULE_IGNORE_ALL, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_SUBMODULE_IGNORE_DIRTY", (void *)_cffi_const_GIT_SUBMODULE_IGNORE_DIRTY, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_SUBMODULE_IGNORE_NONE", (void *)_cffi_const_GIT_SUBMODULE_IGNORE_NONE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_SUBMODULE_IGNORE_UNSPECIFIED", (void *)_cffi_const_GIT_SUBMODULE_IGNORE_UNSPECIFIED, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_SUBMODULE_IGNORE_UNTRACKED", (void *)_cffi_const_GIT_SUBMODULE_IGNORE_UNTRACKED, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_SUBMODULE_UPDATE_OPTIONS_VERSION", (void *)_cffi_const_GIT_SUBMODULE_UPDATE_OPTIONS_VERSION, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "git_attr_get", (void *)_cffi_f_git_attr_get, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 54), (void *)_cffi_d_git_attr_get },
  { "git_attr_value", (void *)_cffi_f_git_attr_value, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 9), (void *)_cffi_d_git_attr_value },
  { "git_blame_file", (void *)_cffi_f_git_blame_file, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 77), (void *)_cffi_d_git_blame_file },
  { "git_blame_free", (void *)_cffi_f_git_blame_free, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 633), (void *)_cffi_d_git_blame_free },
  { "git_blame_get_hunk_byindex", (void *)_cffi_f_git_blame_get_hunk_byindex, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 16), (void *)_cffi_d_git_blame_get_hunk_byindex },
  { "git_blame_get_hunk_byline", (void *)_cffi_f_git_blame_get_hunk_byline, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 12), (void *)_cffi_d_git_blame_get_hunk_byline },
  { "git_blame_get_hunk_count", (void *)_cffi_f_git_blame_get_hunk_count, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 624), (void *)_cffi_d_git_blame_get_hunk_count },
  { "git_blame_init_options", (void *)_cffi_f_git_blame_init_options, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 83), (void *)_cffi_d_git_blame_init_options },
  { "git_buf_dispose", (void *)_cffi_f_git_buf_dispose, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 636), (void *)_cffi_d_git_buf_dispose },
  { "git_checkout_head", (void *)_cffi_f_git_checkout_head, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 478), (void *)_cffi_d_git_checkout_head },
  { "git_checkout_index", (void *)_cffi_f_git_checkout_index, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 482), (void *)_cffi_d_git_checkout_index },
  { "git_checkout_init_options", (void *)_cffi_f_git_checkout_init_options, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 114), (void *)_cffi_d_git_checkout_init_options },
  { "git_checkout_tree", (void *)_cffi_f_git_checkout_tree, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 487), (void *)_cffi_d_git_checkout_tree },
  { "git_clone", (void *)_cffi_f_git_clone, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 440), (void *)_cffi_d_git_clone },
  { "git_clone_init_options", (void *)_cffi_f_git_clone_init_options, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 118), (void *)_cffi_d_git_clone_init_options },
  { "git_config_add_file_ondisk", (void *)_cffi_f_git_config_add_file_ondisk, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 152), (void *)_cffi_d_git_config_add_file_ondisk },
  { "git_config_delete_entry", (void *)_cffi_f_git_config_delete_entry, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 137), (void *)_cffi_d_git_config_delete_entry },
  { "git_config_entry_free", (void *)_cffi_f_git_config_entry_free, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 646), (void *)_cffi_d_git_config_entry_free },
  { "git_config_find_global", (void *)_cffi_f_git_config_find_global, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 87), (void *)_cffi_d_git_config_find_global },
  { "git_config_find_system", (void *)_cffi_f_git_config_find_system, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 87), (void *)_cffi_d_git_config_find_system },
  { "git_config_find_xdg", (void *)_cffi_f_git_config_find_xdg, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 87), (void *)_cffi_d_git_config_find_xdg },
  { "git_config_free", (void *)_cffi_f_git_config_free, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 643), (void *)_cffi_d_git_config_free },
  { "git_config_get_entry", (void *)_cffi_f_git_config_get_entry, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 169), (void *)_cffi_d_git_config_get_entry },
  { "git_config_get_string", (void *)_cffi_f_git_config_get_string, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 49), (void *)_cffi_d_git_config_get_string },
  { "git_config_iterator_free", (void *)_cffi_f_git_config_iterator_free, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 649), (void *)_cffi_d_git_config_iterator_free },
  { "git_config_iterator_new", (void *)_cffi_f_git_config_iterator_new, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 178), (void *)_cffi_d_git_config_iterator_new },
  { "git_config_multivar_iterator_new", (void *)_cffi_f_git_config_multivar_iterator_new, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 182), (void *)_cffi_d_git_config_multivar_iterator_new },
  { "git_config_new", (void *)_cffi_f_git_config_new, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 122), (void *)_cffi_d_git_config_new },
  { "git_config_next", (void *)_cffi_f_git_config_next, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 174), (void *)_cffi_d_git_config_next },
  { "git_config_open_ondisk", (void *)_cffi_f_git_config_open_ondisk, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 125), (void *)_cffi_d_git_config_open_ondisk },
  { "git_config_parse_bool", (void *)_cffi_f_git_config_parse_bool, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 559), (void *)_cffi_d_git_config_parse_bool },
  { "git_config_parse_int64", (void *)_cffi_f_git_config_parse_int64, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 575), (void *)_cffi_d_git_config_parse_int64 },
  { "git_config_set_bool", (void *)_cffi_f_git_config_set_bool, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 159), (void *)_cffi_d_git_config_set_bool },
  { "git_config_set_int64", (void *)_cffi_f_git_config_set_int64, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 164), (void *)_cffi_d_git_config_set_int64 },
  { "git_config_set_multivar", (void *)_cffi_f_git_config_set_multivar, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 146), (void *)_cffi_d_git_config_set_multivar },
  { "git_config_set_string", (void *)_cffi_f_git_config_set_string, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 141), (void *)_cffi_d_git_config_set_string },
  { "git_config_snapshot", (void *)_cffi_f_git_config_snapshot, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 129), (void *)_cffi_d_git_config_snapshot },
  { "git_cred_ssh_key_from_agent", (void *)_cffi_f_git_cred_ssh_key_from_agent, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 188), (void *)_cffi_d_git_cred_ssh_key_from_agent },
  { "git_cred_ssh_key_memory_new", (void *)_cffi_f_git_cred_ssh_key_memory_new, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 197), (void *)_cffi_d_git_cred_ssh_key_memory_new },
  { "git_cred_ssh_key_new", (void *)_cffi_f_git_cred_ssh_key_new, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 197), (void *)_cffi_d_git_cred_ssh_key_new },
  { "git_cred_username_new", (void *)_cffi_f_git_cred_username_new, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 188), (void *)_cffi_d_git_cred_username_new },
  { "git_cred_userpass_plaintext_new", (void *)_cffi_f_git_cred_userpass_plaintext_new, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 192), (void *)_cffi_d_git_cred_userpass_plaintext_new },
  { "git_describe_commit", (void *)_cffi_f_git_describe_commit, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 219), (void *)_cffi_d_git_describe_commit },
  { "git_describe_format", (void *)_cffi_f_git_describe_format, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 90), (void *)_cffi_d_git_describe_format },
  { "git_describe_init_format_options", (void *)_cffi_f_git_describe_init_format_options, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 211), (void *)_cffi_d_git_describe_init_format_options },
  { "git_describe_init_options", (void *)_cffi_f_git_describe_init_options, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 215), (void *)_cffi_d_git_describe_init_options },
  { "git_describe_result_free", (void *)_cffi_f_git_describe_result_free, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 652), (void *)_cffi_d_git_describe_result_free },
  { "git_describe_workdir", (void *)_cffi_f_git_describe_workdir, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 224), (void *)_cffi_d_git_describe_workdir },
  { "git_diff_index_to_workdir", (void *)_cffi_f_git_diff_index_to_workdir, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 229), (void *)_cffi_d_git_diff_index_to_workdir },
  { "git_diff_init_options", (void *)_cffi_f_git_diff_init_options, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 254), (void *)_cffi_d_git_diff_init_options },
  { "git_diff_tree_to_index", (void *)_cffi_f_git_diff_tree_to_index, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 235), (void *)_cffi_d_git_diff_tree_to_index },
  { "git_error_last", (void *)_cffi_f_git_error_last, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_N, 23), (void *)_cffi_d_git_error_last },
  { "git_fetch_init_options", (void *)_cffi_f_git_fetch_init_options, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 258), (void *)_cffi_d_git_fetch_init_options },
  { "git_graph_ahead_behind", (void *)_cffi_f_git_graph_ahead_behind, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 584), (void *)_cffi_d_git_graph_ahead_behind },
  { "git_index_add", (void *)_cffi_f_git_index_add, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 305), (void *)_cffi_d_git_index_add },
  { "git_index_add_all", (void *)_cffi_f_git_index_add_all, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 309), (void *)_cffi_d_git_index_add_all },
  { "git_index_add_bypath", (void *)_cffi_f_git_index_add_bypath, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 296), (void *)_cffi_d_git_index_add_bypath },
  { "git_index_clear", (void *)_cffi_f_git_index_clear, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 293), (void *)_cffi_d_git_index_clear },
  { "git_index_conflict_get", (void *)_cffi_f_git_index_conflict_get, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 331), (void *)_cffi_d_git_index_conflict_get },
  { "git_index_conflict_iterator_free", (void *)_cffi_f_git_index_conflict_iterator_free, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 658), (void *)_cffi_d_git_index_conflict_iterator_free },
  { "git_index_conflict_iterator_new", (void *)_cffi_f_git_index_conflict_iterator_new, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 327), (void *)_cffi_d_git_index_conflict_iterator_new },
  { "git_index_conflict_next", (void *)_cffi_f_git_index_conflict_next, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 338), (void *)_cffi_d_git_index_conflict_next },
  { "git_index_conflict_remove", (void *)_cffi_f_git_index_conflict_remove, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 296), (void *)_cffi_d_git_index_conflict_remove },
  { "git_index_entrycount", (void *)_cffi_f_git_index_entrycount, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 618), (void *)_cffi_d_git_index_entrycount },
  { "git_index_find", (void *)_cffi_f_git_index_find, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 579), (void *)_cffi_d_git_index_find },
  { "git_index_free", (void *)_cffi_f_git_index_free, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 655), (void *)_cffi_d_git_index_free },
  { "git_index_get_byindex", (void *)_cffi_f_git_index_get_byindex, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 30), (void *)_cffi_d_git_index_get_byindex },
  { "git_index_get_bypath", (void *)_cffi_f_git_index_get_bypath, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 25), (void *)_cffi_d_git_index_get_bypath },
  { "git_index_has_conflicts", (void *)_cffi_f_git_index_has_conflicts, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 324), (void *)_cffi_d_git_index_has_conflicts },
  { "git_index_open", (void *)_cffi_f_git_index_open, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 262), (void *)_cffi_d_git_index_open },
  { "git_index_read", (void *)_cffi_f_git_index_read, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 320), (void *)_cffi_d_git_index_read },
  { "git_index_read_tree", (void *)_cffi_f_git_index_read_tree, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 316), (void *)_cffi_d_git_index_read_tree },
  { "git_index_remove", (void *)_cffi_f_git_index_remove, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 300), (void *)_cffi_d_git_index_remove },
  { "git_index_write", (void *)_cffi_f_git_index_write, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 293), (void *)_cffi_d_git_index_write },
  { "git_index_write_tree", (void *)_cffi_f_git_index_write_tree, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 356), (void *)_cffi_d_git_index_write_tree },
  { "git_index_write_tree_to", (void *)_cffi_f_git_index_write_tree_to, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 360), (void *)_cffi_d_git_index_write_tree_to },
  { "git_libgit2_features", (void *)_cffi_f_git_libgit2_features, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_N, 616), (void *)_cffi_d_git_libgit2_features },
  { "git_merge_commits", (void *)_cffi_f_git_merge_commits, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 278), (void *)_cffi_d_git_merge_commits },
  { "git_merge_file_from_index", (void *)_cffi_f_git_merge_file_from_index, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 344), (void *)_cffi_d_git_merge_file_from_index },
  { "git_merge_file_result_free", (void *)_cffi_f_git_merge_file_result_free, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 661), (void *)_cffi_d_git_merge_file_result_free },
  { "git_merge_init_options", (void *)_cffi_f_git_merge_init_options, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 352), (void *)_cffi_d_git_merge_init_options },
  { "git_merge_trees", (void *)_cffi_f_git_merge_trees, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 285), (void *)_cffi_d_git_merge_trees },
  { "git_proxy_init_options", (void *)_cffi_f_git_proxy_init_options, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 372), (void *)_cffi_d_git_proxy_init_options },
  { "git_push_init_options", (void *)_cffi_f_git_push_init_options, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 376), (void *)_cffi_d_git_push_init_options },
  { "git_refspec_direction", (void *)_cffi_f_git_refspec_direction, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 20), (void *)_cffi_d_git_refspec_direction },
  { "git_refspec_dst", (void *)_cffi_f_git_refspec_dst, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 0), (void *)_cffi_d_git_refspec_dst },
  { "git_refspec_dst_matches", (void *)_cffi_f_git_refspec_dst_matches, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 388), (void *)_cffi_d_git_refspec_dst_matches },
  { "git_refspec_force", (void *)_cffi_f_git_refspec_force, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 385), (void *)_cffi_d_git_refspec_force },
  { "git_refspec_rtransform", (void *)_cffi_f_git_refspec_rtransform, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 95), (void *)_cffi_d_git_refspec_rtransform },
  { "git_refspec_src", (void *)_cffi_f_git_refspec_src, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 0), (void *)_cffi_d_git_refspec_src },
  { "git_refspec_src_matches", (void *)_cffi_f_git_refspec_src_matches, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 388), (void *)_cffi_d_git_refspec_src_matches },
  { "git_refspec_string", (void *)_cffi_f_git_refspec_string, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 0), (void *)_cffi_d_git_refspec_string },
  { "git_refspec_transform", (void *)_cffi_f_git_refspec_transform, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 95), (void *)_cffi_d_git_refspec_transform },
  { "git_remote_add_fetch", (void *)_cffi_f_git_remote_add_fetch, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 473), (void *)_cffi_d_git_remote_add_fetch },
  { "git_remote_add_push", (void *)_cffi_f_git_remote_add_push, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 473), (void *)_cffi_d_git_remote_add_push },
  { "git_remote_create", (void *)_cffi_f_git_remote_create, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 397), (void *)_cffi_d_git_remote_create },
  { "git_remote_create_with_fetchspec", (void *)_cffi_f_git_remote_create_with_fetchspec, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 403), (void *)_cffi_d_git_remote_create_with_fetchspec },
  { "git_remote_delete", (void *)_cffi_f_git_remote_delete, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 469), (void *)_cffi_d_git_remote_delete },
  { "git_remote_fetch", (void *)_cffi_f_git_remote_fetch, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 421), (void *)_cffi_d_git_remote_fetch },
  { "git_remote_free", (void *)_cffi_f_git_remote_free, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 664), (void *)_cffi_d_git_remote_free },
  { "git_remote_get_fetch_refspecs", (void *)_cffi_f_git_remote_get_fetch_refspecs, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 522), (void *)_cffi_d_git_remote_get_fetch_refspecs },
  { "git_remote_get_push_refspecs", (void *)_cffi_f_git_remote_get_push_refspecs, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 522), (void *)_cffi_d_git_remote_get_push_refspecs },
  { "git_remote_get_refspec", (void *)_cffi_f_git_remote_get_refspec, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 37), (void *)_cffi_d_git_remote_get_refspec },
  { "git_remote_init_callbacks", (void *)_cffi_f_git_remote_init_callbacks, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 432), (void *)_cffi_d_git_remote_init_callbacks },
  { "git_remote_list", (void *)_cffi_f_git_remote_list, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 526), (void *)_cffi_d_git_remote_list },
  { "git_remote_lookup", (void *)_cffi_f_git_remote_lookup, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 392), (void *)_cffi_d_git_remote_lookup },
  { "git_remote_name", (void *)_cffi_f_git_remote_name, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 3), (void *)_cffi_d_git_remote_name },
  { "git_remote_prune", (void *)_cffi_f_git_remote_prune, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 417), (void *)_cffi_d_git_remote_prune },
  { "git_remote_push", (void *)_cffi_f_git_remote_push, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 427), (void *)_cffi_d_git_remote_push },
  { "git_remote_pushurl", (void *)_cffi_f_git_remote_pushurl, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 3), (void *)_cffi_d_git_remote_pushurl },
  { "git_remote_refspec_count", (void *)_cffi_f_git_remote_refspec_count, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 621), (void *)_cffi_d_git_remote_refspec_count },
  { "git_remote_rename", (void *)_cffi_f_git_remote_rename, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 530), (void *)_cffi_d_git_remote_rename },
  { "git_remote_set_pushurl", (void *)_cffi_f_git_remote_set_pushurl, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 473), (void *)_cffi_d_git_remote_set_pushurl },
  { "git_remote_set_url", (void *)_cffi_f_git_remote_set_url, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 473), (void *)_cffi_d_git_remote_set_url },
  { "git_remote_stats", (void *)_cffi_f_git_remote_stats, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 41), (void *)_cffi_d_git_remote_stats },
  { "git_remote_url", (void *)_cffi_f_git_remote_url, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 3), (void *)_cffi_d_git_remote_url },
  { "git_repository_config", (void *)_cffi_f_git_repository_config, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 133), (void *)_cffi_d_git_repository_config },
  { "git_repository_config_snapshot", (void *)_cffi_f_git_repository_config_snapshot, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 133), (void *)_cffi_d_git_repository_config_snapshot },
  { "git_repository_free", (void *)_cffi_f_git_repository_free, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 667), (void *)_cffi_d_git_repository_free },
  { "git_repository_ident", (void *)_cffi_f_git_repository_ident, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 44), (void *)_cffi_d_git_repository_ident },
  { "git_repository_index", (void *)_cffi_f_git_repository_index, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 266), (void *)_cffi_d_git_repository_index },
  { "git_repository_init", (void *)_cffi_f_git_repository_init, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 457), (void *)_cffi_d_git_repository_init },
  { "git_repository_init_ext", (void *)_cffi_f_git_repository_init_ext, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 446), (void *)_cffi_d_git_repository_init_ext },
  { "git_repository_init_init_options", (void *)_cffi_f_git_repository_init_init_options, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 510), (void *)_cffi_d_git_repository_init_init_options },
  { "git_repository_set_head", (void *)_cffi_f_git_repository_set_head, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 469), (void *)_cffi_d_git_repository_set_head },
  { "git_repository_set_head_detached", (void *)_cffi_f_git_repository_set_head_detached, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 492), (void *)_cffi_d_git_repository_set_head_detached },
  { "git_repository_set_ident", (void *)_cffi_f_git_repository_set_ident, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 473), (void *)_cffi_d_git_repository_set_ident },
  { "git_repository_state_cleanup", (void *)_cffi_f_git_repository_state_cleanup, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 466), (void *)_cffi_d_git_repository_state_cleanup },
  { "git_revert_commit", (void *)_cffi_f_git_revert_commit, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 270), (void *)_cffi_d_git_revert_commit },
  { "git_stash_apply", (void *)_cffi_f_git_stash_apply, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 505), (void *)_cffi_d_git_stash_apply },
  { "git_stash_apply_init_options", (void *)_cffi_f_git_stash_apply_init_options, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 514), (void *)_cffi_d_git_stash_apply_init_options },
  { "git_stash_drop", (void *)_cffi_f_git_stash_drop, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 501), (void *)_cffi_d_git_stash_drop },
  { "git_stash_foreach", (void *)_cffi_f_git_stash_foreach, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 496), (void *)_cffi_d_git_stash_foreach },
  { "git_stash_pop", (void *)_cffi_f_git_stash_pop, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 505), (void *)_cffi_d_git_stash_pop },
  { "git_stash_save", (void *)_cffi_f_git_stash_save, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 365), (void *)_cffi_d_git_stash_save },
  { "git_strarray_free", (void *)_cffi_f_git_strarray_free, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 670), (void *)_cffi_d_git_strarray_free },
  { "git_submodule_branch", (void *)_cffi_f_git_submodule_branch, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 6), (void *)_cffi_d_git_submodule_branch },
  { "git_submodule_free", (void *)_cffi_f_git_submodule_free, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 673), (void *)_cffi_d_git_submodule_free },
  { "git_submodule_head_id", (void *)_cffi_f_git_submodule_head_id, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 34), (void *)_cffi_d_git_submodule_head_id },
  { "git_submodule_lookup", (void *)_cffi_f_git_submodule_lookup, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 536), (void *)_cffi_d_git_submodule_lookup },
  { "git_submodule_name", (void *)_cffi_f_git_submodule_name, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 6), (void *)_cffi_d_git_submodule_name },
  { "git_submodule_open", (void *)_cffi_f_git_submodule_open, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 462), (void *)_cffi_d_git_submodule_open },
  { "git_submodule_path", (void *)_cffi_f_git_submodule_path, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 6), (void *)_cffi_d_git_submodule_path },
  { "git_submodule_update", (void *)_cffi_f_git_submodule_update, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 541), (void *)_cffi_d_git_submodule_update },
  { "git_submodule_update_init_options", (void *)_cffi_f_git_submodule_update_init_options, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 546), (void *)_cffi_d_git_submodule_update_init_options },
  { "git_submodule_url", (void *)_cffi_f_git_submodule_url, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 6), (void *)_cffi_d_git_submodule_url },
};

static const struct _cffi_field_s _cffi_fields[] = {
  { "ptr", offsetof(git_buf, ptr),
           sizeof(((git_buf *)0)->ptr),
           _CFFI_OP(_CFFI_OP_NOOP, 681) },
  { "asize", offsetof(git_buf, asize),
             sizeof(((git_buf *)0)->asize),
             _CFFI_OP(_CFFI_OP_NOOP, 14) },
  { "size", offsetof(git_buf, size),
            sizeof(((git_buf *)0)->size),
            _CFFI_OP(_CFFI_OP_NOOP, 14) },
  { "cert_type", offsetof(git_cert, cert_type),
                 sizeof(((git_cert *)0)->cert_type),
                 _CFFI_OP(_CFFI_OP_NOOP, 692) },
  { "parent", offsetof(git_cert_hostkey, parent),
              sizeof(((git_cert_hostkey *)0)->parent),
              _CFFI_OP(_CFFI_OP_NOOP, 689) },
  { "type", offsetof(git_cert_hostkey, type),
            sizeof(((git_cert_hostkey *)0)->type),
            _CFFI_OP(_CFFI_OP_NOOP, 691) },
  { "hash_md5", offsetof(git_cert_hostkey, hash_md5),
                sizeof(((git_cert_hostkey *)0)->hash_md5),
                _CFFI_OP(_CFFI_OP_NOOP, 786) },
  { "hash_sha1", offsetof(git_cert_hostkey, hash_sha1),
                 sizeof(((git_cert_hostkey *)0)->hash_sha1),
                 _CFFI_OP(_CFFI_OP_NOOP, 788) },
  { "parent", offsetof(git_cert_x509, parent),
              sizeof(((git_cert_x509 *)0)->parent),
              _CFFI_OP(_CFFI_OP_NOOP, 689) },
  { "data", offsetof(git_cert_x509, data),
            sizeof(((git_cert_x509 *)0)->data),
            _CFFI_OP(_CFFI_OP_NOOP, 64) },
  { "len", offsetof(git_cert_x509, len),
           sizeof(((git_cert_x509 *)0)->len),
           _CFFI_OP(_CFFI_OP_NOOP, 14) },
  { "mkdir_calls", offsetof(git_checkout_perfdata, mkdir_calls),
                   sizeof(((git_checkout_perfdata *)0)->mkdir_calls),
                   _CFFI_OP(_CFFI_OP_NOOP, 14) },
  { "stat_calls", offsetof(git_checkout_perfdata, stat_calls),
                  sizeof(((git_checkout_perfdata *)0)->stat_calls),
                  _CFFI_OP(_CFFI_OP_NOOP, 14) },
  { "chmod_calls", offsetof(git_checkout_perfdata, chmod_calls),
                   sizeof(((git_checkout_perfdata *)0)->chmod_calls),
                   _CFFI_OP(_CFFI_OP_NOOP, 14) },
  { "version", offsetof(git_describe_format_options, version),
               sizeof(((git_describe_format_options *)0)->version),
               _CFFI_OP(_CFFI_OP_NOOP, 85) },
  { "abbreviated_size", offsetof(git_describe_format_options, abbreviated_size),
                        sizeof(((git_describe_format_options *)0)->abbreviated_size),
                        _CFFI_OP(_CFFI_OP_NOOP, 85) },
  { "always_use_long_format", offsetof(git_describe_format_options, always_use_long_format),
                              sizeof(((git_describe_format_options *)0)->always_use_long_format),
                              _CFFI_OP(_CFFI_OP_NOOP, 28) },
  { "dirty_suffix", offsetof(git_describe_format_options, dirty_suffix),
                    sizeof(((git_describe_format_options *)0)->dirty_suffix),
                    _CFFI_OP(_CFFI_OP_NOOP, 10) },
  { "status", offsetof(git_diff_delta, status),
              sizeof(((git_diff_delta *)0)->status),
              _CFFI_OP(_CFFI_OP_NOOP, 705) },
  { "flags", offsetof(git_diff_delta, flags),
             sizeof(((git_diff_delta *)0)->flags),
             _CFFI_OP(_CFFI_OP_NOOP, 18) },
  { "similarity", offsetof(git_diff_delta, similarity),
                  sizeof(((git_diff_delta *)0)->similarity),
                  _CFFI_OP(_CFFI_OP_NOOP, 784) },
  { "nfiles", offsetof(git_diff_delta, nfiles),
              sizeof(((git_diff_delta *)0)->nfiles),
              _CFFI_OP(_CFFI_OP_NOOP, 784) },
  { "old_file", offsetof(git_diff_delta, old_file),
                sizeof(((git_diff_delta *)0)->old_file),
                _CFFI_OP(_CFFI_OP_NOOP, 713) },
  { "new_file", offsetof(git_diff_delta, new_file),
                sizeof(((git_diff_delta *)0)->new_file),
                _CFFI_OP(_CFFI_OP_NOOP, 713) },
  { "id", offsetof(git_diff_file, id),
          sizeof(((git_diff_file *)0)->id),
          _CFFI_OP(_CFFI_OP_NOOP, 735) },
  { "path", offsetof(git_diff_file, path),
            sizeof(((git_diff_file *)0)->path),
            _CFFI_OP(_CFFI_OP_NOOP, 10) },
  { "size", offsetof(git_diff_file, size),
            sizeof(((git_diff_file *)0)->size),
            _CFFI_OP(_CFFI_OP_NOOP, 167) },
  { "flags", offsetof(git_diff_file, flags),
             sizeof(((git_diff_file *)0)->flags),
             _CFFI_OP(_CFFI_OP_NOOP, 18) },
  { "mode", offsetof(git_diff_file, mode),
            sizeof(((git_diff_file *)0)->mode),
            _CFFI_OP(_CFFI_OP_NOOP, 784) },
  { "id_abbrev", offsetof(git_diff_file, id_abbrev),
                 sizeof(((git_diff_file *)0)->id_abbrev),
                 _CFFI_OP(_CFFI_OP_NOOP, 784) },
  { "version", offsetof(git_diff_options, version),
               sizeof(((git_diff_options *)0)->version),
               _CFFI_OP(_CFFI_OP_NOOP, 85) },
  { "flags", offsetof(git_diff_options, flags),
             sizeof(((git_diff_options *)0)->flags),
             _CFFI_OP(_CFFI_OP_NOOP, 18) },
  { "ignore_submodules", offsetof(git_diff_options, ignore_submodules),
                         sizeof(((git_diff_options *)0)->ignore_submodules),
                         _CFFI_OP(_CFFI_OP_NOOP, 757) },
  { "pathspec", offsetof(git_diff_options, pathspec),
                sizeof(((git_diff_options *)0)->pathspec),
                _CFFI_OP(_CFFI_OP_NOOP, 755) },
  { "notify_cb", offsetof(git_diff_options, notify_cb),
                 sizeof(((git_diff_options *)0)->notify_cb),
                 _CFFI_OP(_CFFI_OP_NOOP, 770) },
  { "progress_cb", offsetof(git_diff_options, progress_cb),
                   sizeof(((git_diff_options *)0)->progress_cb),
                   _CFFI_OP(_CFFI_OP_NOOP, 769) },
  { "payload", offsetof(git_diff_options, payload),
               sizeof(((git_diff_options *)0)->payload),
               _CFFI_OP(_CFFI_OP_NOOP, 64) },
  { "context_lines", offsetof(git_diff_options, context_lines),
                     sizeof(((git_diff_options *)0)->context_lines),
                     _CFFI_OP(_CFFI_OP_NOOP, 18) },
  { "interhunk_lines", offsetof(git_diff_options, interhunk_lines),
                       sizeof(((git_diff_options *)0)->interhunk_lines),
                       _CFFI_OP(_CFFI_OP_NOOP, 18) },
  { "id_abbrev", offsetof(git_diff_options, id_abbrev),
                 sizeof(((git_diff_options *)0)->id_abbrev),
                 _CFFI_OP(_CFFI_OP_NOOP, 784) },
  { "max_size", offsetof(git_diff_options, max_size),
                sizeof(((git_diff_options *)0)->max_size),
                _CFFI_OP(_CFFI_OP_NOOP, 167) },
  { "old_prefix", offsetof(git_diff_options, old_prefix),
                  sizeof(((git_diff_options *)0)->old_prefix),
                  _CFFI_OP(_CFFI_OP_NOOP, 10) },
  { "new_prefix", offsetof(git_diff_options, new_prefix),
                  sizeof(((git_diff_options *)0)->new_prefix),
                  _CFFI_OP(_CFFI_OP_NOOP, 10) },
  { "file_signature", offsetof(git_diff_similarity_metric, file_signature),
                      sizeof(((git_diff_similarity_metric *)0)->file_signature),
                      _CFFI_OP(_CFFI_OP_NOOP, 782) },
  { "buffer_signature", offsetof(git_diff_similarity_metric, buffer_signature),
                        sizeof(((git_diff_similarity_metric *)0)->buffer_signature),
                        _CFFI_OP(_CFFI_OP_NOOP, 781) },
  { "free_signature", offsetof(git_diff_similarity_metric, free_signature),
                      sizeof(((git_diff_similarity_metric *)0)->free_signature),
                      _CFFI_OP(_CFFI_OP_NOOP, 794) },
  { "similarity", offsetof(git_diff_similarity_metric, similarity),
                  sizeof(((git_diff_similarity_metric *)0)->similarity),
                  _CFFI_OP(_CFFI_OP_NOOP, 778) },
  { "payload", offsetof(git_diff_similarity_metric, payload),
               sizeof(((git_diff_similarity_metric *)0)->payload),
               _CFFI_OP(_CFFI_OP_NOOP, 64) },
  { "message", offsetof(git_error, message),
               sizeof(((git_error *)0)->message),
               _CFFI_OP(_CFFI_OP_NOOP, 681) },
  { "klass", offsetof(git_error, klass),
             sizeof(((git_error *)0)->klass),
             _CFFI_OP(_CFFI_OP_NOOP, 28) },
  { "version", offsetof(git_fetch_options, version),
               sizeof(((git_fetch_options *)0)->version),
               _CFFI_OP(_CFFI_OP_NOOP, 28) },
  { "callbacks", offsetof(git_fetch_options, callbacks),
                 sizeof(((git_fetch_options *)0)->callbacks),
                 _CFFI_OP(_CFFI_OP_NOOP, 745) },
  { "prune", offsetof(git_fetch_options, prune),
             sizeof(((git_fetch_options *)0)->prune),
             _CFFI_OP(_CFFI_OP_NOOP, 723) },
  { "update_fetchhead", offsetof(git_fetch_options, update_fetchhead),
                        sizeof(((git_fetch_options *)0)->update_fetchhead),
                        _CFFI_OP(_CFFI_OP_NOOP, 28) },
  { "download_tags", offsetof(git_fetch_options, download_tags),
                     sizeof(((git_fetch_options *)0)->download_tags),
                     _CFFI_OP(_CFFI_OP_NOOP, 744) },
  { "proxy_opts", offsetof(git_fetch_options, proxy_opts),
                  sizeof(((git_fetch_options *)0)->proxy_opts),
                  _CFFI_OP(_CFFI_OP_NOOP, 736) },
  { "custom_headers", offsetof(git_fetch_options, custom_headers),
                      sizeof(((git_fetch_options *)0)->custom_headers),
                      _CFFI_OP(_CFFI_OP_NOOP, 755) },
  { "seconds", offsetof(git_index_time, seconds),
               sizeof(((git_index_time *)0)->seconds),
               _CFFI_OP(_CFFI_OP_NOOP, 783) },
  { "nanoseconds", offsetof(git_index_time, nanoseconds),
                   sizeof(((git_index_time *)0)->nanoseconds),
                   _CFFI_OP(_CFFI_OP_NOOP, 18) },
  { "version", offsetof(git_merge_file_options, version),
               sizeof(((git_merge_file_options *)0)->version),
               _CFFI_OP(_CFFI_OP_NOOP, 85) },
  { "ancestor_label", offsetof(git_merge_file_options, ancestor_label),
                      sizeof(((git_merge_file_options *)0)->ancestor_label),
                      _CFFI_OP(_CFFI_OP_NOOP, 10) },
  { "our_label", offsetof(git_merge_file_options, our_label),
                 sizeof(((git_merge_file_options *)0)->our_label),
                 _CFFI_OP(_CFFI_OP_NOOP, 10) },
  { "their_label", offsetof(git_merge_file_options, their_label),
                   sizeof(((git_merge_file_options *)0)->their_label),
                   _CFFI_OP(_CFFI_OP_NOOP, 10) },
  { "favor", offsetof(git_merge_file_options, favor),
             sizeof(((git_merge_file_options *)0)->favor),
             _CFFI_OP(_CFFI_OP_NOOP, 728) },
  { "flags", offsetof(git_merge_file_options, flags),
             sizeof(((git_merge_file_options *)0)->flags),
             _CFFI_OP(_CFFI_OP_NOOP, 729) },
  { "marker_size", offsetof(git_merge_file_options, marker_size),
                   sizeof(((git_merge_file_options *)0)->marker_size),
                   _CFFI_OP(_CFFI_OP_NOOP, 790) },
  { "automergeable", offsetof(git_merge_file_result, automergeable),
                     sizeof(((git_merge_file_result *)0)->automergeable),
                     _CFFI_OP(_CFFI_OP_NOOP, 85) },
  { "path", offsetof(git_merge_file_result, path),
            sizeof(((git_merge_file_result *)0)->path),
            _CFFI_OP(_CFFI_OP_NOOP, 10) },
  { "mode", offsetof(git_merge_file_result, mode),
            sizeof(((git_merge_file_result *)0)->mode),
            _CFFI_OP(_CFFI_OP_NOOP, 85) },
  { "ptr", offsetof(git_merge_file_result, ptr),
           sizeof(((git_merge_file_result *)0)->ptr),
           _CFFI_OP(_CFFI_OP_NOOP, 10) },
  { "len", offsetof(git_merge_file_result, len),
           sizeof(((git_merge_file_result *)0)->len),
           _CFFI_OP(_CFFI_OP_NOOP, 14) },
  { "version", offsetof(git_merge_options, version),
               sizeof(((git_merge_options *)0)->version),
               _CFFI_OP(_CFFI_OP_NOOP, 85) },
  { "flags", offsetof(git_merge_options, flags),
             sizeof(((git_merge_options *)0)->flags),
             _CFFI_OP(_CFFI_OP_NOOP, 732) },
  { "rename_threshold", offsetof(git_merge_options, rename_threshold),
                        sizeof(((git_merge_options *)0)->rename_threshold),
                        _CFFI_OP(_CFFI_OP_NOOP, 85) },
  { "target_limit", offsetof(git_merge_options, target_limit),
                    sizeof(((git_merge_options *)0)->target_limit),
                    _CFFI_OP(_CFFI_OP_NOOP, 85) },
  { "metric", offsetof(git_merge_options, metric),
              sizeof(((git_merge_options *)0)->metric),
              _CFFI_OP(_CFFI_OP_NOOP, 715) },
  { "recursion_limit", offsetof(git_merge_options, recursion_limit),
                       sizeof(((git_merge_options *)0)->recursion_limit),
                       _CFFI_OP(_CFFI_OP_NOOP, 85) },
  { "default_driver", offsetof(git_merge_options, default_driver),
                      sizeof(((git_merge_options *)0)->default_driver),
                      _CFFI_OP(_CFFI_OP_NOOP, 10) },
  { "file_favor", offsetof(git_merge_options, file_favor),
                  sizeof(((git_merge_options *)0)->file_favor),
                  _CFFI_OP(_CFFI_OP_NOOP, 728) },
  { "file_flags", offsetof(git_merge_options, file_flags),
                  sizeof(((git_merge_options *)0)->file_flags),
                  _CFFI_OP(_CFFI_OP_NOOP, 729) },
  { "version", offsetof(git_proxy_options, version),
               sizeof(((git_proxy_options *)0)->version),
               _CFFI_OP(_CFFI_OP_NOOP, 85) },
  { "type", offsetof(git_proxy_options, type),
            sizeof(((git_proxy_options *)0)->type),
            _CFFI_OP(_CFFI_OP_NOOP, 737) },
  { "url", offsetof(git_proxy_options, url),
           sizeof(((git_proxy_options *)0)->url),
           _CFFI_OP(_CFFI_OP_NOOP, 10) },
  { "credentials", offsetof(git_proxy_options, credentials),
                   sizeof(((git_proxy_options *)0)->credentials),
                   _CFFI_OP(_CFFI_OP_NOOP, 768) },
  { "certificate_check", offsetof(git_proxy_options, certificate_check),
                         sizeof(((git_proxy_options *)0)->certificate_check),
                         _CFFI_OP(_CFFI_OP_NOOP, 766) },
  { "payload", offsetof(git_proxy_options, payload),
               sizeof(((git_proxy_options *)0)->payload),
               _CFFI_OP(_CFFI_OP_NOOP, 64) },
  { "version", offsetof(git_push_options, version),
               sizeof(((git_push_options *)0)->version),
               _CFFI_OP(_CFFI_OP_NOOP, 85) },
  { "pb_parallelism", offsetof(git_push_options, pb_parallelism),
                      sizeof(((git_push_options *)0)->pb_parallelism),
                      _CFFI_OP(_CFFI_OP_NOOP, 85) },
  { "callbacks", offsetof(git_push_options, callbacks),
                 sizeof(((git_push_options *)0)->callbacks),
                 _CFFI_OP(_CFFI_OP_NOOP, 745) },
  { "proxy_opts", offsetof(git_push_options, proxy_opts),
                  sizeof(((git_push_options *)0)->proxy_opts),
                  _CFFI_OP(_CFFI_OP_NOOP, 736) },
  { "custom_headers", offsetof(git_push_options, custom_headers),
                      sizeof(((git_push_options *)0)->custom_headers),
                      _CFFI_OP(_CFFI_OP_NOOP, 755) },
  { "src_refname", offsetof(git_push_update, src_refname),
                   sizeof(((git_push_update *)0)->src_refname),
                   _CFFI_OP(_CFFI_OP_NOOP, 681) },
  { "dst_refname", offsetof(git_push_update, dst_refname),
                   sizeof(((git_push_update *)0)->dst_refname),
                   _CFFI_OP(_CFFI_OP_NOOP, 681) },
  { "src", offsetof(git_push_update, src),
           sizeof(((git_push_update *)0)->src),
           _CFFI_OP(_CFFI_OP_NOOP, 735) },
  { "dst", offsetof(git_push_update, dst),
           sizeof(((git_push_update *)0)->dst),
           _CFFI_OP(_CFFI_OP_NOOP, 735) },
  { "version", offsetof(git_repository_init_options, version),
               sizeof(((git_repository_init_options *)0)->version),
               _CFFI_OP(_CFFI_OP_NOOP, 85) },
  { "flags", offsetof(git_repository_init_options, flags),
             sizeof(((git_repository_init_options *)0)->flags),
             _CFFI_OP(_CFFI_OP_NOOP, 18) },
  { "mode", offsetof(git_repository_init_options, mode),
            sizeof(((git_repository_init_options *)0)->mode),
            _CFFI_OP(_CFFI_OP_NOOP, 18) },
  { "workdir_path", offsetof(git_repository_init_options, workdir_path),
                    sizeof(((git_repository_init_options *)0)->workdir_path),
                    _CFFI_OP(_CFFI_OP_NOOP, 10) },
  { "description", offsetof(git_repository_init_options, description),
                   sizeof(((git_repository_init_options *)0)->description),
                   _CFFI_OP(_CFFI_OP_NOOP, 10) },
  { "template_path", offsetof(git_repository_init_options, template_path),
                     sizeof(((git_repository_init_options *)0)->template_path),
                     _CFFI_OP(_CFFI_OP_NOOP, 10) },
  { "initial_head", offsetof(git_repository_init_options, initial_head),
                    sizeof(((git_repository_init_options *)0)->initial_head),
                    _CFFI_OP(_CFFI_OP_NOOP, 10) },
  { "origin_url", offsetof(git_repository_init_options, origin_url),
                  sizeof(((git_repository_init_options *)0)->origin_url),
                  _CFFI_OP(_CFFI_OP_NOOP, 10) },
  { "lines_in_hunk", offsetof(git_blame_hunk, lines_in_hunk),
                     sizeof(((git_blame_hunk *)0)->lines_in_hunk),
                     _CFFI_OP(_CFFI_OP_NOOP, 14) },
  { "final_commit_id", offsetof(git_blame_hunk, final_commit_id),
                       sizeof(((git_blame_hunk *)0)->final_commit_id),
                       _CFFI_OP(_CFFI_OP_NOOP, 735) },
  { "final_start_line_number", offsetof(git_blame_hunk, final_start_line_number),
                               sizeof(((git_blame_hunk *)0)->final_start_line_number),
                               _CFFI_OP(_CFFI_OP_NOOP, 14) },
  { "final_signature", offsetof(git_blame_hunk, final_signature),
                       sizeof(((git_blame_hunk *)0)->final_signature),
                       _CFFI_OP(_CFFI_OP_NOOP, 750) },
  { "orig_commit_id", offsetof(git_blame_hunk, orig_commit_id),
                      sizeof(((git_blame_hunk *)0)->orig_commit_id),
                      _CFFI_OP(_CFFI_OP_NOOP, 735) },
  { "orig_path", offsetof(git_blame_hunk, orig_path),
                 sizeof(((git_blame_hunk *)0)->orig_path),
                 _CFFI_OP(_CFFI_OP_NOOP, 10) },
  { "orig_start_line_number", offsetof(git_blame_hunk, orig_start_line_number),
                              sizeof(((git_blame_hunk *)0)->orig_start_line_number),
                              _CFFI_OP(_CFFI_OP_NOOP, 14) },
  { "orig_signature", offsetof(git_blame_hunk, orig_signature),
                      sizeof(((git_blame_hunk *)0)->orig_signature),
                      _CFFI_OP(_CFFI_OP_NOOP, 750) },
  { "boundary", offsetof(git_blame_hunk, boundary),
                sizeof(((git_blame_hunk *)0)->boundary),
                _CFFI_OP(_CFFI_OP_NOOP, 682) },
  { "version", offsetof(git_blame_options, version),
               sizeof(((git_blame_options *)0)->version),
               _CFFI_OP(_CFFI_OP_NOOP, 85) },
  { "flags", offsetof(git_blame_options, flags),
             sizeof(((git_blame_options *)0)->flags),
             _CFFI_OP(_CFFI_OP_NOOP, 18) },
  { "min_match_characters", offsetof(git_blame_options, min_match_characters),
                            sizeof(((git_blame_options *)0)->min_match_characters),
                            _CFFI_OP(_CFFI_OP_NOOP, 784) },
  { "newest_commit", offsetof(git_blame_options, newest_commit),
                     sizeof(((git_blame_options *)0)->newest_commit),
                     _CFFI_OP(_CFFI_OP_NOOP, 735) },
  { "oldest_commit", offsetof(git_blame_options, oldest_commit),
                     sizeof(((git_blame_options *)0)->oldest_commit),
                     _CFFI_OP(_CFFI_OP_NOOP, 735) },
  { "min_line", offsetof(git_blame_options, min_line),
                sizeof(((git_blame_options *)0)->min_line),
                _CFFI_OP(_CFFI_OP_NOOP, 14) },
  { "max_line", offsetof(git_blame_options, max_line),
                sizeof(((git_blame_options *)0)->max_line),
                _CFFI_OP(_CFFI_OP_NOOP, 14) },
  { "version", offsetof(git_checkout_options, version),
               sizeof(((git_checkout_options *)0)->version),
               _CFFI_OP(_CFFI_OP_NOOP, 85) },
  { "checkout_strategy", offsetof(git_checkout_options, checkout_strategy),
                         sizeof(((git_checkout_options *)0)->checkout_strategy),
                         _CFFI_OP(_CFFI_OP_NOOP, 85) },
  { "disable_filters", offsetof(git_checkout_options, disable_filters),
                       sizeof(((git_checkout_options *)0)->disable_filters),
                       _CFFI_OP(_CFFI_OP_NOOP, 28) },
  { "dir_mode", offsetof(git_checkout_options, dir_mode),
                sizeof(((git_checkout_options *)0)->dir_mode),
                _CFFI_OP(_CFFI_OP_NOOP, 85) },
  { "file_mode", offsetof(git_checkout_options, file_mode),
                 sizeof(((git_checkout_options *)0)->file_mode),
                 _CFFI_OP(_CFFI_OP_NOOP, 85) },
  { "file_open_flags", offsetof(git_checkout_options, file_open_flags),
                       sizeof(((git_checkout_options *)0)->file_open_flags),
                       _CFFI_OP(_CFFI_OP_NOOP, 28) },
  { "notify_flags", offsetof(git_checkout_options, notify_flags),
                    sizeof(((git_checkout_options *)0)->notify_flags),
                    _CFFI_OP(_CFFI_OP_NOOP, 85) },
  { "notify_cb", offsetof(git_checkout_options, notify_cb),
                 sizeof(((git_checkout_options *)0)->notify_cb),
                 _CFFI_OP(_CFFI_OP_NOOP, 767) },
  { "notify_payload", offsetof(git_checkout_options, notify_payload),
                      sizeof(((git_checkout_options *)0)->notify_payload),
                      _CFFI_OP(_CFFI_OP_NOOP, 64) },
  { "progress_cb", offsetof(git_checkout_options, progress_cb),
                   sizeof(((git_checkout_options *)0)->progress_cb),
                   _CFFI_OP(_CFFI_OP_NOOP, 791) },
  { "progress_payload", offsetof(git_checkout_options, progress_payload),
                        sizeof(((git_checkout_options *)0)->progress_payload),
                        _CFFI_OP(_CFFI_OP_NOOP, 64) },
  { "paths", offsetof(git_checkout_options, paths),
             sizeof(((git_checkout_options *)0)->paths),
             _CFFI_OP(_CFFI_OP_NOOP, 755) },
  { "baseline", offsetof(git_checkout_options, baseline),
                sizeof(((git_checkout_options *)0)->baseline),
                _CFFI_OP(_CFFI_OP_NOOP, 238) },
  { "baseline_index", offsetof(git_checkout_options, baseline_index),
                      sizeof(((git_checkout_options *)0)->baseline_index),
                      _CFFI_OP(_CFFI_OP_NOOP, 26) },
  { "target_directory", offsetof(git_checkout_options, target_directory),
                        sizeof(((git_checkout_options *)0)->target_directory),
                        _CFFI_OP(_CFFI_OP_NOOP, 10) },
  { "ancestor_label", offsetof(git_checkout_options, ancestor_label),
                      sizeof(((git_checkout_options *)0)->ancestor_label),
                      _CFFI_OP(_CFFI_OP_NOOP, 10) },
  { "our_label", offsetof(git_checkout_options, our_label),
                 sizeof(((git_checkout_options *)0)->our_label),
                 _CFFI_OP(_CFFI_OP_NOOP, 10) },
  { "their_label", offsetof(git_checkout_options, their_label),
                   sizeof(((git_checkout_options *)0)->their_label),
                   _CFFI_OP(_CFFI_OP_NOOP, 10) },
  { "perfdata_cb", offsetof(git_checkout_options, perfdata_cb),
                   sizeof(((git_checkout_options *)0)->perfdata_cb),
                   _CFFI_OP(_CFFI_OP_NOOP, 792) },
  { "perfdata_payload", offsetof(git_checkout_options, perfdata_payload),
                        sizeof(((git_checkout_options *)0)->perfdata_payload),
                        _CFFI_OP(_CFFI_OP_NOOP, 64) },
  { "version", offsetof(git_clone_options, version),
               sizeof(((git_clone_options *)0)->version),
               _CFFI_OP(_CFFI_OP_NOOP, 85) },
  { "checkout_opts", offsetof(git_clone_options, checkout_opts),
                     sizeof(((git_clone_options *)0)->checkout_opts),
                     _CFFI_OP(_CFFI_OP_NOOP, 694) },
  { "fetch_opts", offsetof(git_clone_options, fetch_opts),
                  sizeof(((git_clone_options *)0)->fetch_opts),
                  _CFFI_OP(_CFFI_OP_NOOP, 722) },
  { "bare", offsetof(git_clone_options, bare),
            sizeof(((git_clone_options *)0)->bare),
            _CFFI_OP(_CFFI_OP_NOOP, 28) },
  { "local", offsetof(git_clone_options, local),
             sizeof(((git_clone_options *)0)->local),
             _CFFI_OP(_CFFI_OP_NOOP, 696) },
  { "checkout_branch", offsetof(git_clone_options, checkout_branch),
                       sizeof(((git_clone_options *)0)->checkout_branch),
                       _CFFI_OP(_CFFI_OP_NOOP, 10) },
  { "repository_cb", offsetof(git_clone_options, repository_cb),
                     sizeof(((git_clone_options *)0)->repository_cb),
                     _CFFI_OP(_CFFI_OP_NOOP, 774) },
  { "repository_cb_payload", offsetof(git_clone_options, repository_cb_payload),
                             sizeof(((git_clone_options *)0)->repository_cb_payload),
                             _CFFI_OP(_CFFI_OP_NOOP, 64) },
  { "remote_cb", offsetof(git_clone_options, remote_cb),
                 sizeof(((git_clone_options *)0)->remote_cb),
                 _CFFI_OP(_CFFI_OP_NOOP, 772) },
  { "remote_cb_payload", offsetof(git_clone_options, remote_cb_payload),
                         sizeof(((git_clone_options *)0)->remote_cb_payload),
                         _CFFI_OP(_CFFI_OP_NOOP, 64) },
  { "name", offsetof(git_config_entry, name),
            sizeof(((git_config_entry *)0)->name),
            _CFFI_OP(_CFFI_OP_NOOP, 10) },
  { "value", offsetof(git_config_entry, value),
             sizeof(((git_config_entry *)0)->value),
             _CFFI_OP(_CFFI_OP_NOOP, 10) },
  { "include_depth", offsetof(git_config_entry, include_depth),
                     sizeof(((git_config_entry *)0)->include_depth),
                     _CFFI_OP(_CFFI_OP_NOOP, 85) },
  { "level", offsetof(git_config_entry, level),
             sizeof(((git_config_entry *)0)->level),
             _CFFI_OP(_CFFI_OP_NOOP, 155) },
  { "free", offsetof(git_config_entry, free),
            sizeof(((git_config_entry *)0)->free),
            _CFFI_OP(_CFFI_OP_NOOP, 793) },
  { "payload", offsetof(git_config_entry, payload),
               sizeof(((git_config_entry *)0)->payload),
               _CFFI_OP(_CFFI_OP_NOOP, 64) },
  { "version", offsetof(git_describe_options, version),
               sizeof(((git_describe_options *)0)->version),
               _CFFI_OP(_CFFI_OP_NOOP, 85) },
  { "max_candidates_tags", offsetof(git_describe_options, max_candidates_tags),
                           sizeof(((git_describe_options *)0)->max_candidates_tags),
                           _CFFI_OP(_CFFI_OP_NOOP, 85) },
  { "describe_strategy", offsetof(git_describe_options, describe_strategy),
                         sizeof(((git_describe_options *)0)->describe_strategy),
                         _CFFI_OP(_CFFI_OP_NOOP, 85) },
  { "pattern", offsetof(git_describe_options, pattern),
               sizeof(((git_describe_options *)0)->pattern),
               _CFFI_OP(_CFFI_OP_NOOP, 10) },
  { "only_follow_first_parent", offsetof(git_describe_options, only_follow_first_parent),
                                sizeof(((git_describe_options *)0)->only_follow_first_parent),
                                _CFFI_OP(_CFFI_OP_NOOP, 28) },
  { "show_commit_oid_as_fallback", offsetof(git_describe_options, show_commit_oid_as_fallback),
                                   sizeof(((git_describe_options *)0)->show_commit_oid_as_fallback),
                                   _CFFI_OP(_CFFI_OP_NOOP, 28) },
  { "ctime", offsetof(git_index_entry, ctime),
             sizeof(((git_index_entry *)0)->ctime),
             _CFFI_OP(_CFFI_OP_NOOP, 727) },
  { "mtime", offsetof(git_index_entry, mtime),
             sizeof(((git_index_entry *)0)->mtime),
             _CFFI_OP(_CFFI_OP_NOOP, 727) },
  { "dev", offsetof(git_index_entry, dev),
           sizeof(((git_index_entry *)0)->dev),
           _CFFI_OP(_CFFI_OP_NOOP, 18) },
  { "ino", offsetof(git_index_entry, ino),
           sizeof(((git_index_entry *)0)->ino),
           _CFFI_OP(_CFFI_OP_NOOP, 18) },
  { "mode", offsetof(git_index_entry, mode),
            sizeof(((git_index_entry *)0)->mode),
            _CFFI_OP(_CFFI_OP_NOOP, 18) },
  { "uid", offsetof(git_index_entry, uid),
           sizeof(((git_index_entry *)0)->uid),
           _CFFI_OP(_CFFI_OP_NOOP, 18) },
  { "gid", offsetof(git_index_entry, gid),
           sizeof(((git_index_entry *)0)->gid),
           _CFFI_OP(_CFFI_OP_NOOP, 18) },
  { "file_size", offsetof(git_index_entry, file_size),
                 sizeof(((git_index_entry *)0)->file_size),
                 _CFFI_OP(_CFFI_OP_NOOP, 18) },
  { "id", offsetof(git_index_entry, id),
          sizeof(((git_index_entry *)0)->id),
          _CFFI_OP(_CFFI_OP_NOOP, 735) },
  { "flags", offsetof(git_index_entry, flags),
             sizeof(((git_index_entry *)0)->flags),
             _CFFI_OP(_CFFI_OP_NOOP, 784) },
  { "flags_extended", offsetof(git_index_entry, flags_extended),
                      sizeof(((git_index_entry *)0)->flags_extended),
                      _CFFI_OP(_CFFI_OP_NOOP, 784) },
  { "path", offsetof(git_index_entry, path),
            sizeof(((git_index_entry *)0)->path),
            _CFFI_OP(_CFFI_OP_NOOP, 10) },
  { "id", offsetof(git_oid, id),
          sizeof(((git_oid *)0)->id),
          _CFFI_OP(_CFFI_OP_NOOP, 788) },
  { "version", offsetof(git_remote_callbacks, version),
               sizeof(((git_remote_callbacks *)0)->version),
               _CFFI_OP(_CFFI_OP_NOOP, 85) },
  { "sideband_progress", offsetof(git_remote_callbacks, sideband_progress),
                         sizeof(((git_remote_callbacks *)0)->sideband_progress),
                         _CFFI_OP(_CFFI_OP_NOOP, 765) },
  { "completion", offsetof(git_remote_callbacks, completion),
                  sizeof(((git_remote_callbacks *)0)->completion),
                  _CFFI_OP(_CFFI_OP_NOOP, 773) },
  { "credentials", offsetof(git_remote_callbacks, credentials),
                   sizeof(((git_remote_callbacks *)0)->credentials),
                   _CFFI_OP(_CFFI_OP_NOOP, 768) },
  { "certificate_check", offsetof(git_remote_callbacks, certificate_check),
                         sizeof(((git_remote_callbacks *)0)->certificate_check),
                         _CFFI_OP(_CFFI_OP_NOOP, 766) },
  { "transfer_progress", offsetof(git_remote_callbacks, transfer_progress),
                         sizeof(((git_remote_callbacks *)0)->transfer_progress),
                         _CFFI_OP(_CFFI_OP_NOOP, 776) },
  { "update_tips", offsetof(git_remote_callbacks, update_tips),
                   sizeof(((git_remote_callbacks *)0)->update_tips),
                   _CFFI_OP(_CFFI_OP_NOOP, 764) },
  { "pack_progress", offsetof(git_remote_callbacks, pack_progress),
                     sizeof(((git_remote_callbacks *)0)->pack_progress),
                     _CFFI_OP(_CFFI_OP_NOOP, 779) },
  { "push_transfer_progress", offsetof(git_remote_callbacks, push_transfer_progress),
                              sizeof(((git_remote_callbacks *)0)->push_transfer_progress),
                              _CFFI_OP(_CFFI_OP_NOOP, 780) },
  { "push_update_reference", offsetof(git_remote_callbacks, push_update_reference),
                             sizeof(((git_remote_callbacks *)0)->push_update_reference),
                             _CFFI_OP(_CFFI_OP_NOOP, 313) },
  { "push_negotiation", offsetof(git_remote_callbacks, push_negotiation),
                        sizeof(((git_remote_callbacks *)0)->push_negotiation),
                        _CFFI_OP(_CFFI_OP_NOOP, 771) },
  { "transport", offsetof(git_remote_callbacks, transport),
                 sizeof(((git_remote_callbacks *)0)->transport),
                 _CFFI_OP(_CFFI_OP_NOOP, 777) },
  { "payload", offsetof(git_remote_callbacks, payload),
               sizeof(((git_remote_callbacks *)0)->payload),
               _CFFI_OP(_CFFI_OP_NOOP, 64) },
  { "name", offsetof(git_signature, name),
            sizeof(((git_signature *)0)->name),
            _CFFI_OP(_CFFI_OP_NOOP, 681) },
  { "email", offsetof(git_signature, email),
             sizeof(((git_signature *)0)->email),
             _CFFI_OP(_CFFI_OP_NOOP, 681) },
  { "when", offsetof(git_signature, when),
            sizeof(((git_signature *)0)->when),
            _CFFI_OP(_CFFI_OP_NOOP, 759) },
  { "version", offsetof(git_stash_apply_options, version),
               sizeof(((git_stash_apply_options *)0)->version),
               _CFFI_OP(_CFFI_OP_NOOP, 85) },
  { "flags", offsetof(git_stash_apply_options, flags),
             sizeof(((git_stash_apply_options *)0)->flags),
             _CFFI_OP(_CFFI_OP_NOOP, 752) },
  { "checkout_options", offsetof(git_stash_apply_options, checkout_options),
                        sizeof(((git_stash_apply_options *)0)->checkout_options),
                        _CFFI_OP(_CFFI_OP_NOOP, 694) },
  { "progress_cb", offsetof(git_stash_apply_options, progress_cb),
                   sizeof(((git_stash_apply_options *)0)->progress_cb),
                   _CFFI_OP(_CFFI_OP_NOOP, 775) },
  { "progress_payload", offsetof(git_stash_apply_options, progress_payload),
                        sizeof(((git_stash_apply_options *)0)->progress_payload),
                        _CFFI_OP(_CFFI_OP_NOOP, 64) },
  { "strings", offsetof(git_strarray, strings),
               sizeof(((git_strarray *)0)->strings),
               _CFFI_OP(_CFFI_OP_NOOP, 680) },
  { "count", offsetof(git_strarray, count),
             sizeof(((git_strarray *)0)->count),
             _CFFI_OP(_CFFI_OP_NOOP, 14) },
  { "version", offsetof(git_submodule_update_options, version),
               sizeof(((git_submodule_update_options *)0)->version),
               _CFFI_OP(_CFFI_OP_NOOP, 85) },
  { "checkout_opts", offsetof(git_submodule_update_options, checkout_opts),
                     sizeof(((git_submodule_update_options *)0)->checkout_opts),
                     _CFFI_OP(_CFFI_OP_NOOP, 694) },
  { "fetch_opts", offsetof(git_submodule_update_options, fetch_opts),
                  sizeof(((git_submodule_update_options *)0)->fetch_opts),
                  _CFFI_OP(_CFFI_OP_NOOP, 722) },
  { "allow_fetch", offsetof(git_submodule_update_options, allow_fetch),
                   sizeof(((git_submodule_update_options *)0)->allow_fetch),
                   _CFFI_OP(_CFFI_OP_NOOP, 28) },
  { "time", offsetof(git_time, time),
            sizeof(((git_time *)0)->time),
            _CFFI_OP(_CFFI_OP_NOOP, 167) },
  { "offset", offsetof(git_time, offset),
              sizeof(((git_time *)0)->offset),
              _CFFI_OP(_CFFI_OP_NOOP, 28) },
  { "sign", offsetof(git_time, sign),
            sizeof(((git_time *)0)->sign),
            _CFFI_OP(_CFFI_OP_NOOP, 682) },
  { "total_objects", offsetof(git_transfer_progress, total_objects),
                     sizeof(((git_transfer_progress *)0)->total_objects),
                     _CFFI_OP(_CFFI_OP_NOOP, 85) },
  { "indexed_objects", offsetof(git_transfer_progress, indexed_objects),
                       sizeof(((git_transfer_progress *)0)->indexed_objects),
                       _CFFI_OP(_CFFI_OP_NOOP, 85) },
  { "received_objects", offsetof(git_transfer_progress, received_objects),
                        sizeof(((git_transfer_progress *)0)->received_objects),
                        _CFFI_OP(_CFFI_OP_NOOP, 85) },
  { "local_objects", offsetof(git_transfer_progress, local_objects),
                     sizeof(((git_transfer_progress *)0)->local_objects),
                     _CFFI_OP(_CFFI_OP_NOOP, 85) },
  { "total_deltas", offsetof(git_transfer_progress, total_deltas),
                    sizeof(((git_transfer_progress *)0)->total_deltas),
                    _CFFI_OP(_CFFI_OP_NOOP, 85) },
  { "indexed_deltas", offsetof(git_transfer_progress, indexed_deltas),
                      sizeof(((git_transfer_progress *)0)->indexed_deltas),
                      _CFFI_OP(_CFFI_OP_NOOP, 85) },
  { "received_bytes", offsetof(git_transfer_progress, received_bytes),
                      sizeof(((git_transfer_progress *)0)->received_bytes),
                      _CFFI_OP(_CFFI_OP_NOOP, 14) },
};

static const struct _cffi_struct_union_s _cffi_struct_unions[] = {
  { "$git_buf", 688, _CFFI_F_CHECK_FIELDS,
    sizeof(git_buf), offsetof(struct _cffi_align_typedef_git_buf, y), 0, 3 },
  { "$git_cert", 689, _CFFI_F_CHECK_FIELDS,
    sizeof(git_cert), offsetof(struct _cffi_align_typedef_git_cert, y), 3, 1 },
  { "$git_cert_hostkey", 690, _CFFI_F_CHECK_FIELDS,
    sizeof(git_cert_hostkey), offsetof(struct _cffi_align_typedef_git_cert_hostkey, y), 4, 4 },
  { "$git_cert_x509", 693, _CFFI_F_CHECK_FIELDS,
    sizeof(git_cert_x509), offsetof(struct _cffi_align_typedef_git_cert_x509, y), 8, 3 },
  { "$git_checkout_perfdata", 695, _CFFI_F_CHECK_FIELDS,
    sizeof(git_checkout_perfdata), offsetof(struct _cffi_align_typedef_git_checkout_perfdata, y), 11, 3 },
  { "$git_describe_format_options", 706, _CFFI_F_CHECK_FIELDS,
    sizeof(git_describe_format_options), offsetof(struct _cffi_align_typedef_git_describe_format_options, y), 14, 4 },
  { "$git_diff_delta", 712, _CFFI_F_CHECK_FIELDS,
    sizeof(git_diff_delta), offsetof(struct _cffi_align_typedef_git_diff_delta, y), 18, 6 },
  { "$git_diff_file", 713, _CFFI_F_CHECK_FIELDS,
    sizeof(git_diff_file), offsetof(struct _cffi_align_typedef_git_diff_file, y), 24, 6 },
  { "$git_diff_options", 714, _CFFI_F_CHECK_FIELDS,
    sizeof(git_diff_options), offsetof(struct _cffi_align_typedef_git_diff_options, y), 30, 13 },
  { "$git_diff_similarity_metric", 716, _CFFI_F_CHECK_FIELDS,
    sizeof(git_diff_similarity_metric), offsetof(struct _cffi_align_typedef_git_diff_similarity_metric, y), 43, 5 },
  { "$git_error", 719, _CFFI_F_CHECK_FIELDS,
    sizeof(git_error), offsetof(struct _cffi_align_typedef_git_error, y), 48, 2 },
  { "$git_fetch_options", 722, _CFFI_F_CHECK_FIELDS,
    sizeof(git_fetch_options), offsetof(struct _cffi_align_typedef_git_fetch_options, y), 50, 7 },
  { "$git_index_time", 727, _CFFI_F_CHECK_FIELDS,
    sizeof(git_index_time), offsetof(struct _cffi_align_typedef_git_index_time, y), 57, 2 },
  { "$git_merge_file_options", 730, _CFFI_F_CHECK_FIELDS,
    sizeof(git_merge_file_options), offsetof(struct _cffi_align_typedef_git_merge_file_options, y), 59, 7 },
  { "$git_merge_file_result", 731, _CFFI_F_CHECK_FIELDS,
    sizeof(git_merge_file_result), offsetof(struct _cffi_align_typedef_git_merge_file_result, y), 66, 5 },
  { "$git_merge_options", 733, _CFFI_F_CHECK_FIELDS,
    sizeof(git_merge_options), offsetof(struct _cffi_align_typedef_git_merge_options, y), 71, 9 },
  { "$git_proxy_options", 736, _CFFI_F_CHECK_FIELDS,
    sizeof(git_proxy_options), offsetof(struct _cffi_align_typedef_git_proxy_options, y), 80, 6 },
  { "$git_push_options", 738, _CFFI_F_CHECK_FIELDS,
    sizeof(git_push_options), offsetof(struct _cffi_align_typedef_git_push_options, y), 86, 5 },
  { "$git_push_update", 740, _CFFI_F_CHECK_FIELDS,
    sizeof(git_push_update), offsetof(struct _cffi_align_typedef_git_push_update, y), 91, 4 },
  { "$git_repository_init_options", 749, _CFFI_F_CHECK_FIELDS,
    sizeof(git_repository_init_options), offsetof(struct _cffi_align_typedef_git_repository_init_options, y), 95, 8 },
  { "git_blame", 684, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "git_blame_hunk", 686, _CFFI_F_CHECK_FIELDS,
    sizeof(git_blame_hunk), offsetof(struct _cffi_align__git_blame_hunk, y), 103, 9 },
  { "git_blame_options", 687, _CFFI_F_CHECK_FIELDS,
    sizeof(git_blame_options), offsetof(struct _cffi_align__git_blame_options, y), 112, 7 },
  { "git_checkout_options", 694, _CFFI_F_CHECK_FIELDS,
    sizeof(git_checkout_options), offsetof(struct _cffi_align__git_checkout_options, y), 119, 20 },
  { "git_clone_options", 697, _CFFI_F_CHECK_FIELDS,
    sizeof(git_clone_options), offsetof(struct _cffi_align__git_clone_options, y), 139, 10 },
  { "git_commit", 698, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "git_config", 699, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "git_config_entry", 700, _CFFI_F_CHECK_FIELDS,
    sizeof(git_config_entry), offsetof(struct _cffi_align__git_config_entry, y), 149, 6 },
  { "git_config_iterator", 701, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "git_cred", 703, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "git_describe_options", 707, _CFFI_F_CHECK_FIELDS,
    sizeof(git_describe_options), offsetof(struct _cffi_align__git_describe_options, y), 155, 6 },
  { "git_describe_result", 708, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "git_diff", 711, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "git_index", 724, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "git_index_conflict_iterator", 725, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "git_index_entry", 726, _CFFI_F_CHECK_FIELDS,
    sizeof(git_index_entry), offsetof(struct _cffi_align__git_index_entry, y), 161, 12 },
  { "git_object", 734, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "git_oid", 735, _CFFI_F_CHECK_FIELDS,
    sizeof(git_oid), offsetof(struct _cffi_align__git_oid, y), 173, 1 },
  { "git_refspec", 742, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "git_remote", 743, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "git_remote_callbacks", 745, _CFFI_F_CHECK_FIELDS,
    sizeof(git_remote_callbacks), offsetof(struct _cffi_align__git_remote_callbacks, y), 174, 13 },
  { "git_repository", 746, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "git_signature", 751, _CFFI_F_CHECK_FIELDS,
    sizeof(git_signature), offsetof(struct _cffi_align__git_signature, y), 187, 3 },
  { "git_stash_apply_options", 753, _CFFI_F_CHECK_FIELDS,
    sizeof(git_stash_apply_options), offsetof(struct _cffi_align__git_stash_apply_options, y), 190, 5 },
  { "git_strarray", 755, _CFFI_F_CHECK_FIELDS,
    sizeof(git_strarray), offsetof(struct _cffi_align__git_strarray, y), 195, 2 },
  { "git_submodule", 756, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "git_submodule_update_options", 758, _CFFI_F_CHECK_FIELDS,
    sizeof(git_submodule_update_options), offsetof(struct _cffi_align__git_submodule_update_options, y), 197, 4 },
  { "git_time", 759, _CFFI_F_CHECK_FIELDS,
    sizeof(git_time), offsetof(struct _cffi_align__git_time, y), 201, 3 },
  { "git_transfer_progress", 760, _CFFI_F_CHECK_FIELDS,
    sizeof(git_transfer_progress), offsetof(struct _cffi_align__git_transfer_progress, y), 204, 7 },
  { "git_transport", 762, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "git_tree", 763, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
};

static const struct _cffi_enum_s _cffi_enums[] = {
  { "$git_attr_t", 683, _cffi_prim_int(sizeof(git_attr_t), ((git_attr_t)-1) <= 0),
    "GIT_ATTR_UNSPECIFIED_T,GIT_ATTR_TRUE_T,GIT_ATTR_FALSE_T,GIT_ATTR_VALUE_T" },
  { "$git_cert_ssh_t", 691, _cffi_prim_int(sizeof(git_cert_ssh_t), ((git_cert_ssh_t)-1) <= 0),
    "GIT_CERT_SSH_MD5,GIT_CERT_SSH_SHA1" },
  { "$git_checkout_notify_t", 107, _cffi_prim_int(sizeof(git_checkout_notify_t), ((git_checkout_notify_t)-1) <= 0),
    "GIT_CHECKOUT_NOTIFY_NONE,GIT_CHECKOUT_NOTIFY_CONFLICT,GIT_CHECKOUT_NOTIFY_DIRTY,GIT_CHECKOUT_NOTIFY_UPDATED,GIT_CHECKOUT_NOTIFY_UNTRACKED,GIT_CHECKOUT_NOTIFY_IGNORED,GIT_CHECKOUT_NOTIFY_ALL" },
  { "$git_clone_local_t", 696, _cffi_prim_int(sizeof(git_clone_local_t), ((git_clone_local_t)-1) <= 0),
    "GIT_CLONE_LOCAL_AUTO,GIT_CLONE_LOCAL,GIT_CLONE_NO_LOCAL,GIT_CLONE_LOCAL_NO_LINKS" },
  { "$git_config_level_t", 155, _cffi_prim_int(sizeof(git_config_level_t), ((git_config_level_t)-1) <= 0),
    "GIT_CONFIG_LEVEL_PROGRAMDATA,GIT_CONFIG_LEVEL_SYSTEM,GIT_CONFIG_LEVEL_XDG,GIT_CONFIG_LEVEL_GLOBAL,GIT_CONFIG_LEVEL_LOCAL,GIT_CONFIG_LEVEL_APP,GIT_CONFIG_HIGHEST_LEVEL" },
  { "$git_credtype_t", 704, _cffi_prim_int(sizeof(git_credtype_t), ((git_credtype_t)-1) <= 0),
    "GIT_CREDTYPE_USERPASS_PLAINTEXT,GIT_CREDTYPE_SSH_KEY,GIT_CREDTYPE_SSH_CUSTOM,GIT_CREDTYPE_DEFAULT,GIT_CREDTYPE_SSH_INTERACTIVE,GIT_CREDTYPE_USERNAME,GIT_CREDTYPE_SSH_MEMORY" },
  { "$git_delta_t", 705, _cffi_prim_int(sizeof(git_delta_t), ((git_delta_t)-1) <= 0),
    "GIT_DELTA_UNMODIFIED,GIT_DELTA_ADDED,GIT_DELTA_DELETED,GIT_DELTA_MODIFIED,GIT_DELTA_RENAMED,GIT_DELTA_COPIED,GIT_DELTA_IGNORED,GIT_DELTA_UNTRACKED,GIT_DELTA_TYPECHANGE,GIT_DELTA_UNREADABLE,GIT_DELTA_CONFLICTED" },
  { "$git_describe_strategy_t", 709, _cffi_prim_int(sizeof(git_describe_strategy_t), ((git_describe_strategy_t)-1) <= 0),
    "GIT_DESCRIBE_DEFAULT,GIT_DESCRIBE_TAGS,GIT_DESCRIBE_ALL" },
  { "$git_direction", 717, _cffi_prim_int(sizeof(git_direction), ((git_direction)-1) <= 0),
    "GIT_DIRECTION_FETCH,GIT_DIRECTION_PUSH" },
  { "$git_error_code", 720, _cffi_prim_int(sizeof(git_error_code), ((git_error_code)-1) <= 0),
    "GIT_OK,GIT_ERROR,GIT_ENOTFOUND,GIT_EEXISTS,GIT_EAMBIGUOUS,GIT_EBUFS,GIT_EUSER,GIT_EBAREREPO,GIT_EUNBORNBRANCH,GIT_EUNMERGED,GIT_ENONFASTFORWARD,GIT_EINVALIDSPEC,GIT_ECONFLICT,GIT_ELOCKED,GIT_EMODIFIED,GIT_EAUTH,GIT_ECERTIFICATE,GIT_EAPPLIED,GIT_EPEEL,GIT_EEOF,GIT_EINVALID,GIT_EUNCOMMITTED,GIT_EDIRECTORY,GIT_EMERGECONFLICT,GIT_PASSTHROUGH,GIT_ITEROVER,GIT_RETRY,GIT_EMISMATCH,GIT_EINDEXDIRTY,GIT_EAPPLYFAIL" },
  { "$git_feature_t", 721, _cffi_prim_int(sizeof(git_feature_t), ((git_feature_t)-1) <= 0),
    "GIT_FEATURE_THREADS,GIT_FEATURE_HTTPS,GIT_FEATURE_SSH,GIT_FEATURE_NSEC" },
  { "$git_fetch_prune_t", 723, _cffi_prim_int(sizeof(git_fetch_prune_t), ((git_fetch_prune_t)-1) <= 0),
    "GIT_FETCH_PRUNE_UNSPECIFIED,GIT_FETCH_PRUNE,GIT_FETCH_NO_PRUNE" },
  { "$git_merge_file_favor_t", 728, _cffi_prim_int(sizeof(git_merge_file_favor_t), ((git_merge_file_favor_t)-1) <= 0),
    "GIT_MERGE_FILE_FAVOR_NORMAL,GIT_MERGE_FILE_FAVOR_OURS,GIT_MERGE_FILE_FAVOR_THEIRS,GIT_MERGE_FILE_FAVOR_UNION" },
  { "$git_merge_file_flag_t", 729, _cffi_prim_int(sizeof(git_merge_file_flag_t), ((git_merge_file_flag_t)-1) <= 0),
    "GIT_MERGE_FILE_DEFAULT,GIT_MERGE_FILE_STYLE_MERGE,GIT_MERGE_FILE_STYLE_DIFF3,GIT_MERGE_FILE_SIMPLIFY_ALNUM,GIT_MERGE_FILE_IGNORE_WHITESPACE,GIT_MERGE_FILE_IGNORE_WHITESPACE_CHANGE,GIT_MERGE_FILE_IGNORE_WHITESPACE_EOL,GIT_MERGE_FILE_DIFF_PATIENCE,GIT_MERGE_FILE_DIFF_MINIMAL" },
  { "$git_merge_flag_t", 732, _cffi_prim_int(sizeof(git_merge_flag_t), ((git_merge_flag_t)-1) <= 0),
    "GIT_MERGE_FIND_RENAMES,GIT_MERGE_FAIL_ON_CONFLICT,GIT_MERGE_SKIP_REUC,GIT_MERGE_NO_RECURSIVE" },
  { "$git_proxy_t", 737, _cffi_prim_int(sizeof(git_proxy_t), ((git_proxy_t)-1) <= 0),
    "GIT_PROXY_NONE,GIT_PROXY_AUTO,GIT_PROXY_SPECIFIED" },
  { "$git_reference_t", 741, _cffi_prim_int(sizeof(git_reference_t), ((git_reference_t)-1) <= 0),
    "GIT_REFERENCE_INVALID,GIT_REFERENCE_DIRECT,GIT_REFERENCE_SYMBOLIC,GIT_REFERENCE_ALL" },
  { "$git_remote_autotag_option_t", 744, _cffi_prim_int(sizeof(git_remote_autotag_option_t), ((git_remote_autotag_option_t)-1) <= 0),
    "GIT_REMOTE_DOWNLOAD_TAGS_UNSPECIFIED,GIT_REMOTE_DOWNLOAD_TAGS_AUTO,GIT_REMOTE_DOWNLOAD_TAGS_NONE,GIT_REMOTE_DOWNLOAD_TAGS_ALL" },
  { "$git_repository_init_flag_t", 747, _cffi_prim_int(sizeof(git_repository_init_flag_t), ((git_repository_init_flag_t)-1) <= 0),
    "GIT_REPOSITORY_INIT_BARE,GIT_REPOSITORY_INIT_NO_REINIT,GIT_REPOSITORY_INIT_NO_DOTGIT_DIR,GIT_REPOSITORY_INIT_MKDIR,GIT_REPOSITORY_INIT_MKPATH,GIT_REPOSITORY_INIT_EXTERNAL_TEMPLATE,GIT_REPOSITORY_INIT_RELATIVE_GITLINK" },
  { "$git_repository_init_mode_t", 748, _cffi_prim_int(sizeof(git_repository_init_mode_t), ((git_repository_init_mode_t)-1) <= 0),
    "GIT_REPOSITORY_INIT_SHARED_UMASK,GIT_REPOSITORY_INIT_SHARED_GROUP,GIT_REPOSITORY_INIT_SHARED_ALL" },
  { "$git_stash_apply_flags", 752, _cffi_prim_int(sizeof(git_stash_apply_flags), ((git_stash_apply_flags)-1) <= 0),
    "GIT_STASH_APPLY_DEFAULT,GIT_STASH_APPLY_REINSTATE_INDEX" },
  { "$git_stash_apply_progress_t", 519, _cffi_prim_int(sizeof(git_stash_apply_progress_t), ((git_stash_apply_progress_t)-1) <= 0),
    "GIT_STASH_APPLY_PROGRESS_NONE,GIT_STASH_APPLY_PROGRESS_LOADING_STASH,GIT_STASH_APPLY_PROGRESS_ANALYZE_INDEX,GIT_STASH_APPLY_PROGRESS_ANALYZE_MODIFIED,GIT_STASH_APPLY_PROGRESS_ANALYZE_UNTRACKED,GIT_STASH_APPLY_PROGRESS_CHECKOUT_UNTRACKED,GIT_STASH_APPLY_PROGRESS_CHECKOUT_MODIFIED,GIT_STASH_APPLY_PROGRESS_DONE" },
  { "$git_stash_flags", 754, _cffi_prim_int(sizeof(git_stash_flags), ((git_stash_flags)-1) <= 0),
    "GIT_STASH_DEFAULT,GIT_STASH_KEEP_INDEX,GIT_STASH_INCLUDE_UNTRACKED,GIT_STASH_INCLUDE_IGNORED" },
  { "$git_submodule_ignore_t", 757, _cffi_prim_int(sizeof(git_submodule_ignore_t), ((git_submodule_ignore_t)-1) <= 0),
    "GIT_SUBMODULE_IGNORE_UNSPECIFIED,GIT_SUBMODULE_IGNORE_NONE,GIT_SUBMODULE_IGNORE_UNTRACKED,GIT_SUBMODULE_IGNORE_DIRTY,GIT_SUBMODULE_IGNORE_ALL" },
  { "git_cert_t", 692, _cffi_prim_int(sizeof(git_cert_t), ((git_cert_t)-1) <= 0),
    "GIT_CERT_NONE,GIT_CERT_X509,GIT_CERT_HOSTKEY_LIBSSH2,GIT_CERT_STRARRAY" },
  { "git_remote_completion_type", 437, _cffi_prim_int(sizeof(git_remote_completion_type), ((git_remote_completion_type)-1) <= 0),
    "GIT_REMOTE_COMPLETION_DOWNLOAD,GIT_REMOTE_COMPLETION_INDEXING,GIT_REMOTE_COMPLETION_ERROR" },
};

static const struct _cffi_typename_s _cffi_typenames[] = {
  { "git_attr_t", 683 },
  { "git_blame", 684 },
  { "git_blame_hunk", 686 },
  { "git_blame_options", 687 },
  { "git_buf", 688 },
  { "git_cert", 689 },
  { "git_cert_hostkey", 690 },
  { "git_cert_ssh_t", 691 },
  { "git_cert_t", 692 },
  { "git_cert_x509", 693 },
  { "git_checkout_notify_cb", 767 },
  { "git_checkout_notify_t", 107 },
  { "git_checkout_options", 694 },
  { "git_checkout_perfdata", 695 },
  { "git_checkout_perfdata_cb", 792 },
  { "git_checkout_progress_cb", 791 },
  { "git_clone_local_t", 696 },
  { "git_clone_options", 697 },
  { "git_commit", 698 },
  { "git_config", 699 },
  { "git_config_entry", 700 },
  { "git_config_iterator", 701 },
  { "git_config_level_t", 155 },
  { "git_cred", 703 },
  { "git_cred_acquire_cb", 768 },
  { "git_credtype_t", 704 },
  { "git_delta_t", 705 },
  { "git_describe_format_options", 706 },
  { "git_describe_options", 707 },
  { "git_describe_result", 708 },
  { "git_describe_strategy_t", 709 },
  { "git_diff", 711 },
  { "git_diff_delta", 712 },
  { "git_diff_file", 713 },
  { "git_diff_notify_cb", 770 },
  { "git_diff_options", 714 },
  { "git_diff_progress_cb", 769 },
  { "git_diff_similarity_metric", 716 },
  { "git_direction", 717 },
  { "git_error", 719 },
  { "git_error_code", 720 },
  { "git_feature_t", 721 },
  { "git_fetch_options", 722 },
  { "git_fetch_prune_t", 723 },
  { "git_index", 724 },
  { "git_index_conflict_iterator", 725 },
  { "git_index_entry", 726 },
  { "git_index_matched_path_cb", 313 },
  { "git_index_time", 727 },
  { "git_merge_file_favor_t", 728 },
  { "git_merge_file_flag_t", 729 },
  { "git_merge_file_options", 730 },
  { "git_merge_file_result", 731 },
  { "git_merge_flag_t", 732 },
  { "git_merge_options", 733 },
  { "git_object", 734 },
  { "git_off_t", 167 },
  { "git_oid", 735 },
  { "git_packbuilder_progress", 779 },
  { "git_proxy_options", 736 },
  { "git_proxy_t", 737 },
  { "git_push_negotiation", 771 },
  { "git_push_options", 738 },
  { "git_push_transfer_progress", 780 },
  { "git_push_update", 740 },
  { "git_push_update_reference_cb", 313 },
  { "git_reference_t", 741 },
  { "git_refspec", 742 },
  { "git_remote", 743 },
  { "git_remote_autotag_option_t", 744 },
  { "git_remote_callbacks", 745 },
  { "git_remote_completion_type", 437 },
  { "git_remote_create_cb", 772 },
  { "git_repository", 746 },
  { "git_repository_create_cb", 774 },
  { "git_repository_init_flag_t", 747 },
  { "git_repository_init_mode_t", 748 },
  { "git_repository_init_options", 749 },
  { "git_signature", 751 },
  { "git_stash_apply_flags", 752 },
  { "git_stash_apply_options", 753 },
  { "git_stash_apply_progress_cb", 775 },
  { "git_stash_apply_progress_t", 519 },
  { "git_stash_cb", 498 },
  { "git_stash_flags", 754 },
  { "git_strarray", 755 },
  { "git_submodule", 756 },
  { "git_submodule_ignore_t", 757 },
  { "git_submodule_update_options", 758 },
  { "git_time", 759 },
  { "git_time_t", 167 },
  { "git_transfer_progress", 760 },
  { "git_transfer_progress_cb", 776 },
  { "git_transport", 762 },
  { "git_transport_cb", 777 },
  { "git_transport_certificate_check_cb", 766 },
  { "git_transport_message_cb", 765 },
  { "git_tree", 763 },
};

static const struct _cffi_type_context_s _cffi_type_context = {
  _cffi_types,
  _cffi_globals,
  _cffi_fields,
  _cffi_struct_unions,
  _cffi_enums,
  _cffi_typenames,
  311,  /* num_globals */
  51,  /* num_struct_unions */
  26,  /* num_enums */
  98,  /* num_typenames */
  NULL,  /* no includes */
  796,  /* num_types */
  0,  /* flags */
};

#ifdef __GNUC__
#  pragma GCC visibility push(default)  /* for -fvisibility= */
#endif

#ifdef PYPY_VERSION
PyMODINIT_FUNC
_cffi_pypyinit__libgit2(const void *p[])
{
    p[0] = (const void *)0x2601;
    p[1] = &_cffi_type_context;
#if PY_MAJOR_VERSION >= 3
    return NULL;
#endif
}
#  ifdef _MSC_VER
     PyMODINIT_FUNC
#  if PY_MAJOR_VERSION >= 3
     PyInit__libgit2(void) { return NULL; }
#  else
     init_libgit2(void) { }
#  endif
#  endif
#elif PY_MAJOR_VERSION >= 3
PyMODINIT_FUNC
PyInit__libgit2(void)
{
  return _cffi_init("pygit2._libgit2", 0x2601, &_cffi_type_context);
}
#else
PyMODINIT_FUNC
init_libgit2(void)
{
  _cffi_init("pygit2._libgit2", 0x2601, &_cffi_type_context);
}
#endif

#ifdef __GNUC__
#  pragma GCC visibility pop
#endif
